/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_24[21] = {
0x34,0x08,0x00,0x00,0x21,0x05,0x05,0x00,0x01,0x06,0x01,0x01,0x07,0x02,0x01,0x04,0x07,0x24,0x05,0x38,
0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_24, 3, (MRB_SYM(k), MRB_SYM(v), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_24 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_24,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_24,
  NULL,					/* debug_info */
  21,0,0,0,0
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_25[4] = {
{IREP_TT_STR|(19<<2), {"\x77\x72\x6f\x6e\x67\x20\x65\x6c\x65\x6d\x65\x6e\x74\x20\x74\x79\x70\x65\x20"}},
{IREP_TT_STR|(17<<2), {"\x20\x28\x65\x78\x70\x65\x63\x74\x65\x64\x20\x61\x72\x72\x61\x79\x29"}},
{IREP_TT_STR|(28<<2), {"\x69\x6e\x76\x61\x6c\x69\x64\x20\x6e\x75\x6d\x62\x65\x72\x20\x6f\x66\x20\x65\x6c\x65\x6d\x65\x6e\x74\x73\x20\x28"}},
{IREP_TT_STR|(10<<2), {"\x20\x66\x6f\x72\x20\x31\x2e\x2e\x32\x29"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_25, 7, (MRB_SYM(to_a), MRB_SYM_Q(respond_to), MRB_SYM(ArgumentError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(size), MRB_OPSYM(eqq), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_25[171] = {
0x34,0x04,0x00,0x00,0x01,0x05,0x01,0x10,0x06,0x00,0x2f,0x05,0x01,0x01,0x26,0x05,0x00,0x18,0x1d,0x06,
0x02,0x51,0x07,0x00,0x01,0x08,0x01,0x2f,0x08,0x03,0x00,0x52,0x07,0x51,0x08,0x01,0x52,0x07,0x2d,0x05,
0x04,0x02,0x11,0x05,0x4c,0x03,0x05,0x00,0x4c,0x04,0x05,0x01,0x01,0x05,0x01,0x2f,0x05,0x05,0x00,0x08,
0x06,0x01,0x07,0x05,0x2f,0x06,0x06,0x01,0x26,0x06,0x00,0x03,0x25,0x00,0x17,0x01,0x06,0x01,0x06,0x07,
0x23,0x06,0x01,0x03,0x06,0x01,0x06,0x01,0x07,0x07,0x23,0x06,0x01,0x04,0x06,0x25,0x00,0x38,0x07,0x06,
0x01,0x07,0x05,0x2f,0x06,0x06,0x01,0x26,0x06,0x00,0x03,0x25,0x00,0x0d,0x01,0x06,0x01,0x06,0x07,0x23,
0x06,0x01,0x03,0x06,0x25,0x00,0x1b,0x1d,0x07,0x02,0x51,0x08,0x02,0x01,0x09,0x01,0x2f,0x09,0x05,0x00,
0x52,0x08,0x51,0x09,0x03,0x52,0x08,0x2d,0x06,0x04,0x02,0x25,0x00,0x00,0x21,0x06,0x05,0x00,0x01,0x07,
0x03,0x01,0x08,0x04,0x01,0x05,0x08,0x24,0x06,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_25, 4, (MRB_SYM(i), 0,MRB_SYM(k), MRB_SYM(v), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_25 = {
  5,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_25,
  gem_mrblib_mruby_hash_ext_proc_pool_25,gem_mrblib_mruby_hash_ext_proc_syms_25,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_25,
  NULL,					/* debug_info */
  171,4,7,0,0
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_26[36] = {
0x34,0x04,0x00,0x00,0x21,0x04,0x05,0x00,0x21,0x05,0x01,0x00,0x01,0x06,0x01,0x23,0x05,0x21,0x06,0x01,
0x00,0x01,0x07,0x01,0x3d,0x07,0x01,0x23,0x06,0x01,0x03,0x06,0x24,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_26, 2, (MRB_SYM(i), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_26 = {
  3,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_26,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_26,
  NULL,					/* debug_info */
  36,0,0,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_2[3] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_24,
  &gem_mrblib_mruby_hash_ext_proc_irep_25,
  &gem_mrblib_mruby_hash_ext_proc_irep_26,
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_2[1] = {
{IREP_TT_STR|(32<<2), {"\x6f\x64\x64\x20\x6e\x75\x6d\x62\x65\x72\x20\x6f\x66\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x73\x20\x66\x6f\x72\x20\x48\x61\x73\x68"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_2, 11, (MRB_SYM(length), MRB_SYM(Hash), MRB_OPSYM(eqq), MRB_SYM(new), MRB_SYM(each), MRB_SYM(to_a), MRB_SYM_Q(respond_to), MRB_OPSYM(mod), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(step), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_2[167] = {
0x34,0x00,0x10,0x00,0x01,0x06,0x01,0x2f,0x06,0x00,0x00,0x01,0x03,0x06,0x01,0x06,0x03,0x07,0x07,0x42,
0x06,0x27,0x06,0x00,0x57,0x01,0x06,0x01,0x06,0x07,0x23,0x06,0x01,0x04,0x06,0x1d,0x06,0x01,0x01,0x07,
0x04,0x2f,0x06,0x02,0x01,0x27,0x06,0x00,0x18,0x12,0x06,0x2f,0x06,0x03,0x00,0x01,0x05,0x06,0x01,0x06,
0x04,0x57,0x07,0x00,0x30,0x06,0x04,0x00,0x38,0x05,0x25,0x00,0x27,0x01,0x06,0x04,0x10,0x07,0x05,0x2f,
0x06,0x06,0x01,0x27,0x06,0x00,0x19,0x12,0x06,0x2f,0x06,0x03,0x00,0x01,0x05,0x06,0x01,0x06,0x04,0x2f,
0x06,0x05,0x00,0x57,0x07,0x01,0x30,0x06,0x04,0x00,0x38,0x05,0x01,0x06,0x03,0x08,0x07,0x2f,0x06,0x07,
0x01,0x06,0x07,0x42,0x06,0x26,0x06,0x00,0x0a,0x1d,0x07,0x08,0x51,0x08,0x00,0x2d,0x06,0x09,0x02,0x12,
0x06,0x2f,0x06,0x03,0x00,0x01,0x05,0x06,0x06,0x06,0x01,0x07,0x03,0x3f,0x07,0x02,0x08,0x08,0x57,0x09,
0x02,0x30,0x06,0x0a,0x02,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_2, 5, (MRB_SYM(object), 0,MRB_SYM(length), MRB_SYM(o), MRB_SYM(h), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_2 = {
  6,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_2,
  gem_mrblib_mruby_hash_ext_proc_pool_2,gem_mrblib_mruby_hash_ext_proc_syms_2,gem_mrblib_mruby_hash_ext_proc_reps_2,
  gem_mrblib_mruby_hash_ext_proc_lv_2,
  NULL,					/* debug_info */
  167,1,11,3,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_55, 2, (MRB_SYM_Q(has_key), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_55[68] = {
0x34,0x04,0x00,0x00,0x12,0x04,0x01,0x05,0x01,0x12,0x06,0x01,0x07,0x01,0x2f,0x06,0x00,0x01,0x27,0x06,
0x00,0x1e,0x21,0x06,0x02,0x00,0x01,0x07,0x01,0x12,0x08,0x01,0x09,0x01,0x23,0x08,0x21,0x09,0x05,0x00,
0x01,0x0a,0x01,0x23,0x09,0x2f,0x06,0x01,0x03,0x25,0x00,0x09,0x21,0x06,0x05,0x00,0x01,0x07,0x01,0x23,
0x06,0x01,0x03,0x06,0x24,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_55, 2, (MRB_SYM(k), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_55 = {
  3,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_55,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_55,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_55,
  NULL,					/* debug_info */
  68,0,2,0,0
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_56[25] = {
0x34,0x04,0x00,0x00,0x12,0x04,0x01,0x05,0x01,0x21,0x06,0x05,0x00,0x01,0x07,0x01,0x23,0x06,0x01,0x03,
0x06,0x24,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_56, 2, (MRB_SYM(k), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_56 = {
  3,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_56,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_56,
  NULL,					/* debug_info */
  25,0,0,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_3[2] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_55,
  &gem_mrblib_mruby_hash_ext_proc_irep_56,
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_3[2] = {
{IREP_TT_STR|(15<<2), {"\x48\x61\x73\x68\x20\x72\x65\x71\x75\x69\x72\x65\x64\x20\x28"}},
{IREP_TT_STR|(7<<2), {"\x20\x67\x69\x76\x65\x6e\x29"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_3, 8, (MRB_SYM(size), MRB_SYM(__merge), MRB_SYM(Hash), MRB_OPSYM(eqq), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(each_key), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_3[139] = {
0x34,0x00,0x10,0x01,0x06,0x03,0x01,0x06,0x01,0x2f,0x06,0x00,0x00,0x01,0x04,0x06,0x01,0x06,0x02,0x26,
0x06,0x00,0x0f,0x12,0x06,0x11,0x07,0x01,0x08,0x01,0x49,0x07,0x2f,0x06,0x01,0x0f,0x38,0x06,0x01,0x06,
0x03,0x01,0x07,0x04,0x43,0x06,0x27,0x06,0x00,0x55,0x01,0x06,0x01,0x01,0x07,0x03,0x23,0x06,0x01,0x05,
0x06,0x3d,0x03,0x01,0x1d,0x06,0x02,0x01,0x07,0x05,0x2f,0x06,0x03,0x01,0x26,0x06,0x00,0x18,0x1d,0x07,
0x04,0x51,0x08,0x00,0x01,0x09,0x05,0x2f,0x09,0x05,0x00,0x52,0x08,0x51,0x09,0x01,0x52,0x08,0x2d,0x06,
0x06,0x02,0x01,0x06,0x02,0x27,0x06,0x00,0x0d,0x01,0x06,0x05,0x57,0x07,0x00,0x30,0x06,0x07,0x00,0x25,
0x00,0x0a,0x01,0x06,0x05,0x57,0x07,0x01,0x30,0x06,0x07,0x00,0x25,0xff,0x9f,0x12,0x06,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_3, 5, (MRB_SYM(others), MRB_SYM(block), MRB_SYM(i), MRB_SYM(len), MRB_SYM(other), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_3 = {
  6,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_3,
  gem_mrblib_mruby_hash_ext_proc_pool_3,gem_mrblib_mruby_hash_ext_proc_syms_3,gem_mrblib_mruby_hash_ext_proc_reps_3,
  gem_mrblib_mruby_hash_ext_proc_lv_3,
  NULL,					/* debug_info */
  139,2,8,2,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_4, 1, (MRB_SYM(__compact), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_4[12] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x2f,0x02,0x00,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_4, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_4 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_4,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_4,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_4,
  NULL,					/* debug_info */
  12,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_5, 2, (MRB_SYM(dup), MRB_SYM(__compact), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_5[22] = {
0x34,0x00,0x00,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x2f,0x03,0x01,0x00,
0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_5, 2, (0,MRB_SYM(h), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_5 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_5,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_5,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_5,
  NULL,					/* debug_info */
  22,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_6[1] = {
{IREP_TT_STR|(15<<2), {"\x4b\x65\x79\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x3a\x20"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_6, 7, (MRB_SYM(NONE), MRB_SYM_Q(key), MRB_SYM(call), MRB_OPSYM(neq), MRB_SYM(KeyError), MRB_SYM(inspect), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_6[97] = {
0x34,0x04,0x20,0x01,0x25,0x00,0x03,0x25,0x00,0x03,0x1d,0x02,0x00,0x12,0x04,0x01,0x05,0x01,0x2f,0x04,
0x01,0x01,0x27,0x04,0x00,0x0a,0x12,0x04,0x01,0x05,0x01,0x23,0x04,0x25,0x00,0x3b,0x01,0x04,0x03,0x27,
0x04,0x00,0x0d,0x01,0x04,0x03,0x01,0x05,0x01,0x2f,0x04,0x02,0x01,0x25,0x00,0x27,0x01,0x04,0x02,0x1d,
0x05,0x00,0x2f,0x04,0x03,0x01,0x27,0x04,0x00,0x06,0x01,0x04,0x02,0x25,0x00,0x13,0x1d,0x05,0x04,0x51,
0x06,0x00,0x01,0x07,0x01,0x2f,0x07,0x05,0x00,0x52,0x06,0x2d,0x04,0x06,0x02,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_6, 3, (MRB_SYM(key), MRB_SYM(none), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_6 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_6,
  gem_mrblib_mruby_hash_ext_proc_pool_6,gem_mrblib_mruby_hash_ext_proc_syms_6,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_6,
  NULL,					/* debug_info */
  97,1,7,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_147, 2, (MRB_SYM(call), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_147[38] = {
0x34,0x08,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x01,0x06,0x02,0x2f,0x04,0x00,0x02,0x27,0x04,
0x00,0x0c,0x12,0x04,0x01,0x05,0x01,0x2f,0x04,0x01,0x01,0x25,0x00,0x02,0x11,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_147, 3, (MRB_SYM(k), MRB_SYM(v), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_147 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_147,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_147,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_147,
  NULL,					/* debug_info */
  38,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_7[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_147,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_7, 3, (MRB_SYM(delete_if), MRB_SYM(to_enum), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_7[33] = {
0x34,0x00,0x00,0x01,0x01,0x02,0x01,0x26,0x02,0x00,0x09,0x10,0x03,0x00,0x2d,0x02,0x01,0x01,0x38,0x02,
0x12,0x02,0x57,0x03,0x00,0x30,0x02,0x02,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_7, 1, (MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_7 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_7,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_7,gem_mrblib_mruby_hash_ext_proc_reps_7,
  gem_mrblib_mruby_hash_ext_proc_lv_7,
  NULL,					/* debug_info */
  33,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_8, 2, (MRB_SYM(to_a), MRB_SYM(flatten), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_8[27] = {
0x34,0x00,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x07,0x01,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x04,
0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_8, 2, (MRB_SYM(level), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_8 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_8,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_8,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_8,
  NULL,					/* debug_info */
  27,0,2,0,0
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_192[21] = {
0x34,0x08,0x00,0x00,0x21,0x05,0x02,0x00,0x01,0x06,0x02,0x01,0x07,0x01,0x01,0x04,0x07,0x24,0x05,0x38,
0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_192, 3, (MRB_SYM(k), MRB_SYM(v), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_192 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_192,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_192,
  NULL,					/* debug_info */
  21,0,0,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_9[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_192,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_9, 3, (MRB_SYM(class), MRB_SYM(new), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_9[28] = {
0x34,0x00,0x00,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x2f,0x03,0x01,0x00,0x01,0x02,0x03,0x12,0x03,0x57,
0x04,0x00,0x30,0x03,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_9, 2, (0,MRB_SYM(h), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_9 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_9,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_9,gem_mrblib_mruby_hash_ext_proc_reps_9,
  gem_mrblib_mruby_hash_ext_proc_lv_9,
  NULL,					/* debug_info */
  28,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_215, 2, (MRB_SYM(call), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_215[41] = {
0x34,0x08,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x01,0x06,0x02,0x47,0x05,0x02,0x2f,0x04,0x00,
0x01,0x27,0x04,0x00,0x05,0x11,0x04,0x25,0x00,0x09,0x12,0x04,0x01,0x05,0x01,0x2f,0x04,0x01,0x01,0x38,
0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_215, 3, (MRB_SYM(k), MRB_SYM(v), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_215 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_215,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_215,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_215,
  NULL,					/* debug_info */
  41,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_10[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_215,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_10, 3, (MRB_SYM(keep_if), MRB_SYM(to_enum), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_10[33] = {
0x34,0x00,0x00,0x01,0x01,0x02,0x01,0x26,0x02,0x00,0x09,0x10,0x03,0x00,0x2d,0x02,0x01,0x01,0x38,0x02,
0x12,0x02,0x57,0x03,0x00,0x30,0x02,0x02,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_10, 1, (MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_10 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_10,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_10,gem_mrblib_mruby_hash_ext_proc_reps_10,
  gem_mrblib_mruby_hash_ext_proc_lv_10,
  NULL,					/* debug_info */
  33,0,3,1,0
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_238[26] = {
0x34,0x08,0x00,0x00,0x01,0x04,0x02,0x21,0x05,0x01,0x00,0x42,0x04,0x27,0x04,0x00,0x05,0x39,0x01,0x25,
0x00,0x02,0x11,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_238, 3, (MRB_SYM(k), MRB_SYM(v), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_238 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_238,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_238,
  NULL,					/* debug_info */
  26,0,0,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_11[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_238,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_11, 1, (MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_11[17] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x57,0x04,0x00,0x30,0x03,0x00,0x00,0x11,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_11, 2, (MRB_SYM(val), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_11 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_11,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_11,gem_mrblib_mruby_hash_ext_proc_reps_11,
  gem_mrblib_mruby_hash_ext_proc_lv_11,
  NULL,					/* debug_info */
  17,0,1,1,0
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_12[8] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_12, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_12 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_12,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_12,
  NULL,					/* debug_info */
  8,0,0,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_283, 1, (MRB_SYM_Q(key), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_283[35] = {
0x34,0x08,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x2f,0x04,0x00,0x01,0x27,0x04,0x00,0x0e,0x21,
0x04,0x01,0x00,0x01,0x05,0x01,0x23,0x04,0x01,0x05,0x02,0x42,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_283, 3, (MRB_SYM(key), MRB_SYM(val), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_283 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_283,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_283,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_283,
  NULL,					/* debug_info */
  35,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_13[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_283,
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_13[2] = {
{IREP_TT_STR|(14<<2), {"\x63\x61\x6e\x27\x74\x20\x63\x6f\x6e\x76\x65\x72\x74\x20"}},
{IREP_TT_STR|(8<<2), {"\x20\x74\x6f\x20\x48\x61\x73\x68"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_13, 7, (MRB_SYM(Hash), MRB_OPSYM(eqq), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_13[68] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x18,0x1d,0x04,
0x02,0x51,0x05,0x00,0x01,0x06,0x01,0x2f,0x06,0x03,0x00,0x52,0x05,0x51,0x06,0x01,0x52,0x05,0x2d,0x03,
0x04,0x02,0x2d,0x03,0x05,0x00,0x01,0x04,0x01,0x2f,0x04,0x05,0x00,0x43,0x03,0x27,0x03,0x00,0x07,0x57,
0x04,0x00,0x2e,0x03,0x06,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_13, 2, (MRB_SYM(hash), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_13 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_13,
  gem_mrblib_mruby_hash_ext_proc_pool_13,gem_mrblib_mruby_hash_ext_proc_syms_13,gem_mrblib_mruby_hash_ext_proc_reps_13,
  gem_mrblib_mruby_hash_ext_proc_lv_13,
  NULL,					/* debug_info */
  68,2,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_306, 1, (MRB_SYM_Q(key), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_306[35] = {
0x34,0x08,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x2f,0x04,0x00,0x01,0x27,0x04,0x00,0x0e,0x21,
0x04,0x01,0x00,0x01,0x05,0x01,0x23,0x04,0x01,0x05,0x02,0x42,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_306, 3, (MRB_SYM(key), MRB_SYM(val), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_306 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_306,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_306,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_306,
  NULL,					/* debug_info */
  35,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_14[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_306,
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_14[2] = {
{IREP_TT_STR|(14<<2), {"\x63\x61\x6e\x27\x74\x20\x63\x6f\x6e\x76\x65\x72\x74\x20"}},
{IREP_TT_STR|(8<<2), {"\x20\x74\x6f\x20\x48\x61\x73\x68"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_14, 7, (MRB_SYM(Hash), MRB_OPSYM(eqq), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_14[68] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x18,0x1d,0x04,
0x02,0x51,0x05,0x00,0x01,0x06,0x01,0x2f,0x06,0x03,0x00,0x52,0x05,0x51,0x06,0x01,0x52,0x05,0x2d,0x03,
0x04,0x02,0x2d,0x03,0x05,0x00,0x01,0x04,0x01,0x2f,0x04,0x05,0x00,0x44,0x03,0x27,0x03,0x00,0x07,0x57,
0x04,0x00,0x2e,0x03,0x06,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_14, 2, (MRB_SYM(hash), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_14 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_14,
  gem_mrblib_mruby_hash_ext_proc_pool_14,gem_mrblib_mruby_hash_ext_proc_syms_14,gem_mrblib_mruby_hash_ext_proc_reps_14,
  gem_mrblib_mruby_hash_ext_proc_lv_14,
  NULL,					/* debug_info */
  68,2,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_329, 1, (MRB_SYM_Q(key), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_329[29] = {
0x34,0x08,0x00,0x00,0x01,0x05,0x01,0x2d,0x04,0x00,0x01,0x27,0x04,0x00,0x0c,0x12,0x04,0x01,0x05,0x01,
0x23,0x04,0x01,0x05,0x02,0x42,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_329, 3, (MRB_SYM(key), MRB_SYM(val), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_329 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_329,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_329,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_329,
  NULL,					/* debug_info */
  29,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_15[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_329,
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_15[2] = {
{IREP_TT_STR|(14<<2), {"\x63\x61\x6e\x27\x74\x20\x63\x6f\x6e\x76\x65\x72\x74\x20"}},
{IREP_TT_STR|(8<<2), {"\x20\x74\x6f\x20\x48\x61\x73\x68"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_15, 7, (MRB_SYM(Hash), MRB_OPSYM(eqq), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_15[71] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x18,0x1d,0x04,
0x02,0x51,0x05,0x00,0x01,0x06,0x01,0x2f,0x06,0x03,0x00,0x52,0x05,0x51,0x06,0x01,0x52,0x05,0x2d,0x03,
0x04,0x02,0x2d,0x03,0x05,0x00,0x01,0x04,0x01,0x2f,0x04,0x05,0x00,0x45,0x03,0x27,0x03,0x00,0x0a,0x01,
0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x06,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_15, 2, (MRB_SYM(hash), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_15 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_15,
  gem_mrblib_mruby_hash_ext_proc_pool_15,gem_mrblib_mruby_hash_ext_proc_syms_15,gem_mrblib_mruby_hash_ext_proc_reps_15,
  gem_mrblib_mruby_hash_ext_proc_lv_15,
  NULL,					/* debug_info */
  71,2,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_352, 1, (MRB_SYM_Q(key), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_352[29] = {
0x34,0x08,0x00,0x00,0x01,0x05,0x01,0x2d,0x04,0x00,0x01,0x27,0x04,0x00,0x0c,0x12,0x04,0x01,0x05,0x01,
0x23,0x04,0x01,0x05,0x02,0x42,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_352, 3, (MRB_SYM(key), MRB_SYM(val), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_352 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_352,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_352,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_352,
  NULL,					/* debug_info */
  29,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_16[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_352,
};
static const mrb_pool_value gem_mrblib_mruby_hash_ext_proc_pool_16[2] = {
{IREP_TT_STR|(14<<2), {"\x63\x61\x6e\x27\x74\x20\x63\x6f\x6e\x76\x65\x72\x74\x20"}},
{IREP_TT_STR|(8<<2), {"\x20\x74\x6f\x20\x48\x61\x73\x68"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_16, 7, (MRB_SYM(Hash), MRB_OPSYM(eqq), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_16[71] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x18,0x1d,0x04,
0x02,0x51,0x05,0x00,0x01,0x06,0x01,0x2f,0x06,0x03,0x00,0x52,0x05,0x51,0x06,0x01,0x52,0x05,0x2d,0x03,
0x04,0x02,0x2d,0x03,0x05,0x00,0x01,0x04,0x01,0x2f,0x04,0x05,0x00,0x46,0x03,0x27,0x03,0x00,0x0a,0x01,
0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x06,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_16, 2, (MRB_SYM(hash), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_16 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_16,
  gem_mrblib_mruby_hash_ext_proc_pool_16,gem_mrblib_mruby_hash_ext_proc_syms_16,gem_mrblib_mruby_hash_ext_proc_reps_16,
  gem_mrblib_mruby_hash_ext_proc_lv_16,
  NULL,					/* debug_info */
  71,2,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_17, 2, (MRB_SYM(size), MRB_SYM(dig), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_17[58] = {
0x34,0x04,0x10,0x00,0x12,0x05,0x01,0x06,0x01,0x23,0x05,0x01,0x04,0x05,0x01,0x05,0x02,0x2f,0x05,0x00,
0x00,0x06,0x06,0x45,0x05,0x27,0x05,0x00,0x18,0x01,0x05,0x04,0x01,0x06,0x05,0x28,0x06,0x00,0x0b,0x11,
0x06,0x01,0x07,0x02,0x49,0x06,0x2f,0x05,0x01,0x0f,0x25,0x00,0x03,0x01,0x05,0x04,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_17, 4, (MRB_SYM(idx), MRB_SYM(args), 0,MRB_SYM(n), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_17 = {
  5,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_17,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_17,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_17,
  NULL,					/* debug_info */
  58,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_397, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_397[39] = {
0x34,0x04,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x2f,0x04,0x00,0x01,0x01,0x03,0x04,0x21,0x05,
0x02,0x00,0x01,0x06,0x03,0x12,0x07,0x01,0x08,0x01,0x23,0x07,0x01,0x04,0x07,0x24,0x05,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_397, 3, (MRB_SYM(k), 0,MRB_SYM(new_key), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_397 = {
  4,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_397,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_397,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_397,
  NULL,					/* debug_info */
  39,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_18[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_397,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_18, 4, (MRB_SYM(transform_keys), MRB_SYM(to_enum), MRB_SYM(keys), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_18[38] = {
0x34,0x00,0x00,0x01,0x01,0x03,0x01,0x26,0x03,0x00,0x09,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,0x38,0x03,
0x53,0x02,0x00,0x12,0x03,0x2f,0x03,0x02,0x00,0x57,0x04,0x00,0x30,0x03,0x03,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_18, 2, (MRB_SYM(block), MRB_SYM(hash), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_18 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_18,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_18,gem_mrblib_mruby_hash_ext_proc_reps_18,
  gem_mrblib_mruby_hash_ext_proc_lv_18,
  NULL,					/* debug_info */
  38,0,4,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_19, 4, (MRB_SYM_B(transform_keys), MRB_SYM(to_enum), MRB_SYM(transform_keys), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_19[45] = {
0x34,0x00,0x00,0x01,0x01,0x03,0x01,0x26,0x03,0x00,0x09,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,0x38,0x03,
0x12,0x03,0x01,0x04,0x01,0x30,0x03,0x02,0x00,0x01,0x02,0x03,0x12,0x03,0x01,0x04,0x02,0x2f,0x03,0x03,
0x01,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_19, 2, (MRB_SYM(block), MRB_SYM(hash), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_19 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_19,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_19,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_19,
  NULL,					/* debug_info */
  45,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_442, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_442[33] = {
0x34,0x04,0x00,0x00,0x21,0x04,0x02,0x00,0x01,0x05,0x01,0x12,0x07,0x01,0x08,0x01,0x23,0x07,0x3b,0x06,
0x00,0x01,0x2f,0x06,0x00,0x01,0x01,0x03,0x06,0x24,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_442, 2, (MRB_SYM(k), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_442 = {
  3,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_442,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_442,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_442,
  NULL,					/* debug_info */
  33,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_20[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_442,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_20, 5, (MRB_SYM_Q(block_given), MRB_SYM(transform_values), MRB_SYM(to_enum), MRB_SYM(keys), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_20[39] = {
0x34,0x00,0x00,0x01,0x2d,0x03,0x00,0x00,0x26,0x03,0x00,0x09,0x10,0x04,0x01,0x2d,0x03,0x02,0x01,0x38,
0x03,0x53,0x02,0x00,0x12,0x03,0x2f,0x03,0x03,0x00,0x57,0x04,0x00,0x30,0x03,0x04,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_20, 2, (MRB_SYM(b), MRB_SYM(hash), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_20 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_20,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_20,gem_mrblib_mruby_hash_ext_proc_reps_20,
  gem_mrblib_mruby_hash_ext_proc_lv_20,
  NULL,					/* debug_info */
  39,0,5,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_465, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_465[31] = {
0x34,0x04,0x00,0x00,0x12,0x04,0x01,0x05,0x01,0x12,0x07,0x01,0x08,0x01,0x23,0x07,0x3b,0x06,0x00,0x01,
0x2f,0x06,0x00,0x01,0x01,0x03,0x06,0x24,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_465, 2, (MRB_SYM(k), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_465 = {
  3,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_465,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_465,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_465,
  NULL,					/* debug_info */
  31,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_21[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_465,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_21, 5, (MRB_SYM_Q(block_given), MRB_SYM_B(transform_values), MRB_SYM(to_enum), MRB_SYM(keys), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_21[38] = {
0x34,0x00,0x00,0x01,0x2d,0x02,0x00,0x00,0x26,0x02,0x00,0x09,0x10,0x03,0x01,0x2d,0x02,0x02,0x01,0x38,
0x02,0x12,0x02,0x2f,0x02,0x03,0x00,0x57,0x03,0x00,0x30,0x02,0x04,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_21, 1, (MRB_SYM(b), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_21 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_21,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_21,gem_mrblib_mruby_hash_ext_proc_reps_21,
  gem_mrblib_mruby_hash_ext_proc_lv_21,
  NULL,					/* debug_info */
  38,0,5,1,0
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_488[13] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x23,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_488, 2, (MRB_SYM(x), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_488 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_488,
  NULL,NULL,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_488,
  NULL,					/* debug_info */
  13,0,0,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_22[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_488,
};
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_22[9] = {
0x34,0x00,0x00,0x00,0x56,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_22, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_22 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_22,
  NULL,NULL,gem_mrblib_mruby_hash_ext_proc_reps_22,
  gem_mrblib_mruby_hash_ext_proc_lv_22,
  NULL,					/* debug_info */
  9,0,0,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_511, 1, (MRB_SYM(fetch), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_511[19] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x21,0x05,0x02,0x00,0x30,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_511, 2, (MRB_SYM(k), 0,), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_511 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_511,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_511,NULL,
  gem_mrblib_mruby_hash_ext_proc_lv_511,
  NULL,					/* debug_info */
  19,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_23[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_511,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_23, 1, (MRB_SYM(map), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_23[16] = {
0x34,0x00,0x10,0x01,0x01,0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x00,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_lv_23, 2, (MRB_SYM(keys), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_23 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_23,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_23,gem_mrblib_mruby_hash_ext_proc_reps_23,
  gem_mrblib_mruby_hash_ext_proc_lv_23,
  NULL,					/* debug_info */
  16,0,1,1,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_1[22] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_2,
  &gem_mrblib_mruby_hash_ext_proc_irep_3,
  &gem_mrblib_mruby_hash_ext_proc_irep_4,
  &gem_mrblib_mruby_hash_ext_proc_irep_5,
  &gem_mrblib_mruby_hash_ext_proc_irep_6,
  &gem_mrblib_mruby_hash_ext_proc_irep_7,
  &gem_mrblib_mruby_hash_ext_proc_irep_8,
  &gem_mrblib_mruby_hash_ext_proc_irep_9,
  &gem_mrblib_mruby_hash_ext_proc_irep_10,
  &gem_mrblib_mruby_hash_ext_proc_irep_11,
  &gem_mrblib_mruby_hash_ext_proc_irep_12,
  &gem_mrblib_mruby_hash_ext_proc_irep_13,
  &gem_mrblib_mruby_hash_ext_proc_irep_14,
  &gem_mrblib_mruby_hash_ext_proc_irep_15,
  &gem_mrblib_mruby_hash_ext_proc_irep_16,
  &gem_mrblib_mruby_hash_ext_proc_irep_17,
  &gem_mrblib_mruby_hash_ext_proc_irep_18,
  &gem_mrblib_mruby_hash_ext_proc_irep_19,
  &gem_mrblib_mruby_hash_ext_proc_irep_20,
  &gem_mrblib_mruby_hash_ext_proc_irep_21,
  &gem_mrblib_mruby_hash_ext_proc_irep_22,
  &gem_mrblib_mruby_hash_ext_proc_irep_23,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_1, 29, (MRB_SYM(each_pair), MRB_SYM(each), MRB_OPSYM(aref), MRB_SYM_B(merge), MRB_SYM(update), MRB_SYM_B(compact), MRB_SYM(compact), MRB_SYM(fetch), MRB_SYM(delete_if), MRB_SYM(flatten), MRB_SYM(invert), MRB_SYM(keep_if), MRB_SYM(key), MRB_SYM(to_h), MRB_OPSYM(lt), MRB_OPSYM(le), MRB_OPSYM(gt), MRB_OPSYM(ge), MRB_SYM(dig), MRB_SYM(transform_keys), MRB_SYM_B(transform_keys), MRB_SYM(transform_values), MRB_SYM_B(transform_values), MRB_SYM(to_proc), MRB_SYM(fetch_values), MRB_SYM(filter), MRB_SYM(select), MRB_SYM_B(filter), MRB_SYM_B(select), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_1[194] = {
0x60,0x00,0x01,0x12,0x01,0x62,0x01,0x58,0x02,0x00,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,
0x03,0x60,0x04,0x03,0x63,0x01,0x58,0x02,0x02,0x5f,0x01,0x05,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x06,
0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x07,0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x08,0x63,0x01,0x58,0x02,
0x06,0x5f,0x01,0x09,0x63,0x01,0x58,0x02,0x07,0x5f,0x01,0x0a,0x63,0x01,0x58,0x02,0x08,0x5f,0x01,0x0b,
0x63,0x01,0x58,0x02,0x09,0x5f,0x01,0x0c,0x63,0x01,0x58,0x02,0x0a,0x5f,0x01,0x0d,0x63,0x01,0x58,0x02,
0x0b,0x5f,0x01,0x0e,0x63,0x01,0x58,0x02,0x0c,0x5f,0x01,0x0f,0x63,0x01,0x58,0x02,0x0d,0x5f,0x01,0x10,
0x63,0x01,0x58,0x02,0x0e,0x5f,0x01,0x11,0x63,0x01,0x58,0x02,0x0f,0x5f,0x01,0x12,0x63,0x01,0x58,0x02,
0x10,0x5f,0x01,0x13,0x63,0x01,0x58,0x02,0x11,0x5f,0x01,0x14,0x63,0x01,0x58,0x02,0x12,0x5f,0x01,0x15,
0x63,0x01,0x58,0x02,0x13,0x5f,0x01,0x16,0x63,0x01,0x58,0x02,0x14,0x5f,0x01,0x17,0x63,0x01,0x58,0x02,
0x15,0x5f,0x01,0x18,0x60,0x19,0x1a,0x60,0x1b,0x1c,0x11,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_1 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_1,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_1,gem_mrblib_mruby_hash_ext_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  194,0,29,22,0
};
static const mrb_irep *gem_mrblib_mruby_hash_ext_proc_reps_0[1] = {
  &gem_mrblib_mruby_hash_ext_proc_irep_1,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_hash_ext_proc_syms_0, 1, (MRB_SYM(Hash), ), const);
static const mrb_code gem_mrblib_mruby_hash_ext_proc_iseq_0[13] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_hash_ext_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_hash_ext_proc_iseq_0,
  NULL,gem_mrblib_mruby_hash_ext_proc_syms_0,gem_mrblib_mruby_hash_ext_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  13,0,1,1,0
};
static
const struct RProc gem_mrblib_mruby_hash_ext_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_hash_ext_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_hash_ext_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_hash_ext_gem_init(mrb_state *mrb);
void mrb_mruby_hash_ext_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_hash_ext_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_hash_ext_proc_init_syms(mrb);
  mrb_mruby_hash_ext_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_hash_ext_proc);
}

void GENERATED_TMP_mrb_mruby_hash_ext_gem_final(mrb_state *mrb) {
  mrb_mruby_hash_ext_gem_final(mrb);
}
