/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_6[1] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_6, 5, (MRB_SYM(Integer), MRB_SYM_Q(kind_of), MRB_IVSYM(path), MRB_SYM(IO), MRB_SYM(sysopen), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_6[85] = {
0x34,0x04,0x40,0x00,0x25,0x00,0x06,0x25,0x00,0x06,0x25,0x00,0x07,0x51,0x02,0x00,0x0e,0x03,0x01,0xb6,
0x01,0x06,0x01,0x1d,0x07,0x00,0x2f,0x06,0x01,0x01,0x27,0x06,0x00,0x0f,0x01,0x07,0x01,0x01,0x08,0x02,
0x01,0x09,0x04,0x32,0x06,0x02,0x25,0x00,0x22,0x1a,0x01,0x02,0x1d,0x06,0x03,0x19,0x07,0x02,0x01,0x08,
0x02,0x01,0x09,0x03,0x2f,0x06,0x04,0x03,0x01,0x05,0x06,0x01,0x07,0x05,0x01,0x08,0x02,0x01,0x09,0x04,
0x32,0x06,0x02,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_6, 5, (MRB_SYM(fd_or_path), MRB_SYM(mode), MRB_SYM(perm), 0,MRB_SYM(fd), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_6 = {
  6,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_6,
  gem_mrblib_mruby_io_proc_pool_6,gem_mrblib_mruby_io_proc_syms_6,NULL,
  gem_mrblib_mruby_io_proc_lv_6,
  NULL,					/* debug_info */
  85,1,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_7, 3, (MRB_SYM(_atime), MRB_SYM(Time), MRB_SYM(at), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_7[32] = {
0x34,0x00,0x00,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x27,0x03,0x00,0x0a,
0x1d,0x03,0x01,0x01,0x04,0x02,0x2f,0x03,0x02,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_7, 2, (0,MRB_SYM(t), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_7 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_7,
  NULL,gem_mrblib_mruby_io_proc_syms_7,NULL,
  gem_mrblib_mruby_io_proc_lv_7,
  NULL,					/* debug_info */
  32,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_8, 3, (MRB_SYM(_ctime), MRB_SYM(Time), MRB_SYM(at), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_8[32] = {
0x34,0x00,0x00,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x27,0x03,0x00,0x0a,
0x1d,0x03,0x01,0x01,0x04,0x02,0x2f,0x03,0x02,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_8, 2, (0,MRB_SYM(t), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_8 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_8,
  NULL,gem_mrblib_mruby_io_proc_syms_8,NULL,
  gem_mrblib_mruby_io_proc_lv_8,
  NULL,					/* debug_info */
  32,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_9, 3, (MRB_SYM(_mtime), MRB_SYM(Time), MRB_SYM(at), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_9[32] = {
0x34,0x00,0x00,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x27,0x03,0x00,0x0a,
0x1d,0x03,0x01,0x01,0x04,0x02,0x2f,0x03,0x02,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_9, 2, (0,MRB_SYM(t), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_9 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_9,
  NULL,gem_mrblib_mruby_io_proc_syms_9,NULL,
  gem_mrblib_mruby_io_proc_lv_9,
  NULL,					/* debug_info */
  32,0,3,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_10[3] = {
{IREP_TT_STR|(1<<2), {"\x3c"}},
{IREP_TT_STR|(1<<2), {"\x3a"}},
{IREP_TT_STR|(1<<2), {"\x3e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_10, 2, (MRB_SYM(class), MRB_IVSYM(path), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_10[32] = {
0x34,0x00,0x00,0x00,0x51,0x02,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x52,0x02,0x51,0x03,0x01,0x52,0x02,
0x19,0x03,0x01,0x52,0x02,0x51,0x03,0x02,0x52,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_10, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_10 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_10,
  gem_mrblib_mruby_io_proc_pool_10,gem_mrblib_mruby_io_proc_syms_10,NULL,
  gem_mrblib_mruby_io_proc_lv_10,
  NULL,					/* debug_info */
  32,3,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_132[3] = {
{IREP_TT_STR|(15<<2), {"\x72\x65\x63\x75\x72\x73\x69\x76\x65\x20\x61\x72\x72\x61\x79"}},
{IREP_TT_STR|(26<<2), {"\x6e\x6f\x20\x69\x6d\x70\x6c\x69\x63\x69\x74\x20\x63\x6f\x6e\x76\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20"}},
{IREP_TT_STR|(12<<2), {"\x20\x69\x6e\x74\x6f\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_132, 8, (MRB_SYM(String), MRB_OPSYM(eqq), MRB_SYM(Array), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(join), MRB_SYM(TypeError), MRB_SYM(class), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_132[115] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x01,0x05,0x03,0x2f,0x04,0x01,0x01,0x26,0x04,0x00,
0x03,0x25,0x00,0x06,0x01,0x04,0x01,0x25,0x00,0x53,0x1d,0x04,0x02,0x01,0x05,0x03,0x2f,0x04,0x01,0x01,
0x26,0x04,0x00,0x03,0x25,0x00,0x25,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x42,0x04,0x27,0x04,0x00,0x0a,
0x1d,0x05,0x03,0x51,0x06,0x00,0x2d,0x04,0x04,0x02,0x11,0x05,0x01,0x06,0x01,0x49,0x05,0x2d,0x04,0x05,
0x0f,0x25,0x00,0x1d,0x1d,0x05,0x06,0x51,0x06,0x01,0x01,0x07,0x01,0x2f,0x07,0x07,0x00,0x52,0x06,0x51,
0x07,0x02,0x52,0x06,0x2d,0x04,0x04,0x02,0x25,0x00,0x02,0x11,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_132, 2, (MRB_SYM(name), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_132 = {
  3,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_132,
  gem_mrblib_mruby_io_proc_pool_132,gem_mrblib_mruby_io_proc_syms_132,NULL,
  gem_mrblib_mruby_io_proc_lv_132,
  NULL,					/* debug_info */
  115,3,8,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_133[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_133, 3, (MRB_SYM(SEPARATOR), MRB_SYM(File), MRB_OPSYM(neq), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_133[184] = {
0x34,0x04,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x23,0x04,0x01,0x03,0x04,0x01,0x04,0x03,0x06,
0x05,0x23,0x04,0x1d,0x05,0x01,0x1f,0x05,0x00,0x42,0x04,0x27,0x04,0x00,0x0f,0x01,0x04,0x03,0x05,0x05,
0x23,0x04,0x1d,0x05,0x01,0x1f,0x05,0x00,0x42,0x04,0x27,0x04,0x00,0x12,0x01,0x04,0x03,0x07,0x05,0x04,
0x06,0x02,0x59,0x05,0x23,0x04,0x01,0x03,0x04,0x25,0x00,0x46,0x01,0x04,0x03,0x06,0x05,0x23,0x04,0x1d,
0x05,0x01,0x1f,0x05,0x00,0x42,0x04,0x27,0x04,0x00,0x11,0x01,0x04,0x03,0x07,0x05,0x05,0x06,0x59,0x05,
0x23,0x04,0x01,0x03,0x04,0x25,0x00,0x22,0x01,0x04,0x03,0x05,0x05,0x23,0x04,0x1d,0x05,0x01,0x1f,0x05,
0x00,0x42,0x04,0x27,0x04,0x00,0x0f,0x01,0x04,0x03,0x06,0x05,0x04,0x06,0x02,0x59,0x05,0x23,0x04,0x01,
0x03,0x04,0x01,0x04,0x03,0x51,0x05,0x00,0x2f,0x04,0x02,0x01,0x27,0x04,0x00,0x18,0x21,0x04,0x03,0x00,
0x1d,0x05,0x01,0x1f,0x05,0x00,0x01,0x06,0x03,0x3c,0x05,0x3c,0x04,0x22,0x04,0x03,0x00,0x25,0x00,0x02,
0x11,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_133, 3, (MRB_SYM(i), 0,MRB_SYM(t), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_133 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_133,
  gem_mrblib_mruby_io_proc_pool_133,gem_mrblib_mruby_io_proc_syms_133,NULL,
  gem_mrblib_mruby_io_proc_lv_133,
  NULL,					/* debug_info */
  184,1,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_11[2] = {
  &gem_mrblib_mruby_io_proc_irep_132,
  &gem_mrblib_mruby_io_proc_irep_133,
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_11[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_11, 7, (MRB_SYM_Q(empty), MRB_SYM_B(map), MRB_SYM(size), MRB_SYM(SEPARATOR), MRB_SYM(File), MRB_SYM(dup), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_11[216] = {
0x34,0x00,0x10,0x00,0x01,0x04,0x01,0x2f,0x04,0x00,0x00,0x27,0x04,0x00,0x05,0x51,0x04,0x00,0x38,0x04,
0x01,0x04,0x01,0x57,0x05,0x00,0x30,0x04,0x01,0x00,0x01,0x04,0x01,0x2f,0x04,0x02,0x00,0x07,0x05,0x42,
0x04,0x27,0x04,0x00,0x09,0x01,0x04,0x01,0x06,0x05,0x23,0x04,0x38,0x04,0x01,0x04,0x01,0x06,0x05,0x23,
0x04,0x05,0x05,0x23,0x04,0x1d,0x05,0x04,0x1f,0x05,0x03,0x42,0x04,0x27,0x04,0x00,0x16,0x01,0x04,0x01,
0x06,0x05,0x23,0x04,0x06,0x05,0x04,0x06,0x02,0x59,0x05,0x23,0x04,0x01,0x03,0x04,0x25,0x00,0x0e,0x01,
0x04,0x01,0x06,0x05,0x23,0x04,0x2f,0x04,0x05,0x00,0x01,0x03,0x04,0x07,0x04,0x01,0x05,0x01,0x2f,0x05,
0x02,0x00,0x3f,0x05,0x02,0x59,0x04,0x57,0x05,0x01,0x30,0x04,0x06,0x00,0x01,0x04,0x01,0x05,0x05,0x23,
0x04,0x06,0x05,0x23,0x04,0x1d,0x05,0x04,0x1f,0x05,0x03,0x42,0x04,0x27,0x04,0x00,0x22,0x01,0x04,0x03,
0x1d,0x05,0x04,0x1f,0x05,0x03,0x01,0x06,0x01,0x05,0x07,0x23,0x06,0x07,0x07,0x05,0x08,0x59,0x07,0x23,
0x06,0x3c,0x05,0x3c,0x04,0x01,0x03,0x04,0x25,0x00,0x17,0x01,0x04,0x03,0x1d,0x05,0x04,0x1f,0x05,0x03,
0x01,0x06,0x01,0x05,0x07,0x23,0x06,0x3c,0x05,0x3c,0x04,0x01,0x03,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_11, 3, (MRB_SYM(names), 0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_11 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_11,
  gem_mrblib_mruby_io_proc_pool_11,gem_mrblib_mruby_io_proc_syms_11,gem_mrblib_mruby_io_proc_reps_11,
  gem_mrblib_mruby_io_proc_lv_11,
  NULL,					/* debug_info */
  216,1,7,2,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_12[6] = {
{IREP_TT_STR|(1<<2), {"\x2f"}},
{IREP_TT_STR|(1<<2), {"\x3a"}},
{IREP_TT_STR|(1<<2), {"\x7e"}},
{IREP_TT_STR|(47<<2), {"\x63\x6f\x75\x6c\x64\x6e\x27\x74\x20\x66\x69\x6e\x64\x20\x48\x4f\x4d\x45\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x20\x2d\x2d\x20\x65\x78\x70\x61\x6e\x64\x69\x6e\x67\x20\x27\x7e\x27"}},
{IREP_TT_STR|(5<<2), {"\x75\x73\x65\x72\x20"}},
{IREP_TT_STR|(14<<2), {"\x20\x64\x6f\x65\x73\x6e\x27\x74\x20\x65\x78\x69\x73\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_12, 9, (MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(_gethome), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(split), MRB_SYM(join), MRB_SYM(_getwd), MRB_SYM(_concat_path), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_12[342] = {
0x34,0x08,0x00,0x00,0x01,0x09,0x01,0x06,0x0a,0x23,0x09,0x51,0x0a,0x00,0x42,0x09,0x26,0x09,0x00,0x0c,
0x01,0x09,0x01,0x07,0x0a,0x23,0x09,0x51,0x0a,0x01,0x42,0x09,0x27,0x09,0x00,0x06,0x01,0x04,0x01,0x25,
0x01,0x2a,0x01,0x09,0x01,0x06,0x0a,0x23,0x09,0x51,0x0a,0x02,0x42,0x09,0x27,0x09,0x00,0xfc,0x01,0x09,
0x01,0x07,0x0a,0x23,0x09,0x51,0x0a,0x00,0x42,0x09,0x26,0x09,0x00,0x0b,0x01,0x09,0x01,0x07,0x0a,0x23,
0x09,0x11,0x0a,0x42,0x09,0x27,0x09,0x00,0x4e,0x01,0x09,0x01,0x07,0x0a,0x01,0x0b,0x01,0x2f,0x0b,0x00,
0x00,0x2f,0x09,0x01,0x02,0x01,0x05,0x09,0x2d,0x09,0x02,0x00,0x01,0x06,0x09,0x01,0x09,0x06,0x26,0x09,
0x00,0x0a,0x1d,0x0a,0x03,0x51,0x0b,0x03,0x2d,0x09,0x04,0x02,0x01,0x04,0x06,0x01,0x09,0x05,0x27,0x09,
0x00,0x0b,0x01,0x09,0x04,0x01,0x0a,0x05,0x3c,0x09,0x01,0x04,0x09,0x01,0x09,0x04,0x51,0x0a,0x00,0x3c,
0x09,0x01,0x04,0x09,0x25,0x00,0x8c,0x01,0x09,0x01,0x51,0x0a,0x00,0x2f,0x09,0x05,0x01,0x01,0x07,0x09,
0x01,0x09,0x07,0x06,0x0a,0x23,0x09,0x07,0x0a,0x01,0x0b,0x07,0x06,0x0c,0x23,0x0b,0x2f,0x0b,0x00,0x00,
0x2f,0x09,0x01,0x02,0x01,0x08,0x09,0x51,0x09,0x00,0x01,0x0a,0x07,0x07,0x0b,0x01,0x0c,0x07,0x2f,0x0c,
0x00,0x00,0x2f,0x0a,0x01,0x02,0x51,0x0b,0x00,0x2f,0x0a,0x06,0x01,0x3c,0x09,0x01,0x05,0x09,0x01,0x0a,
0x08,0x2d,0x09,0x02,0x01,0x01,0x06,0x09,0x01,0x09,0x06,0x26,0x09,0x00,0x14,0x1d,0x0a,0x03,0x51,0x0b,
0x04,0x01,0x0c,0x08,0x52,0x0b,0x51,0x0c,0x05,0x52,0x0b,0x2d,0x09,0x04,0x02,0x01,0x04,0x06,0x01,0x09,
0x05,0x27,0x09,0x00,0x0b,0x01,0x09,0x04,0x01,0x0a,0x05,0x3c,0x09,0x01,0x04,0x09,0x01,0x09,0x04,0x51,
0x0a,0x00,0x3c,0x09,0x01,0x04,0x09,0x25,0x00,0x1e,0x01,0x0a,0x02,0x2d,0x0b,0x07,0x00,0x2d,0x09,0x08,
0x02,0x01,0x04,0x09,0x01,0x09,0x04,0x51,0x0a,0x00,0x01,0x0b,0x01,0x3c,0x0a,0x3c,0x09,0x01,0x04,0x09,
0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_12, 8, (MRB_SYM(path), MRB_SYM(base_path), 0,MRB_SYM(expanded_path), MRB_SYM(dir), MRB_SYM(home_dir), MRB_SYM(splitted_path), MRB_SYM(user), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_12 = {
  9,14,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_12,
  gem_mrblib_mruby_io_proc_pool_12,gem_mrblib_mruby_io_proc_syms_12,NULL,
  gem_mrblib_mruby_io_proc_lv_12,
  NULL,					/* debug_info */
  342,6,9,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_178[2] = {
{IREP_TT_STR|(2<<2), {"\x2e\x2e"}},
{IREP_TT_STR|(1<<2), {"\x2e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_178, 3, (MRB_SYM(size), MRB_SYM(pop), MRB_OPSYM(lshift), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_178[78] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x51,0x04,0x00,0x42,0x03,0x27,0x03,0x00,0x20,0x21,0x03,0x06,0x00,
0x2f,0x03,0x00,0x00,0x07,0x04,0x45,0x03,0x27,0x03,0x00,0x0b,0x21,0x03,0x06,0x00,0x2f,0x03,0x01,0x00,
0x25,0x00,0x02,0x11,0x03,0x25,0x00,0x1c,0x01,0x03,0x01,0x51,0x04,0x01,0x42,0x03,0x27,0x03,0x00,0x05,
0x11,0x03,0x25,0x00,0x0b,0x21,0x03,0x06,0x00,0x01,0x04,0x01,0x2f,0x03,0x02,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_178, 2, (MRB_SYM(path_token), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_178 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_178,
  gem_mrblib_mruby_io_proc_pool_178,gem_mrblib_mruby_io_proc_syms_178,NULL,
  gem_mrblib_mruby_io_proc_lv_178,
  NULL,					/* debug_info */
  78,2,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_13[1] = {
  &gem_mrblib_mruby_io_proc_irep_178,
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_13[7] = {
{IREP_TT_STR|(1<<2), {"\x2e"}},
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(1<<2), {"\x41"}},
{IREP_TT_STR|(1<<2), {"\x5a"}},
{IREP_TT_STR|(1<<2), {"\x3a"}},
{IREP_TT_STR|(1<<2), {"\x2f"}},
{IREP_TT_STR|(2<<2), {"\x2f\x2f"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_13, 14, (MRB_SYM(_concat_path), MRB_SYM(ALT_SEPARATOR), MRB_SYM(File), MRB_SYM(size), MRB_SYM(upcase), MRB_SYM_Q(include), MRB_OPSYM(aref), MRB_SYM_B(gsub), MRB_SYM(gsub), MRB_OPSYM(neq), MRB_SYM(split), MRB_SYM(each), MRB_SYM(join), MRB_SYM_Q(empty), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_13[307] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x03,0x51,0x02,0x00,0x01,0x08,0x01,0x01,0x09,0x02,0x2d,
0x07,0x00,0x02,0x01,0x04,0x07,0x51,0x05,0x01,0x1d,0x07,0x02,0x1f,0x07,0x01,0x27,0x07,0x00,0x0b,0x01,
0x07,0x04,0x2f,0x07,0x03,0x00,0x08,0x08,0x45,0x07,0x27,0x07,0x00,0x17,0x51,0x07,0x02,0x51,0x08,0x03,
0x59,0x07,0x01,0x08,0x04,0x06,0x09,0x23,0x08,0x2f,0x08,0x04,0x00,0x2f,0x07,0x05,0x01,0x27,0x07,0x00,
0x0c,0x01,0x07,0x04,0x07,0x08,0x23,0x07,0x51,0x08,0x04,0x42,0x07,0x27,0x07,0x00,0x21,0x01,0x07,0x04,
0x06,0x08,0x08,0x09,0x2f,0x07,0x06,0x02,0x01,0x05,0x07,0x01,0x07,0x04,0x08,0x08,0x01,0x09,0x04,0x2f,
0x09,0x03,0x00,0x2f,0x07,0x06,0x02,0x01,0x04,0x07,0x47,0x06,0x00,0x1d,0x07,0x02,0x1f,0x07,0x01,0x27,
0x07,0x00,0x0d,0x01,0x07,0x04,0x1d,0x08,0x02,0x1f,0x08,0x01,0x2f,0x07,0x05,0x01,0x27,0x07,0x00,0x10,
0x01,0x07,0x04,0x1d,0x08,0x02,0x1f,0x08,0x01,0x51,0x09,0x05,0x2f,0x07,0x07,0x02,0x01,0x07,0x04,0x51,
0x08,0x06,0x2f,0x07,0x05,0x01,0x27,0x07,0x00,0x13,0x01,0x07,0x04,0x51,0x08,0x06,0x51,0x09,0x05,0x2f,
0x07,0x08,0x02,0x01,0x04,0x07,0x25,0xff,0xdf,0x01,0x07,0x04,0x51,0x08,0x05,0x2f,0x07,0x09,0x01,0x27,
0x07,0x00,0x2c,0x01,0x07,0x04,0x51,0x08,0x05,0x2f,0x07,0x0a,0x01,0x57,0x08,0x00,0x30,0x07,0x0b,0x00,
0x01,0x07,0x06,0x51,0x08,0x05,0x2f,0x07,0x0c,0x01,0x01,0x04,0x07,0x01,0x07,0x04,0x2f,0x07,0x0d,0x00,
0x27,0x07,0x00,0x03,0x51,0x04,0x05,0x01,0x07,0x05,0x2f,0x07,0x0d,0x00,0x27,0x07,0x00,0x06,0x01,0x07,
0x04,0x25,0x00,0x15,0x01,0x07,0x05,0x01,0x08,0x04,0x51,0x09,0x05,0x1d,0x0a,0x02,0x1f,0x0a,0x01,0x2f,
0x08,0x08,0x02,0x3c,0x07,0x38,0x07,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_13, 6, (MRB_SYM(path), MRB_SYM(default_dir), 0,MRB_SYM(expanded_path), MRB_SYM(drive_prefix), MRB_SYM(expand_path_array), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_13 = {
  7,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_13,
  gem_mrblib_mruby_io_proc_pool_13,gem_mrblib_mruby_io_proc_syms_13,gem_mrblib_mruby_io_proc_reps_13,
  gem_mrblib_mruby_io_proc_lv_13,
  NULL,					/* debug_info */
  307,7,14,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_201, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_201[17] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x3b,0x03,0x08,0x02,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_201, 2, (MRB_SYM(l), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_201 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_201,
  NULL,gem_mrblib_mruby_io_proc_syms_201,NULL,
  gem_mrblib_mruby_io_proc_lv_201,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_200[1] = {
  &gem_mrblib_mruby_io_proc_irep_201,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_200, 1, (MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_200[16] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x00,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_200, 2, (MRB_SYM(f), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_200 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_200,
  NULL,gem_mrblib_mruby_io_proc_syms_200,gem_mrblib_mruby_io_proc_reps_200,
  gem_mrblib_mruby_io_proc_lv_200,
  NULL,					/* debug_info */
  16,0,1,1,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_14[1] = {
  &gem_mrblib_mruby_io_proc_irep_200,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_14, 3, (MRB_SYM_Q(block_given), MRB_SYM(open), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_14[40] = {
0x34,0x04,0x00,0x00,0x2d,0x03,0x00,0x00,0x27,0x03,0x00,0x0f,0x12,0x03,0x01,0x04,0x01,0x57,0x05,0x00,
0x30,0x03,0x01,0x01,0x25,0x00,0x0b,0x12,0x03,0x01,0x04,0x01,0x2f,0x03,0x02,0x01,0x38,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_14, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_14 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_14,
  NULL,gem_mrblib_mruby_io_proc_syms_14,gem_mrblib_mruby_io_proc_reps_14,
  gem_mrblib_mruby_io_proc_lv_14,
  NULL,					/* debug_info */
  40,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_15, 2, (MRB_SYM(FileTest), MRB_SYM_Q(directory), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_15[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_15, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_15 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_15,
  NULL,gem_mrblib_mruby_io_proc_syms_15,NULL,
  gem_mrblib_mruby_io_proc_lv_15,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_16, 2, (MRB_SYM(FileTest), MRB_SYM_Q(exist), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_16[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_16, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_16 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_16,
  NULL,gem_mrblib_mruby_io_proc_syms_16,NULL,
  gem_mrblib_mruby_io_proc_lv_16,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_17, 2, (MRB_SYM(FileTest), MRB_SYM_Q(exists), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_17[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_17, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_17 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_17,
  NULL,gem_mrblib_mruby_io_proc_syms_17,NULL,
  gem_mrblib_mruby_io_proc_lv_17,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_18, 2, (MRB_SYM(FileTest), MRB_SYM_Q(file), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_18[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_18, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_18 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_18,
  NULL,gem_mrblib_mruby_io_proc_syms_18,NULL,
  gem_mrblib_mruby_io_proc_lv_18,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_19, 2, (MRB_SYM(FileTest), MRB_SYM_Q(pipe), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_19[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_19, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_19 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_19,
  NULL,gem_mrblib_mruby_io_proc_syms_19,NULL,
  gem_mrblib_mruby_io_proc_lv_19,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_20, 2, (MRB_SYM(FileTest), MRB_SYM(size), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_20[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_20, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_20 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_20,
  NULL,gem_mrblib_mruby_io_proc_syms_20,NULL,
  gem_mrblib_mruby_io_proc_lv_20,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_21, 2, (MRB_SYM(FileTest), MRB_SYM_Q(size), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_21[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_21, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_21 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_21,
  NULL,gem_mrblib_mruby_io_proc_syms_21,NULL,
  gem_mrblib_mruby_io_proc_lv_21,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_22, 2, (MRB_SYM(FileTest), MRB_SYM_Q(socket), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_22[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_22, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_22 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_22,
  NULL,gem_mrblib_mruby_io_proc_syms_22,NULL,
  gem_mrblib_mruby_io_proc_lv_22,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_23, 2, (MRB_SYM(FileTest), MRB_SYM_Q(symlink), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_23[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_23, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_23 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_23,
  NULL,gem_mrblib_mruby_io_proc_syms_23,NULL,
  gem_mrblib_mruby_io_proc_lv_23,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_24, 2, (MRB_SYM(FileTest), MRB_SYM_Q(zero), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_24[16] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_24, 2, (MRB_SYM(file), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_24 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_24,
  NULL,gem_mrblib_mruby_io_proc_syms_24,NULL,
  gem_mrblib_mruby_io_proc_lv_24,
  NULL,					/* debug_info */
  16,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_25[2] = {
{IREP_TT_STR|(1<<2), {"\x2e"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_25, 3, (MRB_SYM(basename), MRB_SYM(rindex), MRB_SYM_Q(nil), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_25[70] = {
0x34,0x04,0x00,0x00,0x12,0x05,0x01,0x06,0x01,0x2f,0x05,0x00,0x01,0x01,0x03,0x05,0x01,0x05,0x03,0x51,
0x06,0x00,0x2f,0x05,0x01,0x01,0x01,0x04,0x05,0x01,0x05,0x04,0x06,0x06,0x42,0x05,0x26,0x05,0x00,0x07,
0x01,0x05,0x04,0x2f,0x05,0x02,0x00,0x27,0x05,0x00,0x05,0x51,0x05,0x01,0x38,0x05,0x01,0x05,0x03,0x01,
0x06,0x04,0x05,0x07,0x59,0x06,0x23,0x05,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_25, 4, (MRB_SYM(filename), 0,MRB_SYM(fname), MRB_SYM(epos), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_25 = {
  5,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_25,
  gem_mrblib_mruby_io_proc_pool_25,gem_mrblib_mruby_io_proc_syms_25,NULL,
  gem_mrblib_mruby_io_proc_lv_25,
  NULL,					/* debug_info */
  70,2,3,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_26[2] = {
{IREP_TT_STR|(26<<2), {"\x6e\x6f\x20\x69\x6d\x70\x6c\x69\x63\x69\x74\x20\x63\x6f\x6e\x76\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20"}},
{IREP_TT_STR|(12<<2), {"\x20\x69\x6e\x74\x6f\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_26, 5, (MRB_SYM(String), MRB_SYM_Q(kind_of), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_26[50] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x27,0x03,0x00,0x06,0x01,0x03,
0x01,0x25,0x00,0x18,0x1d,0x04,0x02,0x51,0x05,0x00,0x01,0x06,0x01,0x2f,0x06,0x03,0x00,0x52,0x05,0x51,
0x06,0x01,0x52,0x05,0x2d,0x03,0x04,0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_26, 2, (MRB_SYM(filename), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_26 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_26,
  gem_mrblib_mruby_io_proc_pool_26,gem_mrblib_mruby_io_proc_syms_26,NULL,
  gem_mrblib_mruby_io_proc_lv_26,
  NULL,					/* debug_info */
  50,2,5,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_1[21] = {
  &gem_mrblib_mruby_io_proc_irep_6,
  &gem_mrblib_mruby_io_proc_irep_7,
  &gem_mrblib_mruby_io_proc_irep_8,
  &gem_mrblib_mruby_io_proc_irep_9,
  &gem_mrblib_mruby_io_proc_irep_10,
  &gem_mrblib_mruby_io_proc_irep_11,
  &gem_mrblib_mruby_io_proc_irep_12,
  &gem_mrblib_mruby_io_proc_irep_13,
  &gem_mrblib_mruby_io_proc_irep_14,
  &gem_mrblib_mruby_io_proc_irep_15,
  &gem_mrblib_mruby_io_proc_irep_16,
  &gem_mrblib_mruby_io_proc_irep_17,
  &gem_mrblib_mruby_io_proc_irep_18,
  &gem_mrblib_mruby_io_proc_irep_19,
  &gem_mrblib_mruby_io_proc_irep_20,
  &gem_mrblib_mruby_io_proc_irep_21,
  &gem_mrblib_mruby_io_proc_irep_22,
  &gem_mrblib_mruby_io_proc_irep_23,
  &gem_mrblib_mruby_io_proc_irep_24,
  &gem_mrblib_mruby_io_proc_irep_25,
  &gem_mrblib_mruby_io_proc_irep_26,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1, 22, (MRB_SYM(path), MRB_SYM(attr_accessor), MRB_SYM(initialize), MRB_SYM(atime), MRB_SYM(ctime), MRB_SYM(mtime), MRB_SYM(inspect), MRB_SYM(join), MRB_SYM(_concat_path), MRB_SYM(expand_path), MRB_SYM(foreach), MRB_SYM_Q(directory), MRB_SYM_Q(exist), MRB_SYM_Q(exists), MRB_SYM_Q(file), MRB_SYM_Q(pipe), MRB_SYM(size), MRB_SYM_Q(size), MRB_SYM_Q(socket), MRB_SYM_Q(symlink), MRB_SYM_Q(zero), MRB_SYM(extname), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1[209] = {
0x10,0x02,0x00,0x2d,0x01,0x01,0x01,0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x01,
0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x02,0x5f,0x01,0x04,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x05,0x63,
0x01,0x58,0x02,0x04,0x5f,0x01,0x06,0x12,0x01,0x62,0x01,0x58,0x02,0x05,0x5f,0x01,0x07,0x12,0x01,0x62,
0x01,0x58,0x02,0x06,0x5f,0x01,0x08,0x12,0x01,0x62,0x01,0x58,0x02,0x07,0x5f,0x01,0x09,0x12,0x01,0x62,
0x01,0x58,0x02,0x08,0x5f,0x01,0x0a,0x12,0x01,0x62,0x01,0x58,0x02,0x09,0x5f,0x01,0x0b,0x12,0x01,0x62,
0x01,0x58,0x02,0x0a,0x5f,0x01,0x0c,0x12,0x01,0x62,0x01,0x58,0x02,0x0b,0x5f,0x01,0x0d,0x12,0x01,0x62,
0x01,0x58,0x02,0x0c,0x5f,0x01,0x0e,0x12,0x01,0x62,0x01,0x58,0x02,0x0d,0x5f,0x01,0x0f,0x12,0x01,0x62,
0x01,0x58,0x02,0x0e,0x5f,0x01,0x10,0x12,0x01,0x62,0x01,0x58,0x02,0x0f,0x5f,0x01,0x11,0x12,0x01,0x62,
0x01,0x58,0x02,0x10,0x5f,0x01,0x12,0x12,0x01,0x62,0x01,0x58,0x02,0x11,0x5f,0x01,0x13,0x12,0x01,0x62,
0x01,0x58,0x02,0x12,0x5f,0x01,0x14,0x12,0x01,0x62,0x01,0x58,0x02,0x13,0x5f,0x01,0x15,0x12,0x01,0x62,
0x01,0x58,0x02,0x14,0x5f,0x01,0x00,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1,
  NULL,gem_mrblib_mruby_io_proc_syms_1,gem_mrblib_mruby_io_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  209,0,22,21,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_459, 5, (MRB_SYM(FNM_SYSCASE), MRB_SYM(FNM_NOESCAPE), MRB_SYM(FNM_PATHNAME), MRB_SYM(FNM_DOTMATCH), MRB_SYM(FNM_CASEFOLD), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_459[28] = {
0x06,0x01,0x1e,0x01,0x00,0x07,0x01,0x1e,0x01,0x01,0x08,0x01,0x1e,0x01,0x02,0x0a,0x01,0x1e,0x01,0x03,
0x03,0x01,0x08,0x1e,0x01,0x04,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_459 = {
  1,2,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_459,
  NULL,gem_mrblib_mruby_io_proc_syms_459,NULL,
  NULL,					/* lv */
  NULL,					/* debug_info */
  28,0,5,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_2[1] = {
  &gem_mrblib_mruby_io_proc_irep_459,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_2, 1, (MRB_SYM(Constants), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_2[10] = {
0x11,0x01,0x5d,0x01,0x00,0x5e,0x01,0x00,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_2 = {
  1,2,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_2,
  NULL,gem_mrblib_mruby_io_proc_syms_2,gem_mrblib_mruby_io_proc_reps_2,
  NULL,					/* lv */
  NULL,					/* debug_info */
  10,0,1,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_3, 3, (MRB_SYM(Constants), MRB_SYM(File), MRB_SYM(include), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_3[12] = {
0x1d,0x02,0x01,0x1f,0x02,0x00,0x2d,0x01,0x02,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_3 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_3,
  NULL,gem_mrblib_mruby_io_proc_syms_3,NULL,
  NULL,					/* lv */
  NULL,					/* debug_info */
  12,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_470, 5, (MRB_SYM(new), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), MRB_SYM(StandardError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_470[118] = {
0x34,0x00,0x10,0x01,0x12,0x04,0x11,0x05,0x01,0x06,0x01,0x49,0x05,0x2f,0x04,0x00,0x0f,0x01,0x03,0x04,
0x01,0x04,0x02,0x26,0x04,0x00,0x02,0x38,0x03,0x01,0x05,0x03,0x3b,0x04,0x04,0x00,0x2f,0x04,0x01,0x01,
0x2a,0x06,0x01,0x07,0x03,0x2f,0x07,0x02,0x00,0x27,0x07,0x00,0x05,0x11,0x07,0x25,0x00,0x07,0x01,0x07,
0x03,0x2f,0x07,0x03,0x00,0x25,0x00,0x14,0x2a,0x07,0x1d,0x08,0x04,0x2b,0x07,0x08,0x26,0x08,0x00,0x03,
0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x07,0x2c,0x06,0x38,0x04,0x01,0x00,0x00,0x00,0x1d,0x00,0x00,0x00,
0x28,0x00,0x00,0x00,0x28,0x00,0x00,0x00,0x00,0x2a,0x00,0x00,0x00,0x41,0x00,0x00,0x00,0x44,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_470, 3, (MRB_SYM(args), MRB_SYM(block), MRB_SYM(io), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_470 = {
  4,9,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_470,
  NULL,gem_mrblib_mruby_io_proc_syms_470,NULL,
  gem_mrblib_mruby_io_proc_lv_470,
  NULL,					/* debug_info */
  92,0,5,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_471[2] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
{IREP_TT_STR|(39<<2), {"\x70\x6f\x70\x65\x6e\x20\x69\x73\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64\x20\x6f\x6e\x20\x74\x68\x69\x73\x20\x70\x6c\x61\x74\x66\x6f\x72\x6d"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_471, 9, (MRB_SYM(_popen), MRB_SYM_Q(respond_to), MRB_OPSYM(not), MRB_SYM(NotImplementedError), MRB_SYM(raise), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), MRB_SYM(IOError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_471[161] = {
0x34,0x04,0x20,0x03,0x25,0x00,0x03,0x25,0x00,0x03,0x51,0x02,0x00,0x12,0x06,0x10,0x07,0x00,0x2f,0x06,
0x01,0x01,0x2f,0x06,0x02,0x00,0x27,0x06,0x00,0x0a,0x1d,0x07,0x03,0x51,0x08,0x01,0x2d,0x06,0x04,0x02,
0x12,0x06,0x01,0x07,0x01,0x01,0x08,0x02,0x53,0x09,0x00,0x01,0x0a,0x03,0x55,0x09,0x2f,0x06,0x00,0xf2,
0x01,0x05,0x06,0x01,0x06,0x04,0x26,0x06,0x00,0x02,0x38,0x05,0x01,0x07,0x05,0x3b,0x06,0x10,0x10,0x2f,
0x06,0x05,0x01,0x2a,0x08,0x01,0x09,0x05,0x2f,0x09,0x06,0x00,0x27,0x09,0x00,0x05,0x11,0x09,0x25,0x00,
0x07,0x01,0x09,0x05,0x2f,0x09,0x07,0x00,0x25,0x00,0x14,0x2a,0x09,0x1d,0x0a,0x08,0x2b,0x09,0x0a,0x26,
0x0a,0x00,0x03,0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x09,0x2c,0x08,0x38,0x06,0x01,0x00,0x00,0x00,0x48,
0x00,0x00,0x00,0x53,0x00,0x00,0x00,0x53,0x00,0x00,0x00,0x00,0x55,0x00,0x00,0x00,0x6c,0x00,0x00,0x00,
0x6f,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_471, 5, (MRB_SYM(command), MRB_SYM(mode), MRB_SYM(opts), MRB_SYM(block), MRB_SYM(io), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_471 = {
  6,11,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_471,
  gem_mrblib_mruby_io_proc_pool_471,gem_mrblib_mruby_io_proc_syms_471,NULL,
  gem_mrblib_mruby_io_proc_lv_471,
  NULL,					/* debug_info */
  135,2,9,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_472[1] = {
{IREP_TT_STR|(38<<2), {"\x70\x69\x70\x65\x20\x69\x73\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64\x20\x6f\x6e\x20\x74\x68\x69\x73\x20\x70\x6c\x61\x74\x66\x6f\x72\x6d"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_472, 9, (MRB_SYM(_pipe), MRB_SYM_Q(respond_to), MRB_OPSYM(not), MRB_SYM(NotImplementedError), MRB_SYM(raise), MRB_SYM(IO), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_472[132] = {
0x34,0x00,0x00,0x01,0x12,0x04,0x10,0x05,0x00,0x2f,0x04,0x01,0x01,0x2f,0x04,0x02,0x00,0x27,0x04,0x00,
0x0a,0x1d,0x05,0x03,0x51,0x06,0x00,0x2d,0x04,0x04,0x02,0x01,0x04,0x01,0x27,0x04,0x00,0x48,0x1d,0x04,
0x05,0x2f,0x04,0x00,0x00,0x4c,0x02,0x04,0x00,0x4c,0x03,0x04,0x01,0x01,0x05,0x02,0x01,0x06,0x03,0x3b,
0x04,0x00,0x00,0x2f,0x04,0x06,0x02,0x2a,0x06,0x01,0x07,0x02,0x2f,0x07,0x07,0x00,0x26,0x07,0x00,0x07,
0x01,0x07,0x02,0x2f,0x07,0x08,0x00,0x01,0x07,0x03,0x2f,0x07,0x07,0x00,0x26,0x07,0x00,0x07,0x01,0x07,
0x03,0x2f,0x07,0x08,0x00,0x2c,0x06,0x25,0x00,0x07,0x1d,0x04,0x05,0x2f,0x04,0x00,0x00,0x38,0x04,0x01,
0x00,0x00,0x00,0x26,0x00,0x00,0x00,0x43,0x00,0x00,0x00,0x43,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_472, 3, (MRB_SYM(block), MRB_SYM(r), MRB_SYM(w), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_472 = {
  4,9,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_472,
  gem_mrblib_mruby_io_proc_pool_472,gem_mrblib_mruby_io_proc_syms_472,NULL,
  gem_mrblib_mruby_io_proc_lv_472,
  NULL,					/* debug_info */
  119,1,9,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_473[2] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_473, 9, (MRB_SYM(mode), MRB_SYM(IO), MRB_SYM(sysopen), MRB_SYM(open), MRB_SYM(seek), MRB_SYM(read), MRB_SYM(close), MRB_OPSYM(neq), MRB_SYM(_sysclose), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_473[163] = {
0x34,0x04,0x40,0x04,0x25,0x00,0x06,0x25,0x00,0x05,0x25,0x00,0x04,0x11,0x02,0x06,0x03,0x35,0x06,0x00,
0x26,0x06,0x00,0x06,0x51,0x06,0x00,0x25,0x00,0x03,0x37,0x06,0x00,0x36,0x51,0x07,0x01,0x05,0x08,0x11,
0x09,0x1d,0x0a,0x01,0x01,0x0b,0x01,0x01,0x0c,0x06,0x2f,0x0a,0x02,0x02,0x01,0x08,0x0a,0x1d,0x0a,0x01,
0x01,0x0b,0x08,0x01,0x0c,0x06,0x2f,0x0a,0x03,0x02,0x01,0x09,0x0a,0x01,0x0a,0x03,0x06,0x0b,0x45,0x0a,
0x27,0x0a,0x00,0x0a,0x01,0x0a,0x09,0x01,0x0b,0x03,0x2f,0x0a,0x04,0x01,0x01,0x0a,0x09,0x01,0x0b,0x02,
0x2f,0x0a,0x05,0x01,0x01,0x07,0x0a,0x2a,0x0b,0x27,0x09,0x00,0x0a,0x01,0x0c,0x09,0x2f,0x0c,0x06,0x00,
0x25,0x00,0x17,0x01,0x0c,0x08,0x05,0x0d,0x2f,0x0c,0x07,0x01,0x27,0x0c,0x00,0x0a,0x1d,0x0c,0x01,0x01,
0x0d,0x08,0x2f,0x0c,0x08,0x01,0x2c,0x0b,0x38,0x07,0x01,0x00,0x00,0x00,0x29,0x00,0x00,0x00,0x6b,0x00,
0x00,0x00,0x6b,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_473, 9, (MRB_SYM(path), MRB_SYM(length), MRB_SYM(offset), MRB_OPSYM(pow), 0,MRB_SYM(mode), MRB_SYM(str), MRB_SYM(fd), MRB_SYM(io), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_473 = {
  10,15,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_473,
  gem_mrblib_mruby_io_proc_pool_473,gem_mrblib_mruby_io_proc_syms_473,NULL,
  gem_mrblib_mruby_io_proc_lv_473,
  NULL,					/* debug_info */
  150,2,9,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_474, 1, (MRB_SYM(__id__), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_474[12] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x2f,0x02,0x00,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_474, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_474 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_474,
  NULL,gem_mrblib_mruby_io_proc_syms_474,NULL,
  gem_mrblib_mruby_io_proc_lv_474,
  NULL,					/* debug_info */
  12,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_475, 1, (MRB_SYM(write), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_475[15] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_475, 2, (MRB_SYM(str), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_475 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_475,
  NULL,gem_mrblib_mruby_io_proc_syms_475,NULL,
  gem_mrblib_mruby_io_proc_lv_475,
  NULL,					/* debug_info */
  15,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_476, 2, (MRB_SYM(SEEK_SET), MRB_SYM(seek), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_476[16] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x1d,0x05,0x00,0x2d,0x03,0x01,0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_476, 2, (MRB_SYM(i), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_476 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_476,
  NULL,gem_mrblib_mruby_io_proc_syms_476,NULL,
  gem_mrblib_mruby_io_proc_lv_476,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_477, 2, (MRB_SYM(SEEK_SET), MRB_SYM(seek), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_477[15] = {
0x34,0x00,0x00,0x00,0x06,0x03,0x1d,0x04,0x00,0x2d,0x02,0x01,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_477, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_477 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_477,
  NULL,gem_mrblib_mruby_io_proc_syms_477,NULL,
  gem_mrblib_mruby_io_proc_lv_477,
  NULL,					/* debug_info */
  15,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_478[1] = {
{IREP_TT_STR|(1<<2), {"\x20"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_478, 6, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(getbyte), MRB_OPSYM(and), MRB_SYM(setbyte), MRB_SYM(ungetc), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_478[70] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x1d,0x05,0x00,0x2f,0x04,0x01,0x01,0x27,0x04,0x00,0x0f,0x01,0x04,
0x01,0x06,0x05,0x2f,0x04,0x02,0x01,0x01,0x01,0x04,0x25,0x00,0x0d,0x01,0x04,0x01,0x03,0x05,0xff,0x2f,
0x04,0x03,0x01,0x01,0x01,0x04,0x51,0x03,0x00,0x01,0x04,0x03,0x06,0x05,0x01,0x06,0x01,0x2f,0x04,0x04,
0x02,0x01,0x05,0x03,0x2d,0x04,0x05,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_478, 3, (MRB_SYM(c), 0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_478 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_478,
  gem_mrblib_mruby_io_proc_pool_478,gem_mrblib_mruby_io_proc_syms_478,NULL,
  gem_mrblib_mruby_io_proc_lv_478,
  NULL,					/* debug_info */
  70,1,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_479, 3, (MRB_SYM(to_enum), MRB_SYM(gets), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_479[47] = {
0x34,0x00,0x00,0x01,0x01,0x03,0x01,0x26,0x03,0x00,0x06,0x2d,0x03,0x00,0x00,0x38,0x03,0x12,0x03,0x2f,
0x03,0x01,0x00,0x01,0x02,0x03,0x27,0x03,0x00,0x0d,0x01,0x03,0x01,0x01,0x04,0x02,0x2f,0x03,0x02,0x01,
0x25,0xff,0xe6,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_479, 2, (MRB_SYM(block), MRB_SYM(line), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_479 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_479,
  NULL,gem_mrblib_mruby_io_proc_syms_479,NULL,
  gem_mrblib_mruby_io_proc_lv_479,
  NULL,					/* debug_info */
  47,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_480, 4, (MRB_SYM(each_byte), MRB_SYM(to_enum), MRB_SYM(getbyte), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_480[50] = {
0x34,0x00,0x00,0x01,0x01,0x03,0x01,0x26,0x03,0x00,0x09,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,0x38,0x03,
0x12,0x03,0x2f,0x03,0x02,0x00,0x01,0x02,0x03,0x27,0x03,0x00,0x0d,0x01,0x03,0x01,0x01,0x04,0x02,0x2f,
0x03,0x03,0x01,0x25,0xff,0xe6,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_480, 2, (MRB_SYM(block), MRB_SYM(byte), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_480 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_480,
  NULL,gem_mrblib_mruby_io_proc_syms_480,NULL,
  gem_mrblib_mruby_io_proc_lv_480,
  NULL,					/* debug_info */
  50,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_481, 4, (MRB_SYM(each_char), MRB_SYM(to_enum), MRB_SYM(getc), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_481[50] = {
0x34,0x00,0x00,0x01,0x01,0x03,0x01,0x26,0x03,0x00,0x09,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,0x38,0x03,
0x12,0x03,0x2f,0x03,0x02,0x00,0x01,0x02,0x03,0x27,0x03,0x00,0x0d,0x01,0x03,0x01,0x01,0x04,0x02,0x2f,
0x03,0x03,0x01,0x25,0xff,0xe6,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_481, 2, (MRB_SYM(block), MRB_SYM(char), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_481 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_481,
  NULL,gem_mrblib_mruby_io_proc_syms_481,NULL,
  gem_mrblib_mruby_io_proc_lv_481,
  NULL,					/* debug_info */
  50,0,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_482[1] = {
{IREP_TT_STR|(1<<2), {"\x0a"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_482, 7, (MRB_SYM(size), MRB_SYM(Array), MRB_SYM_Q(kind_of), MRB_SYM(puts), MRB_SYM(to_s), MRB_SYM(write), MRB_OPSYM(neq), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_482[137] = {
0x34,0x00,0x10,0x00,0x06,0x03,0x01,0x06,0x01,0x2f,0x06,0x00,0x00,0x01,0x04,0x06,0x01,0x06,0x03,0x01,
0x07,0x04,0x43,0x06,0x27,0x06,0x00,0x57,0x01,0x06,0x01,0x01,0x07,0x03,0x23,0x06,0x01,0x05,0x06,0x01,
0x06,0x05,0x1d,0x07,0x01,0x2f,0x06,0x02,0x01,0x27,0x06,0x00,0x0e,0x11,0x07,0x01,0x08,0x05,0x49,0x07,
0x2d,0x06,0x03,0x0f,0x25,0x00,0x2a,0x01,0x06,0x05,0x2f,0x06,0x04,0x00,0x01,0x05,0x06,0x01,0x07,0x05,
0x2d,0x06,0x05,0x01,0x01,0x06,0x05,0x05,0x07,0x23,0x06,0x51,0x07,0x00,0x2f,0x06,0x06,0x01,0x27,0x06,
0x00,0x07,0x51,0x07,0x00,0x2d,0x06,0x05,0x01,0x3d,0x03,0x01,0x25,0xff,0x9d,0x01,0x06,0x04,0x06,0x07,
0x42,0x06,0x27,0x06,0x00,0x07,0x51,0x07,0x00,0x2d,0x06,0x05,0x01,0x11,0x06,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_482, 5, (MRB_SYM(args), 0,MRB_SYM(i), MRB_SYM(len), MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_482 = {
  6,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_482,
  gem_mrblib_mruby_io_proc_pool_482,gem_mrblib_mruby_io_proc_syms_482,NULL,
  gem_mrblib_mruby_io_proc_lv_482,
  NULL,					/* debug_info */
  137,1,7,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_483, 3, (MRB_SYM(size), MRB_SYM(to_s), MRB_SYM(write), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_483[54] = {
0x34,0x00,0x10,0x00,0x06,0x03,0x01,0x05,0x01,0x2f,0x05,0x00,0x00,0x01,0x04,0x05,0x01,0x05,0x03,0x01,
0x06,0x04,0x43,0x05,0x27,0x05,0x00,0x16,0x01,0x06,0x01,0x01,0x07,0x03,0x23,0x06,0x2f,0x06,0x01,0x00,
0x2d,0x05,0x02,0x01,0x3d,0x03,0x01,0x25,0xff,0xde,0x11,0x05,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_483, 4, (MRB_SYM(args), 0,MRB_SYM(i), MRB_SYM(len), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_483 = {
  5,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_483,
  NULL,gem_mrblib_mruby_io_proc_syms_483,NULL,
  gem_mrblib_mruby_io_proc_lv_483,
  NULL,					/* debug_info */
  54,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_484, 2, (MRB_SYM(sprintf), MRB_SYM(write), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_484[23] = {
0x34,0x00,0x10,0x00,0x11,0x05,0x01,0x06,0x01,0x49,0x05,0x2d,0x04,0x00,0x0f,0x2d,0x03,0x01,0x01,0x11,
0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_484, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_484 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_484,
  NULL,gem_mrblib_mruby_io_proc_syms_484,NULL,
  gem_mrblib_mruby_io_proc_lv_484,
  NULL,					/* debug_info */
  23,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_4[15] = {
  &gem_mrblib_mruby_io_proc_irep_470,
  &gem_mrblib_mruby_io_proc_irep_471,
  &gem_mrblib_mruby_io_proc_irep_472,
  &gem_mrblib_mruby_io_proc_irep_473,
  &gem_mrblib_mruby_io_proc_irep_474,
  &gem_mrblib_mruby_io_proc_irep_475,
  &gem_mrblib_mruby_io_proc_irep_476,
  &gem_mrblib_mruby_io_proc_irep_477,
  &gem_mrblib_mruby_io_proc_irep_478,
  &gem_mrblib_mruby_io_proc_irep_479,
  &gem_mrblib_mruby_io_proc_irep_480,
  &gem_mrblib_mruby_io_proc_irep_481,
  &gem_mrblib_mruby_io_proc_irep_482,
  &gem_mrblib_mruby_io_proc_irep_483,
  &gem_mrblib_mruby_io_proc_irep_484,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_4, 25, (MRB_SYM(open), MRB_SYM(popen), MRB_SYM(pipe), MRB_SYM(read), MRB_SYM(hash), MRB_OPSYM(lshift), MRB_SYM(eof), MRB_SYM_Q(eof), MRB_SYM(alias_method), MRB_SYM(tell), MRB_SYM(pos), MRB_SYM_E(pos), MRB_SYM(rewind), MRB_SYM(ungetbyte), MRB_SYM(each), MRB_SYM(each_byte), MRB_SYM(each_line), MRB_SYM(each_char), MRB_SYM(puts), MRB_SYM(print), MRB_SYM(printf), MRB_SYM(to_i), MRB_SYM(fileno), MRB_SYM_Q(tty), MRB_SYM(isatty), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_4[173] = {
0x12,0x01,0x62,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x12,0x01,0x62,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,
0x12,0x01,0x62,0x01,0x58,0x02,0x02,0x5f,0x01,0x02,0x12,0x01,0x62,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,
0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x10,0x02,0x06,0x10,
0x03,0x07,0x2d,0x01,0x08,0x02,0x10,0x02,0x09,0x10,0x03,0x0a,0x2d,0x01,0x08,0x02,0x63,0x01,0x58,0x02,
0x06,0x5f,0x01,0x0b,0x63,0x01,0x58,0x02,0x07,0x5f,0x01,0x0c,0x63,0x01,0x58,0x02,0x08,0x5f,0x01,0x0d,
0x63,0x01,0x58,0x02,0x09,0x5f,0x01,0x0e,0x63,0x01,0x58,0x02,0x0a,0x5f,0x01,0x0f,0x60,0x10,0x0e,0x63,
0x01,0x58,0x02,0x0b,0x5f,0x01,0x11,0x63,0x01,0x58,0x02,0x0c,0x5f,0x01,0x12,0x63,0x01,0x58,0x02,0x0d,
0x5f,0x01,0x13,0x63,0x01,0x58,0x02,0x0e,0x5f,0x01,0x14,0x10,0x02,0x15,0x10,0x03,0x16,0x2d,0x01,0x08,
0x02,0x10,0x02,0x17,0x10,0x03,0x18,0x2d,0x01,0x08,0x02,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_4 = {
  1,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_4,
  NULL,gem_mrblib_mruby_io_proc_syms_4,gem_mrblib_mruby_io_proc_reps_4,
  NULL,					/* lv */
  NULL,					/* debug_info */
  173,0,25,15,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_706, 1, (MRB_SYM(read), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_706[13] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x2f,0x03,0x00,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_706, 2, (MRB_SYM(io), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_706 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_706,
  NULL,gem_mrblib_mruby_io_proc_syms_706,NULL,
  gem_mrblib_mruby_io_proc_lv_706,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_700[1] = {
  &gem_mrblib_mruby_io_proc_irep_706,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_700, 2, (MRB_SYM(IO), MRB_SYM(popen), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_700[19] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x57,0x05,0x00,0x30,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_700, 2, (MRB_SYM(cmd), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_700 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_700,
  NULL,gem_mrblib_mruby_io_proc_syms_700,gem_mrblib_mruby_io_proc_reps_700,
  gem_mrblib_mruby_io_proc_lv_700,
  NULL,					/* debug_info */
  19,0,2,1,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_701[1] = {
{IREP_TT_STR|(1<<2), {"\x7c"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_701, 8, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(IO), MRB_SYM(popen), MRB_SYM(File), MRB_SYM(open), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_701[96] = {
0x34,0x04,0x10,0x01,0x01,0x04,0x01,0x1d,0x05,0x00,0x2f,0x04,0x01,0x01,0x26,0x04,0x00,0x07,0x1d,0x05,
0x02,0x2d,0x04,0x03,0x01,0x01,0x04,0x01,0x06,0x05,0x23,0x04,0x51,0x05,0x00,0x42,0x04,0x27,0x04,0x00,
0x20,0x1d,0x04,0x04,0x01,0x05,0x01,0x07,0x06,0x05,0x07,0x59,0x06,0x23,0x05,0x47,0x05,0x01,0x01,0x06,
0x02,0x49,0x05,0x01,0x06,0x03,0x30,0x04,0x05,0x0f,0x25,0x00,0x15,0x1d,0x04,0x06,0x01,0x05,0x01,0x47,
0x05,0x01,0x01,0x06,0x02,0x49,0x05,0x01,0x06,0x03,0x30,0x04,0x07,0x0f,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_701, 3, (MRB_SYM(file), MRB_SYM(rest), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_701 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_701,
  gem_mrblib_mruby_io_proc_pool_701,gem_mrblib_mruby_io_proc_syms_701,NULL,
  gem_mrblib_mruby_io_proc_lv_701,
  NULL,					/* debug_info */
  96,1,8,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_702, 2, (0, MRB_SYM(print), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_702[20] = {
0x34,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x49,0x04,0x2f,0x03,0x01,0x0f,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_702, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_702 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_702,
  NULL,gem_mrblib_mruby_io_proc_syms_702,NULL,
  gem_mrblib_mruby_io_proc_lv_702,
  NULL,					/* debug_info */
  20,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_703, 2, (0, MRB_SYM(puts), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_703[20] = {
0x34,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x49,0x04,0x2f,0x03,0x01,0x0f,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_703, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_703 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_703,
  NULL,gem_mrblib_mruby_io_proc_syms_703,NULL,
  gem_mrblib_mruby_io_proc_lv_703,
  NULL,					/* debug_info */
  20,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_704, 2, (0, MRB_SYM(printf), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_704[20] = {
0x34,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x49,0x04,0x2f,0x03,0x01,0x0f,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_704, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_704 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_704,
  NULL,gem_mrblib_mruby_io_proc_syms_704,NULL,
  gem_mrblib_mruby_io_proc_lv_704,
  NULL,					/* debug_info */
  20,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_705, 2, (0, MRB_SYM(gets), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_705[20] = {
0x34,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x49,0x04,0x2f,0x03,0x01,0x0f,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_705, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_io_proc_irep_705 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_705,
  NULL,gem_mrblib_mruby_io_proc_syms_705,NULL,
  gem_mrblib_mruby_io_proc_lv_705,
  NULL,					/* debug_info */
  20,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_5[6] = {
  &gem_mrblib_mruby_io_proc_irep_700,
  &gem_mrblib_mruby_io_proc_irep_701,
  &gem_mrblib_mruby_io_proc_irep_702,
  &gem_mrblib_mruby_io_proc_irep_703,
  &gem_mrblib_mruby_io_proc_irep_704,
  &gem_mrblib_mruby_io_proc_irep_705,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_5, 6, (MRB_OPSYM(tick), MRB_SYM(open), MRB_SYM(print), MRB_SYM(puts), MRB_SYM(printf), MRB_SYM(gets), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_5[50] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,
0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_5 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_5,
  NULL,gem_mrblib_mruby_io_proc_syms_5,gem_mrblib_mruby_io_proc_reps_5,
  NULL,					/* lv */
  NULL,					/* debug_info */
  50,0,6,6,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_0[5] = {
  &gem_mrblib_mruby_io_proc_irep_1,
  &gem_mrblib_mruby_io_proc_irep_2,
  &gem_mrblib_mruby_io_proc_irep_3,
  &gem_mrblib_mruby_io_proc_irep_4,
  &gem_mrblib_mruby_io_proc_irep_5,
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_0[2] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
{IREP_TT_STR|(1<<2), {"\x77"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_0, 13, (MRB_SYM(IO), MRB_SYM(File), MRB_SYM(StandardError), MRB_SYM(IOError), MRB_SYM(EOFError), MRB_SYM(open), MRB_SYM(STDIN), MRB_SYM(STDOUT), MRB_SYM(STDERR), 0, 0, 0, MRB_SYM(Kernel), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_0[135] = {
0x11,0x01,0x1d,0x02,0x00,0x5c,0x01,0x01,0x5e,0x01,0x00,0x11,0x01,0x11,0x02,0x5c,0x01,0x01,0x5e,0x01,
0x01,0x11,0x01,0x11,0x02,0x5c,0x01,0x01,0x5e,0x01,0x02,0x11,0x01,0x1d,0x02,0x02,0x5c,0x01,0x03,0x11,
0x01,0x11,0x01,0x1d,0x02,0x03,0x5c,0x01,0x04,0x11,0x01,0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,
0x03,0x1d,0x01,0x00,0x06,0x02,0x51,0x03,0x00,0x2f,0x01,0x05,0x02,0x1e,0x01,0x06,0x1d,0x01,0x00,0x07,
0x02,0x51,0x03,0x01,0x2f,0x01,0x05,0x02,0x1e,0x01,0x07,0x1d,0x01,0x00,0x08,0x02,0x51,0x03,0x01,0x2f,
0x01,0x05,0x02,0x1e,0x01,0x08,0x1d,0x01,0x06,0x16,0x01,0x09,0x1d,0x01,0x07,0x16,0x01,0x0a,0x1d,0x01,
0x08,0x16,0x01,0x0b,0x11,0x01,0x5d,0x01,0x0c,0x5e,0x01,0x04,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_0 = {
  1,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_0,
  gem_mrblib_mruby_io_proc_pool_0,gem_mrblib_mruby_io_proc_syms_0,gem_mrblib_mruby_io_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  135,2,13,5,0
};
static
const struct RProc gem_mrblib_mruby_io_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_io_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_io_proc_init_syms(mrb_state *mrb)
{
  gem_mrblib_mruby_io_proc_syms_702[0] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_syms_703[0] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_syms_704[0] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_syms_705[0] = mrb_intern_lit(mrb, "$stdin");
  gem_mrblib_mruby_io_proc_syms_0[9] = mrb_intern_lit(mrb, "$stdin");
  gem_mrblib_mruby_io_proc_syms_0[10] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_syms_0[11] = mrb_intern_lit(mrb, "$stderr");
}
void mrb_mruby_io_gem_init(mrb_state *mrb);
void mrb_mruby_io_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_io_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_io_proc_init_syms(mrb);
  mrb_mruby_io_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_io_proc);
}

void GENERATED_TMP_mrb_mruby_io_gem_final(mrb_state *mrb) {
  mrb_mruby_io_gem_final(mrb);
}
