/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_3[12] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x06,0x03,0x42,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_3, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_3 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_3,
  NULL,NULL,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_3,
  NULL,					/* debug_info */
  12,0,0,0,0
};
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_4[23] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x06,0x03,0x42,0x02,0x27,0x02,0x00,0x05,0x11,0x02,0x25,0x00,0x02,0x12,
0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_4, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_4 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_4,
  NULL,NULL,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_4,
  NULL,					/* debug_info */
  23,0,0,0,0
};
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_5[12] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x06,0x03,0x45,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_5, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_5 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_5,
  NULL,NULL,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_5,
  NULL,					/* debug_info */
  12,0,0,0,0
};
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_6[12] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x06,0x03,0x43,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_6, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_6 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_6,
  NULL,NULL,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_6,
  NULL,					/* debug_info */
  12,0,0,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_7, 1, (MRB_OPSYM(and), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_7[20] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x01,0x04,0x01,0x42,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_7, 2, (MRB_SYM(mask), 0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_7 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_7,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_7,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_7,
  NULL,					/* debug_info */
  20,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_8, 2, (MRB_OPSYM(and), MRB_OPSYM(neq), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_8[21] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x06,0x04,0x2f,0x03,0x01,0x01,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_8, 2, (MRB_SYM(mask), 0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_8 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_8,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_8,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_8,
  NULL,					/* debug_info */
  21,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_9, 1, (MRB_OPSYM(and), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_9[19] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x06,0x04,0x42,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_9, 2, (MRB_SYM(mask), 0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_9 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_9,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_9,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_9,
  NULL,					/* debug_info */
  19,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_numeric_ext_proc_reps_1[7] = {
  &gem_mrblib_mruby_numeric_ext_proc_irep_3,
  &gem_mrblib_mruby_numeric_ext_proc_irep_4,
  &gem_mrblib_mruby_numeric_ext_proc_irep_5,
  &gem_mrblib_mruby_numeric_ext_proc_irep_6,
  &gem_mrblib_mruby_numeric_ext_proc_irep_7,
  &gem_mrblib_mruby_numeric_ext_proc_irep_8,
  &gem_mrblib_mruby_numeric_ext_proc_irep_9,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_1, 7, (MRB_SYM_Q(zero), MRB_SYM_Q(nonzero), MRB_SYM_Q(positive), MRB_SYM_Q(negative), MRB_SYM_Q(allbits), MRB_SYM_Q(anybits), MRB_SYM_Q(nobits), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_1[58] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,
0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x63,0x01,0x58,0x02,0x06,0x5f,0x01,0x06,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_1 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_1,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_1,gem_mrblib_mruby_numeric_ext_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  58,0,7,7,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_54, 2, (MRB_OPSYM(minus), MRB_SYM(div), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_54[21] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2f,0x04,0x00,0x00,0x2d,0x03,0x01,0x01,0x2f,0x03,0x00,0x00,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_lv_54, 2, (MRB_SYM(other), 0,), const);
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_54 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_54,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_54,NULL,
  gem_mrblib_mruby_numeric_ext_proc_lv_54,
  NULL,					/* debug_info */
  21,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_numeric_ext_proc_reps_2[1] = {
  &gem_mrblib_mruby_numeric_ext_proc_irep_54,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_2, 1, (MRB_SYM(ceildiv), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_2[10] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_2 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_2,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_2,gem_mrblib_mruby_numeric_ext_proc_reps_2,
  NULL,					/* lv */
  NULL,					/* debug_info */
  10,0,1,1,0
};
static const mrb_irep *gem_mrblib_mruby_numeric_ext_proc_reps_0[2] = {
  &gem_mrblib_mruby_numeric_ext_proc_irep_1,
  &gem_mrblib_mruby_numeric_ext_proc_irep_2,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_numeric_ext_proc_syms_0, 2, (MRB_SYM(Numeric), MRB_SYM(Integer), ), const);
static const mrb_code gem_mrblib_mruby_numeric_ext_proc_iseq_0[23] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x11,0x01,0x11,0x02,0x5c,0x01,0x01,0x5e,0x01,0x01,
0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_numeric_ext_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_numeric_ext_proc_iseq_0,
  NULL,gem_mrblib_mruby_numeric_ext_proc_syms_0,gem_mrblib_mruby_numeric_ext_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  23,0,2,2,0
};
static
const struct RProc gem_mrblib_mruby_numeric_ext_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_numeric_ext_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_numeric_ext_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_numeric_ext_gem_init(mrb_state *mrb);
void mrb_mruby_numeric_ext_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_numeric_ext_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_numeric_ext_proc_init_syms(mrb);
  mrb_mruby_numeric_ext_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_numeric_ext_proc);
}

void GENERATED_TMP_mrb_mruby_numeric_ext_gem_final(mrb_state *mrb) {
  mrb_mruby_numeric_ext_gem_final(mrb);
}
