/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_2[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_2, 1, (MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_2[15] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x51,0x03,0x00,0x2f,0x02,0x00,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_2, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_2 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_2,
  gem_mrblib_mruby_string_ext_proc_pool_2,gem_mrblib_mruby_string_ext_proc_syms_2,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_2,
  NULL,					/* debug_info */
  15,1,1,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_3[2] = {
{IREP_TT_STR|(6<<2), {"\x20\x0c\x0a\x0d\x09\x0b"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_3, 2, (MRB_SYM(size), MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_3[85] = {
0x34,0x00,0x00,0x00,0x06,0x02,0x12,0x04,0x2f,0x04,0x00,0x00,0x3f,0x04,0x01,0x01,0x03,0x04,0x01,0x04,
0x02,0x01,0x05,0x03,0x44,0x04,0x27,0x04,0x00,0x0e,0x51,0x04,0x00,0x12,0x05,0x01,0x06,0x02,0x23,0x05,
0x2f,0x04,0x01,0x01,0x27,0x04,0x00,0x06,0x3d,0x02,0x01,0x25,0xff,0xdc,0x01,0x04,0x03,0x06,0x05,0x46,
0x04,0x27,0x04,0x00,0x0f,0x12,0x04,0x01,0x05,0x02,0x01,0x06,0x03,0x59,0x05,0x23,0x04,0x25,0x00,0x03,
0x51,0x04,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_3, 3, (0,MRB_SYM(a), MRB_SYM(z), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_3 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_3,
  gem_mrblib_mruby_string_ext_proc_pool_3,gem_mrblib_mruby_string_ext_proc_syms_3,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_3,
  NULL,					/* debug_info */
  85,2,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_4[2] = {
{IREP_TT_STR|(7<<2), {"\x20\x0c\x0a\x0d\x09\x0b\x00"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_4, 2, (MRB_SYM(size), MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_4[85] = {
0x34,0x00,0x00,0x00,0x06,0x02,0x12,0x04,0x2f,0x04,0x00,0x00,0x3f,0x04,0x01,0x01,0x03,0x04,0x01,0x04,
0x02,0x01,0x05,0x03,0x44,0x04,0x27,0x04,0x00,0x0e,0x51,0x04,0x00,0x12,0x05,0x01,0x06,0x03,0x23,0x05,
0x2f,0x04,0x01,0x01,0x27,0x04,0x00,0x06,0x3f,0x03,0x01,0x25,0xff,0xdc,0x01,0x04,0x03,0x06,0x05,0x46,
0x04,0x27,0x04,0x00,0x0f,0x12,0x04,0x01,0x05,0x02,0x01,0x06,0x03,0x59,0x05,0x23,0x04,0x25,0x00,0x03,
0x51,0x04,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_4, 3, (0,MRB_SYM(a), MRB_SYM(z), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_4 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_4,
  gem_mrblib_mruby_string_ext_proc_pool_4,gem_mrblib_mruby_string_ext_proc_syms_4,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_4,
  NULL,					/* debug_info */
  85,2,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_5[3] = {
{IREP_TT_STR|(6<<2), {"\x20\x0c\x0a\x0d\x09\x0b"}},
{IREP_TT_STR|(7<<2), {"\x20\x0c\x0a\x0d\x09\x0b\x00"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_5, 2, (MRB_SYM(size), MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_5[121] = {
0x34,0x00,0x00,0x00,0x06,0x02,0x12,0x04,0x2f,0x04,0x00,0x00,0x3f,0x04,0x01,0x01,0x03,0x04,0x01,0x04,
0x02,0x01,0x05,0x03,0x44,0x04,0x27,0x04,0x00,0x0e,0x51,0x04,0x00,0x12,0x05,0x01,0x06,0x02,0x23,0x05,
0x2f,0x04,0x01,0x01,0x27,0x04,0x00,0x06,0x3d,0x02,0x01,0x25,0xff,0xdc,0x01,0x04,0x02,0x01,0x05,0x03,
0x44,0x04,0x27,0x04,0x00,0x0e,0x51,0x04,0x01,0x12,0x05,0x01,0x06,0x03,0x23,0x05,0x2f,0x04,0x01,0x01,
0x27,0x04,0x00,0x06,0x3f,0x03,0x01,0x25,0xff,0xdc,0x01,0x04,0x03,0x06,0x05,0x46,0x04,0x27,0x04,0x00,
0x0f,0x12,0x04,0x01,0x05,0x02,0x01,0x06,0x03,0x59,0x05,0x23,0x04,0x25,0x00,0x03,0x51,0x04,0x02,0x38,
0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_5, 3, (0,MRB_SYM(a), MRB_SYM(z), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_5 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_5,
  gem_mrblib_mruby_string_ext_proc_pool_5,gem_mrblib_mruby_string_ext_proc_syms_5,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_5,
  NULL,					/* debug_info */
  121,3,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_6[1] = {
{IREP_TT_STR|(26<<2), {"\x63\x61\x6e\x27\x74\x20\x6d\x6f\x64\x69\x66\x79\x20\x66\x72\x6f\x7a\x65\x6e\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_6, 5, (MRB_SYM_Q(frozen), MRB_SYM(FrozenError), MRB_SYM(raise), MRB_SYM(lstrip), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_6[58] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x27,0x03,0x00,0x0a,0x1d,0x04,0x01,0x51,0x05,0x00,0x2d,0x03,
0x02,0x02,0x12,0x03,0x2f,0x03,0x03,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x12,0x04,0x42,0x03,0x27,0x03,
0x00,0x05,0x11,0x03,0x25,0x00,0x09,0x12,0x03,0x01,0x04,0x02,0x2f,0x03,0x04,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_6, 2, (0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_6 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_6,
  gem_mrblib_mruby_string_ext_proc_pool_6,gem_mrblib_mruby_string_ext_proc_syms_6,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_6,
  NULL,					/* debug_info */
  58,1,5,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_7[1] = {
{IREP_TT_STR|(26<<2), {"\x63\x61\x6e\x27\x74\x20\x6d\x6f\x64\x69\x66\x79\x20\x66\x72\x6f\x7a\x65\x6e\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_7, 5, (MRB_SYM_Q(frozen), MRB_SYM(FrozenError), MRB_SYM(raise), MRB_SYM(rstrip), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_7[58] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x27,0x03,0x00,0x0a,0x1d,0x04,0x01,0x51,0x05,0x00,0x2d,0x03,
0x02,0x02,0x12,0x03,0x2f,0x03,0x03,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x12,0x04,0x42,0x03,0x27,0x03,
0x00,0x05,0x11,0x03,0x25,0x00,0x09,0x12,0x03,0x01,0x04,0x02,0x2f,0x03,0x04,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_7, 2, (0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_7 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_7,
  gem_mrblib_mruby_string_ext_proc_pool_7,gem_mrblib_mruby_string_ext_proc_syms_7,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_7,
  NULL,					/* debug_info */
  58,1,5,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_8[1] = {
{IREP_TT_STR|(26<<2), {"\x63\x61\x6e\x27\x74\x20\x6d\x6f\x64\x69\x66\x79\x20\x66\x72\x6f\x7a\x65\x6e\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_8, 5, (MRB_SYM_Q(frozen), MRB_SYM(FrozenError), MRB_SYM(raise), MRB_SYM(strip), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_8[58] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x27,0x03,0x00,0x0a,0x1d,0x04,0x01,0x51,0x05,0x00,0x2d,0x03,
0x02,0x02,0x12,0x03,0x2f,0x03,0x03,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x12,0x04,0x42,0x03,0x27,0x03,
0x00,0x05,0x11,0x03,0x25,0x00,0x09,0x12,0x03,0x01,0x04,0x02,0x2f,0x03,0x04,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_8, 2, (0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_8 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_8,
  gem_mrblib_mruby_string_ext_proc_pool_8,gem_mrblib_mruby_string_ext_proc_syms_8,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_8,
  NULL,					/* debug_info */
  58,1,5,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_9[3] = {
{IREP_TT_STR|(15<<2), {"\x74\x79\x70\x65\x20\x6d\x69\x73\x6d\x61\x74\x63\x68\x3a\x20"}},
{IREP_TT_STR|(6<<2), {"\x20\x67\x69\x76\x65\x6e"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_9, 8, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(index), MRB_SYM(size), MRB_SYM(slice), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_9[132] = {
0x34,0x04,0x00,0x00,0x01,0x05,0x01,0x1d,0x06,0x00,0x2f,0x05,0x01,0x01,0x26,0x05,0x00,0x18,0x1d,0x06,
0x02,0x51,0x07,0x00,0x01,0x08,0x01,0x2f,0x08,0x03,0x00,0x52,0x07,0x51,0x08,0x01,0x52,0x07,0x2d,0x05,
0x04,0x02,0x01,0x06,0x01,0x2d,0x05,0x05,0x01,0x01,0x03,0x05,0x01,0x05,0x03,0x28,0x05,0x00,0x03,0x25,
0x00,0x16,0x12,0x05,0x06,0x06,0x05,0x07,0x59,0x06,0x23,0x05,0x51,0x06,0x02,0x51,0x07,0x02,0x47,0x05,
0x03,0x25,0x00,0x2e,0x01,0x05,0x03,0x01,0x06,0x01,0x2f,0x06,0x06,0x00,0x3c,0x05,0x01,0x04,0x05,0x06,
0x06,0x01,0x07,0x03,0x2d,0x05,0x07,0x02,0x01,0x06,0x01,0x01,0x08,0x04,0x2d,0x09,0x06,0x00,0x01,0x0a,
0x04,0x3e,0x09,0x2d,0x07,0x07,0x02,0x47,0x05,0x03,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_9, 4, (MRB_SYM(sep), 0,MRB_SYM(n), MRB_SYM(m), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_9 = {
  5,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_9,
  gem_mrblib_mruby_string_ext_proc_pool_9,gem_mrblib_mruby_string_ext_proc_syms_9,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_9,
  NULL,					/* debug_info */
  132,3,8,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_10[3] = {
{IREP_TT_STR|(15<<2), {"\x74\x79\x70\x65\x20\x6d\x69\x73\x6d\x61\x74\x63\x68\x3a\x20"}},
{IREP_TT_STR|(6<<2), {"\x20\x67\x69\x76\x65\x6e"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_10, 8, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(rindex), MRB_SYM(size), MRB_SYM(slice), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_10[124] = {
0x34,0x04,0x00,0x00,0x01,0x05,0x01,0x1d,0x06,0x00,0x2f,0x05,0x01,0x01,0x26,0x05,0x00,0x18,0x1d,0x06,
0x02,0x51,0x07,0x00,0x01,0x08,0x01,0x2f,0x08,0x03,0x00,0x52,0x07,0x51,0x08,0x01,0x52,0x07,0x2d,0x05,
0x04,0x02,0x01,0x06,0x01,0x2d,0x05,0x05,0x01,0x01,0x03,0x05,0x01,0x05,0x03,0x28,0x05,0x00,0x03,0x25,
0x00,0x0e,0x51,0x05,0x02,0x51,0x06,0x02,0x12,0x07,0x47,0x05,0x03,0x25,0x00,0x2e,0x01,0x05,0x03,0x01,
0x06,0x01,0x2f,0x06,0x06,0x00,0x3c,0x05,0x01,0x04,0x05,0x06,0x06,0x01,0x07,0x03,0x2d,0x05,0x07,0x02,
0x01,0x06,0x01,0x01,0x08,0x04,0x2d,0x09,0x06,0x00,0x01,0x0a,0x04,0x3e,0x09,0x2d,0x07,0x07,0x02,0x47,
0x05,0x03,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_10, 4, (MRB_SYM(sep), 0,MRB_SYM(n), MRB_SYM(m), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_10 = {
  5,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_10,
  gem_mrblib_mruby_string_ext_proc_pool_10,gem_mrblib_mruby_string_ext_proc_syms_10,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_10,
  NULL,					/* debug_info */
  124,3,8,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_11[3] = {
{IREP_TT_STR|(26<<2), {"\x63\x61\x6e\x27\x74\x20\x6d\x6f\x64\x69\x66\x79\x20\x66\x72\x6f\x7a\x65\x6e\x20\x53\x74\x72\x69\x6e\x67"}},
{IREP_TT_STR|(41<<2), {"\x77\x72\x6f\x6e\x67\x20\x6e\x75\x6d\x62\x65\x72\x20\x6f\x66\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x73\x20\x28\x65\x78\x70\x65\x63\x74\x65\x64\x20\x31\x2e\x2e\x32\x29"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_11, 17, (MRB_SYM_Q(frozen), MRB_SYM(FrozenError), MRB_SYM(raise), MRB_SYM_Q(nil), MRB_SYM(ArgumentError), MRB_OPSYM(not), MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(Range), MRB_SYM_Q(kind_of), MRB_SYM(begin), MRB_SYM(end), MRB_SYM_Q(exclude_end), MRB_SYM(String), MRB_SYM(to_s), MRB_SYM(index), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_11[777] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x11,0x02,0x2d,0x0b,0x00,0x00,0x27,0x0b,0x00,0x0a,
0x1d,0x0c,0x01,0x51,0x0d,0x00,0x2d,0x0b,0x02,0x02,0x01,0x0b,0x01,0x2f,0x0b,0x03,0x00,0x27,0x0b,0x00,
0x07,0x01,0x0b,0x02,0x2f,0x0b,0x03,0x00,0x27,0x0b,0x00,0x0a,0x1d,0x0c,0x04,0x51,0x0d,0x01,0x2d,0x0b,
0x02,0x02,0x01,0x0b,0x01,0x2f,0x0b,0x03,0x00,0x2f,0x0b,0x05,0x00,0x27,0x0b,0x00,0x0b,0x01,0x0b,0x02,
0x2f,0x0b,0x03,0x00,0x2f,0x0b,0x05,0x00,0x27,0x0b,0x00,0x5a,0x01,0x04,0x01,0x01,0x0b,0x01,0x06,0x0c,
0x43,0x0b,0x27,0x0b,0x00,0x0e,0x01,0x0b,0x04,0x12,0x0c,0x2f,0x0c,0x06,0x00,0x3c,0x0b,0x01,0x04,0x0b,
0x01,0x0b,0x04,0x06,0x0c,0x46,0x0b,0x27,0x0b,0x00,0x0b,0x01,0x0b,0x04,0x12,0x0c,0x2f,0x0c,0x06,0x00,
0x44,0x0b,0x27,0x0b,0x00,0x07,0x01,0x0b,0x02,0x06,0x0c,0x45,0x0b,0x27,0x0b,0x00,0x12,0x12,0x0b,0x01,
0x0c,0x04,0x01,0x0d,0x02,0x2f,0x0b,0x07,0x02,0x01,0x05,0x0b,0x25,0x00,0x04,0x11,0x0b,0x38,0x0b,0x25,
0x00,0xcc,0x14,0x06,0x01,0x0b,0x01,0x1d,0x0c,0x08,0x2f,0x0b,0x09,0x01,0x27,0x0b,0x00,0x59,0x01,0x0b,
0x01,0x2f,0x0b,0x0a,0x00,0x01,0x07,0x0b,0x01,0x0b,0x01,0x2f,0x0b,0x0b,0x00,0x01,0x08,0x0b,0x01,0x0b,
0x07,0x06,0x0c,0x43,0x0b,0x27,0x0b,0x00,0x0e,0x01,0x0b,0x07,0x12,0x0c,0x2f,0x0c,0x06,0x00,0x3c,0x0b,
0x01,0x07,0x0b,0x01,0x0b,0x08,0x06,0x0c,0x43,0x0b,0x27,0x0b,0x00,0x0e,0x01,0x0b,0x08,0x12,0x0c,0x2f,
0x0c,0x06,0x00,0x3c,0x0b,0x01,0x08,0x0b,0x01,0x0b,0x01,0x2f,0x0b,0x0c,0x00,0x27,0x0b,0x00,0x03,0x3f,
0x08,0x01,0x13,0x06,0x25,0x00,0x4b,0x01,0x0b,0x01,0x1d,0x0c,0x0d,0x2f,0x0b,0x09,0x01,0x27,0x0b,0x00,
0x05,0x13,0x06,0x25,0x00,0x38,0x01,0x04,0x01,0x01,0x0b,0x01,0x06,0x0c,0x43,0x0b,0x27,0x0b,0x00,0x0e,
0x01,0x0b,0x04,0x12,0x0c,0x2f,0x0c,0x06,0x00,0x3c,0x0b,0x01,0x04,0x0b,0x01,0x0b,0x04,0x06,0x0c,0x46,
0x0b,0x27,0x0b,0x00,0x0b,0x01,0x0b,0x01,0x12,0x0c,0x2f,0x0c,0x06,0x00,0x43,0x0b,0x27,0x0b,0x00,0x02,
0x13,0x06,0x01,0x0b,0x06,0x27,0x0b,0x00,0x0d,0x12,0x0b,0x01,0x0c,0x01,0x23,0x0b,0x01,0x05,0x0b,0x25,
0x00,0x04,0x11,0x0b,0x38,0x0b,0x01,0x0b,0x05,0x2f,0x0b,0x03,0x00,0x26,0x0b,0x00,0x08,0x01,0x0b,0x05,
0x51,0x0c,0x02,0x42,0x0b,0x26,0x0b,0x01,0x6e,0x01,0x0b,0x01,0x2f,0x0b,0x03,0x00,0x2f,0x0b,0x05,0x00,
0x27,0x0b,0x00,0x0b,0x01,0x0b,0x02,0x2f,0x0b,0x03,0x00,0x2f,0x0b,0x05,0x00,0x27,0x0b,0x00,0x46,0x01,
0x0b,0x01,0x06,0x0c,0x46,0x0b,0x27,0x0b,0x00,0x06,0x01,0x0b,0x01,0x25,0x00,0x0b,0x12,0x0b,0x2f,0x0b,
0x06,0x00,0x01,0x0c,0x01,0x3c,0x0b,0x01,0x04,0x0b,0x12,0x0b,0x06,0x0c,0x01,0x0d,0x04,0x5a,0x0c,0x23,
0x0b,0x12,0x0c,0x01,0x0d,0x04,0x01,0x0e,0x02,0x3c,0x0d,0x05,0x0e,0x59,0x0d,0x23,0x0c,0x2f,0x0c,0x0e,
0x00,0x3c,0x0b,0x01,0x09,0x0b,0x25,0x00,0xfa,0x01,0x0b,0x01,0x1d,0x0c,0x08,0x2f,0x0b,0x09,0x01,0x27,
0x0b,0x00,0x63,0x01,0x0b,0x07,0x06,0x0c,0x46,0x0b,0x27,0x0b,0x00,0x06,0x01,0x0b,0x07,0x25,0x00,0x0b,
0x12,0x0b,0x2f,0x0b,0x06,0x00,0x01,0x0c,0x07,0x3c,0x0b,0x01,0x04,0x0b,0x01,0x0b,0x08,0x06,0x0c,0x46,
0x0b,0x27,0x0b,0x00,0x06,0x01,0x0b,0x08,0x25,0x00,0x0b,0x12,0x0b,0x2f,0x0b,0x06,0x00,0x01,0x0c,0x08,
0x3c,0x0b,0x01,0x0a,0x0b,0x12,0x0b,0x06,0x0c,0x01,0x0d,0x04,0x5a,0x0c,0x23,0x0b,0x12,0x0c,0x01,0x0d,
0x0a,0x3d,0x0d,0x01,0x05,0x0e,0x59,0x0d,0x23,0x0c,0x2f,0x0c,0x0e,0x00,0x3c,0x0b,0x01,0x09,0x0b,0x25,
0x00,0x89,0x01,0x0b,0x01,0x1d,0x0c,0x0d,0x2f,0x0b,0x09,0x01,0x27,0x0b,0x00,0x3a,0x12,0x0b,0x01,0x0c,
0x01,0x2f,0x0b,0x0f,0x01,0x01,0x04,0x0b,0x01,0x0b,0x04,0x28,0x0b,0x00,0x24,0x12,0x0b,0x06,0x0c,0x01,
0x0d,0x04,0x5a,0x0c,0x23,0x0b,0x12,0x0c,0x01,0x0d,0x04,0x01,0x0e,0x01,0x2f,0x0e,0x06,0x00,0x3c,0x0d,
0x05,0x0e,0x59,0x0d,0x23,0x0c,0x3c,0x0b,0x01,0x09,0x0b,0x25,0x00,0x41,0x01,0x0b,0x01,0x06,0x0c,0x46,
0x0b,0x27,0x0b,0x00,0x06,0x01,0x0b,0x01,0x25,0x00,0x0b,0x12,0x0b,0x2f,0x0b,0x06,0x00,0x01,0x0c,0x01,
0x3c,0x0b,0x01,0x04,0x0b,0x12,0x0b,0x06,0x0c,0x01,0x0d,0x04,0x5a,0x0c,0x23,0x0b,0x12,0x0c,0x01,0x0d,
0x04,0x3d,0x0d,0x01,0x05,0x0e,0x59,0x0d,0x23,0x0c,0x2f,0x0c,0x0e,0x00,0x3c,0x0b,0x01,0x09,0x0b,0x01,
0x0b,0x09,0x28,0x0b,0x00,0x09,0x12,0x0b,0x01,0x0c,0x09,0x2f,0x0b,0x10,0x01,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_11, 10, (MRB_SYM(arg1), MRB_SYM(arg2), 0,MRB_SYM(idx), MRB_SYM(str), MRB_SYM(validated), MRB_SYM(beg), MRB_SYM(ed), MRB_SYM(str2), MRB_SYM(idx2), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_11 = {
  11,16,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_11,
  gem_mrblib_mruby_string_ext_proc_pool_11,gem_mrblib_mruby_string_ext_proc_syms_11,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_11,
  NULL,					/* debug_info */
  777,3,17,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_12, 2, (MRB_OPSYM(lshift), MRB_OPSYM(aset), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_12[61] = {
0x34,0x08,0x00,0x00,0x01,0x04,0x01,0x05,0x05,0x42,0x04,0x27,0x04,0x00,0x0e,0x12,0x04,0x01,0x05,0x02,
0x2f,0x04,0x00,0x01,0x38,0x04,0x25,0x00,0x0e,0x01,0x04,0x01,0x06,0x05,0x43,0x04,0x27,0x04,0x00,0x03,
0x3d,0x01,0x01,0x12,0x04,0x01,0x05,0x01,0x06,0x06,0x01,0x07,0x02,0x2f,0x04,0x01,0x03,0x12,0x04,0x38,
0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_12, 3, (MRB_SYM(idx), MRB_SYM(str), 0,), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_12 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_12,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_12,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_12,
  NULL,					/* debug_info */
  61,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_13[3] = {
{IREP_TT_STR|(1<<2), {"\x20"}},
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(18<<2), {"\x7a\x65\x72\x6f\x20\x77\x69\x64\x74\x68\x20\x70\x61\x64\x64\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_13, 4, (MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_OPSYM(aref), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_13[106] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x03,0x51,0x02,0x00,0x01,0x06,0x02,0x51,0x07,0x01,0x42,
0x06,0x27,0x06,0x00,0x0a,0x1d,0x07,0x00,0x51,0x08,0x02,0x2d,0x06,0x01,0x02,0x01,0x06,0x01,0x12,0x07,
0x2f,0x07,0x02,0x00,0x44,0x06,0x27,0x06,0x00,0x04,0x12,0x06,0x38,0x06,0x01,0x06,0x01,0x01,0x07,0x02,
0x2f,0x07,0x02,0x00,0x41,0x06,0x01,0x04,0x06,0x01,0x06,0x02,0x01,0x07,0x04,0x40,0x06,0x06,0x07,0x01,
0x08,0x01,0x12,0x09,0x2f,0x09,0x02,0x00,0x3e,0x08,0x2f,0x06,0x03,0x02,0x01,0x05,0x06,0x12,0x06,0x01,
0x07,0x05,0x3c,0x06,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_13, 5, (MRB_SYM(idx), MRB_SYM(padstr), 0,MRB_SYM(pad_repetitions), MRB_SYM(padding), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_13 = {
  6,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_13,
  gem_mrblib_mruby_string_ext_proc_pool_13,gem_mrblib_mruby_string_ext_proc_syms_13,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_13,
  NULL,					/* debug_info */
  106,3,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_14[3] = {
{IREP_TT_STR|(1<<2), {"\x20"}},
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(18<<2), {"\x7a\x65\x72\x6f\x20\x77\x69\x64\x74\x68\x20\x70\x61\x64\x64\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_14, 4, (MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_OPSYM(aref), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_14[106] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x03,0x51,0x02,0x00,0x01,0x06,0x02,0x51,0x07,0x01,0x42,
0x06,0x27,0x06,0x00,0x0a,0x1d,0x07,0x00,0x51,0x08,0x02,0x2d,0x06,0x01,0x02,0x01,0x06,0x01,0x12,0x07,
0x2f,0x07,0x02,0x00,0x44,0x06,0x27,0x06,0x00,0x04,0x12,0x06,0x38,0x06,0x01,0x06,0x01,0x01,0x07,0x02,
0x2f,0x07,0x02,0x00,0x41,0x06,0x01,0x04,0x06,0x01,0x06,0x02,0x01,0x07,0x04,0x40,0x06,0x06,0x07,0x01,
0x08,0x01,0x12,0x09,0x2f,0x09,0x02,0x00,0x3e,0x08,0x2f,0x06,0x03,0x02,0x01,0x05,0x06,0x01,0x06,0x05,
0x12,0x07,0x3c,0x06,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_14, 5, (MRB_SYM(idx), MRB_SYM(padstr), 0,MRB_SYM(pad_repetitions), MRB_SYM(padding), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_14 = {
  6,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_14,
  gem_mrblib_mruby_string_ext_proc_pool_14,gem_mrblib_mruby_string_ext_proc_syms_14,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_14,
  NULL,					/* debug_info */
  106,3,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_15[3] = {
{IREP_TT_STR|(1<<2), {"\x20"}},
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(18<<2), {"\x7a\x65\x72\x6f\x20\x77\x69\x64\x74\x68\x20\x70\x61\x64\x64\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_15, 4, (MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_OPSYM(aref), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_15[131] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x03,0x51,0x02,0x00,0x01,0x06,0x02,0x51,0x07,0x01,0x42,
0x06,0x27,0x06,0x00,0x0a,0x1d,0x07,0x00,0x51,0x08,0x02,0x2d,0x06,0x01,0x02,0x01,0x06,0x01,0x12,0x07,
0x2f,0x07,0x02,0x00,0x44,0x06,0x27,0x06,0x00,0x04,0x12,0x06,0x38,0x06,0x01,0x06,0x01,0x12,0x07,0x2f,
0x07,0x02,0x00,0x3e,0x06,0x01,0x01,0x06,0x01,0x06,0x01,0x08,0x07,0x41,0x06,0x01,0x04,0x06,0x01,0x06,
0x01,0x01,0x07,0x04,0x3e,0x06,0x01,0x05,0x06,0x01,0x06,0x02,0x01,0x07,0x04,0x40,0x06,0x06,0x07,0x01,
0x08,0x04,0x2f,0x06,0x03,0x02,0x12,0x07,0x3c,0x06,0x01,0x07,0x02,0x01,0x08,0x05,0x40,0x07,0x06,0x08,
0x01,0x09,0x05,0x2f,0x07,0x03,0x02,0x3c,0x06,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_15, 5, (MRB_SYM(width), MRB_SYM(padstr), 0,MRB_SYM(pad1), MRB_SYM(pad2), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_15 = {
  6,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_15,
  gem_mrblib_mruby_string_ext_proc_pool_15,gem_mrblib_mruby_string_ext_proc_syms_15,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_15,
  NULL,					/* debug_info */
  131,3,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_317, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_317[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x01,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_317, 2, (MRB_SYM(i), 0,), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_317 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_317,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_317,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_317,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_string_ext_proc_reps_16[1] = {
  &gem_mrblib_mruby_string_ext_proc_irep_317,
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_16[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_16, 3, (MRB_SYM_Q(block_given), MRB_SYM(split), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_16[44] = {
0x34,0x00,0x00,0x01,0x2d,0x02,0x00,0x00,0x27,0x02,0x00,0x15,0x12,0x02,0x51,0x03,0x00,0x2f,0x02,0x01,
0x01,0x57,0x03,0x00,0x30,0x02,0x02,0x00,0x12,0x02,0x25,0x00,0x09,0x12,0x02,0x51,0x03,0x00,0x2f,0x02,
0x01,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_16, 1, (MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_16 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_16,
  gem_mrblib_mruby_string_ext_proc_pool_16,gem_mrblib_mruby_string_ext_proc_syms_16,gem_mrblib_mruby_string_ext_proc_reps_16,
  gem_mrblib_mruby_string_ext_proc_lv_16,
  NULL,					/* debug_info */
  44,1,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_17, 4, (MRB_SYM(each_char), MRB_SYM(to_enum), MRB_SYM(size), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_17[61] = {
0x34,0x00,0x00,0x01,0x01,0x03,0x01,0x26,0x03,0x00,0x09,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,0x38,0x03,
0x06,0x02,0x01,0x03,0x02,0x12,0x04,0x2f,0x04,0x02,0x00,0x43,0x03,0x27,0x03,0x00,0x14,0x01,0x03,0x01,
0x12,0x04,0x01,0x05,0x02,0x23,0x04,0x2f,0x03,0x03,0x01,0x3d,0x02,0x01,0x25,0xff,0xdd,0x12,0x03,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_17, 2, (MRB_SYM(block), MRB_SYM(pos), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_17 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_17,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_17,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_17,
  NULL,					/* debug_info */
  61,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_360, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_360[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x01,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_360, 2, (MRB_SYM(x), 0,), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_360 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_360,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_360,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_360,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_string_ext_proc_reps_18[1] = {
  &gem_mrblib_mruby_string_ext_proc_irep_360,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_18, 3, (MRB_SYM(__codepoints), MRB_SYM_Q(block_given), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_18[39] = {
0x34,0x00,0x00,0x01,0x2d,0x03,0x00,0x00,0x01,0x02,0x03,0x2d,0x03,0x01,0x00,0x27,0x03,0x00,0x0f,0x01,
0x03,0x02,0x57,0x04,0x00,0x30,0x03,0x02,0x00,0x12,0x03,0x25,0x00,0x03,0x01,0x03,0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_18, 2, (MRB_SYM(block), MRB_SYM(cp), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_18 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_18,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_18,gem_mrblib_mruby_string_ext_proc_reps_18,
  gem_mrblib_mruby_string_ext_proc_lv_18,
  NULL,					/* debug_info */
  39,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_19, 2, (MRB_SYM(size), MRB_OPSYM(aset), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_19[53] = {
0x34,0x00,0x10,0x00,0x01,0x04,0x01,0x2f,0x04,0x00,0x00,0x01,0x03,0x04,0x01,0x04,0x03,0x06,0x05,0x45,
0x04,0x27,0x04,0x00,0x18,0x3f,0x03,0x01,0x12,0x04,0x06,0x05,0x06,0x06,0x01,0x07,0x01,0x01,0x08,0x03,
0x23,0x07,0x2f,0x04,0x01,0x03,0x25,0xff,0xdd,0x12,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_19, 3, (MRB_SYM(args), 0,MRB_SYM(len), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_19 = {
  4,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_19,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_19,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_19,
  NULL,					/* debug_info */
  53,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_403, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_403[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x01,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_403, 2, (MRB_SYM(line), 0,), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_403 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_403,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_403,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_403,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_string_ext_proc_reps_20[1] = {
  &gem_mrblib_mruby_string_ext_proc_irep_403,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_20, 2, (MRB_SYM(__lines), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_20[32] = {
0x34,0x00,0x00,0x01,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x01,0x03,0x01,0x27,0x03,0x00,0x0a,
0x01,0x03,0x02,0x57,0x04,0x00,0x30,0x03,0x01,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_20, 2, (MRB_SYM(blk), MRB_SYM(lines), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_20 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_20,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_20,gem_mrblib_mruby_string_ext_proc_reps_20,
  gem_mrblib_mruby_string_ext_proc_lv_20,
  NULL,					/* debug_info */
  32,0,2,1,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_21[3] = {
{IREP_TT_STR|(26<<2), {"\x6e\x6f\x20\x69\x6d\x70\x6c\x69\x63\x69\x74\x20\x63\x6f\x6e\x76\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20"}},
{IREP_TT_STR|(12<<2), {"\x20\x69\x6e\x74\x6f\x20\x53\x74\x72\x69\x6e\x67"}},
{IREP_TT_STR|(1<<2), {"\x30"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_21, 18, (MRB_SYM(upto), MRB_SYM(to_enum), MRB_SYM(String), MRB_SYM_Q(kind_of), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), MRB_SYM(length), MRB_SYM(ord), MRB_SYM(__ENCODING__), MRB_SYM(chr), MRB_SYM(call), MRB_SYM(to_i), MRB_SYM(to_s), MRB_SYM(rjust), MRB_OPSYM(cmp), MRB_SYM(size), MRB_SYM(succ), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_21[505] = {
0x34,0x04,0x20,0x01,0x25,0x00,0x03,0x25,0x00,0x02,0x14,0x02,0x01,0x0e,0x03,0x26,0x0e,0x00,0x0f,0x10,
0x0f,0x00,0x01,0x10,0x01,0x01,0x11,0x02,0x2d,0x0e,0x01,0x03,0x38,0x0e,0x01,0x0e,0x01,0x1d,0x0f,0x02,
0x2f,0x0e,0x03,0x01,0x26,0x0e,0x00,0x18,0x1d,0x0f,0x04,0x51,0x10,0x00,0x01,0x11,0x01,0x2f,0x11,0x05,
0x00,0x52,0x10,0x51,0x11,0x01,0x52,0x10,0x2d,0x0e,0x06,0x02,0x12,0x0e,0x2f,0x0e,0x07,0x00,0x01,0x04,
0x0e,0x01,0x0e,0x01,0x2f,0x0e,0x07,0x00,0x01,0x05,0x0e,0x01,0x0e,0x04,0x07,0x0f,0x42,0x0e,0x27,0x0e,
0x00,0x07,0x01,0x0e,0x05,0x07,0x0f,0x42,0x0e,0x27,0x0e,0x00,0x52,0x12,0x0e,0x2f,0x0e,0x08,0x00,0x01,
0x06,0x0e,0x01,0x0e,0x01,0x2f,0x0e,0x08,0x00,0x01,0x07,0x0e,0x01,0x0e,0x06,0x01,0x0f,0x07,0x44,0x0e,
0x27,0x0e,0x00,0x2f,0x01,0x0e,0x02,0x27,0x0e,0x00,0x08,0x01,0x0e,0x06,0x01,0x0f,0x07,0x42,0x0e,0x27,
0x0e,0x00,0x03,0x29,0x00,0x19,0x01,0x0f,0x06,0x2d,0x10,0x09,0x00,0x2f,0x0f,0x0a,0x01,0x3b,0x0e,0x10,
0x00,0x2f,0x0e,0x0b,0x01,0x3d,0x06,0x01,0x25,0xff,0xc5,0x12,0x0e,0x38,0x0e,0x12,0x0e,0x03,0x0f,0x0a,
0x2f,0x0e,0x0c,0x01,0x01,0x08,0x0e,0x01,0x0e,0x01,0x03,0x0f,0x0a,0x2f,0x0e,0x0c,0x01,0x01,0x09,0x0e,
0x01,0x0e,0x08,0x06,0x0f,0x45,0x0e,0x26,0x0e,0x00,0x0d,0x01,0x0e,0x08,0x51,0x0f,0x02,0x01,0x10,0x04,
0x40,0x0f,0x42,0x0e,0x27,0x0e,0x00,0x18,0x01,0x0e,0x09,0x06,0x0f,0x45,0x0e,0x26,0x0e,0x00,0x0d,0x01,
0x0e,0x09,0x51,0x0f,0x02,0x01,0x10,0x05,0x40,0x0f,0x42,0x0e,0x27,0x0e,0x00,0x61,0x01,0x0e,0x08,0x01,
0x0f,0x09,0x44,0x0e,0x27,0x0e,0x00,0x51,0x01,0x0e,0x02,0x27,0x0e,0x00,0x08,0x01,0x0e,0x08,0x01,0x0f,
0x09,0x42,0x0e,0x27,0x0e,0x00,0x03,0x29,0x00,0x3b,0x01,0x0e,0x08,0x2f,0x0e,0x0d,0x00,0x01,0x0a,0x0e,
0x01,0x0e,0x0a,0x2f,0x0e,0x07,0x00,0x01,0x0f,0x04,0x43,0x0e,0x27,0x0e,0x00,0x10,0x01,0x0e,0x0a,0x01,
0x0f,0x04,0x51,0x10,0x02,0x2f,0x0e,0x0e,0x02,0x01,0x0a,0x0e,0x01,0x0f,0x0a,0x3b,0x0e,0x10,0x00,0x2f,
0x0e,0x0b,0x01,0x3d,0x08,0x01,0x25,0xff,0xa3,0x12,0x0e,0x38,0x0e,0x12,0x0b,0x01,0x0e,0x0b,0x01,0x0f,
0x01,0x2f,0x0e,0x0f,0x01,0x01,0x0c,0x0e,0x01,0x0e,0x0c,0x06,0x0f,0x45,0x0e,0x27,0x0e,0x00,0x03,0x29,
0x00,0x63,0x01,0x0e,0x02,0x27,0x0e,0x00,0x07,0x01,0x0e,0x0c,0x06,0x0f,0x42,0x0e,0x27,0x0e,0x00,0x03,
0x29,0x00,0x4e,0x01,0x0f,0x0b,0x3b,0x0e,0x10,0x00,0x2f,0x0e,0x0b,0x01,0x01,0x0e,0x0c,0x06,0x0f,0x42,
0x0e,0x27,0x0e,0x00,0x03,0x29,0x00,0x35,0x01,0x0e,0x0b,0x2f,0x0e,0x10,0x00,0x01,0x0d,0x0e,0x01,0x0e,
0x0d,0x01,0x0f,0x01,0x2f,0x0f,0x10,0x00,0x45,0x0e,0x26,0x0e,0x00,0x07,0x01,0x0e,0x0d,0x06,0x0f,0x42,
0x0e,0x27,0x0e,0x00,0x03,0x29,0x00,0x0d,0x01,0x0e,0x0b,0x2f,0x0e,0x11,0x00,0x01,0x0b,0x0e,0x25,0xff,
0x82,0x12,0x0e,0x38,0x0e,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_21, 13, (MRB_SYM(max), MRB_SYM(exclusive), MRB_SYM(block), MRB_SYM(len), MRB_SYM(maxlen), MRB_SYM(c), MRB_SYM(e), MRB_SYM(bi), MRB_SYM(ei), MRB_SYM(s), MRB_SYM(bs), MRB_SYM(n), MRB_SYM(bsiz), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_21 = {
  14,19,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_21,
  gem_mrblib_mruby_string_ext_proc_pool_21,gem_mrblib_mruby_string_ext_proc_syms_21,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_21,
  NULL,					/* debug_info */
  505,3,18,0,0
};
static const mrb_pool_value gem_mrblib_mruby_string_ext_proc_pool_22[1] = {
{IREP_TT_STR|(1<<2), {"\x30"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_22, 6, (MRB_SYM(length), MRB_SYM(to_i), MRB_SYM(to_s), MRB_SYM(rjust), MRB_SYM(call), MRB_SYM(succ), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_22[146] = {
0x34,0x00,0x00,0x01,0x12,0x06,0x2f,0x06,0x00,0x00,0x01,0x02,0x06,0x12,0x06,0x03,0x07,0x0a,0x2f,0x06,
0x01,0x01,0x01,0x03,0x06,0x01,0x06,0x03,0x06,0x07,0x45,0x06,0x26,0x06,0x00,0x0d,0x01,0x06,0x03,0x51,
0x07,0x00,0x01,0x08,0x02,0x40,0x07,0x42,0x06,0x27,0x06,0x00,0x3f,0x01,0x06,0x03,0x2f,0x06,0x02,0x00,
0x01,0x04,0x06,0x01,0x06,0x04,0x2f,0x06,0x00,0x00,0x01,0x07,0x02,0x43,0x06,0x27,0x06,0x00,0x10,0x01,
0x06,0x04,0x01,0x07,0x02,0x51,0x08,0x00,0x2f,0x06,0x03,0x02,0x01,0x04,0x06,0x01,0x07,0x04,0x3b,0x06,
0x00,0x00,0x2f,0x06,0x04,0x01,0x3d,0x03,0x01,0x25,0xff,0xc5,0x12,0x06,0x38,0x06,0x12,0x05,0x01,0x07,
0x05,0x3b,0x06,0x00,0x00,0x2f,0x06,0x04,0x01,0x01,0x06,0x05,0x2f,0x06,0x05,0x00,0x01,0x05,0x06,0x25,
0xff,0xe8,0x12,0x06,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_lv_22, 5, (MRB_SYM(block), MRB_SYM(len), MRB_SYM(bi), MRB_SYM(s), MRB_SYM(bs), ), const);
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_22 = {
  6,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_22,
  gem_mrblib_mruby_string_ext_proc_pool_22,gem_mrblib_mruby_string_ext_proc_syms_22,NULL,
  gem_mrblib_mruby_string_ext_proc_lv_22,
  NULL,					/* debug_info */
  146,1,6,0,0
};
static const mrb_irep *gem_mrblib_mruby_string_ext_proc_reps_1[21] = {
  &gem_mrblib_mruby_string_ext_proc_irep_2,
  &gem_mrblib_mruby_string_ext_proc_irep_3,
  &gem_mrblib_mruby_string_ext_proc_irep_4,
  &gem_mrblib_mruby_string_ext_proc_irep_5,
  &gem_mrblib_mruby_string_ext_proc_irep_6,
  &gem_mrblib_mruby_string_ext_proc_irep_7,
  &gem_mrblib_mruby_string_ext_proc_irep_8,
  &gem_mrblib_mruby_string_ext_proc_irep_9,
  &gem_mrblib_mruby_string_ext_proc_irep_10,
  &gem_mrblib_mruby_string_ext_proc_irep_11,
  &gem_mrblib_mruby_string_ext_proc_irep_12,
  &gem_mrblib_mruby_string_ext_proc_irep_13,
  &gem_mrblib_mruby_string_ext_proc_irep_14,
  &gem_mrblib_mruby_string_ext_proc_irep_15,
  &gem_mrblib_mruby_string_ext_proc_irep_16,
  &gem_mrblib_mruby_string_ext_proc_irep_17,
  &gem_mrblib_mruby_string_ext_proc_irep_18,
  &gem_mrblib_mruby_string_ext_proc_irep_19,
  &gem_mrblib_mruby_string_ext_proc_irep_20,
  &gem_mrblib_mruby_string_ext_proc_irep_21,
  &gem_mrblib_mruby_string_ext_proc_irep_22,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_1, 22, (MRB_SYM(clear), MRB_SYM(lstrip), MRB_SYM(rstrip), MRB_SYM(strip), MRB_SYM_B(lstrip), MRB_SYM_B(rstrip), MRB_SYM_B(strip), MRB_SYM(partition), MRB_SYM(rpartition), MRB_SYM_B(slice), MRB_SYM(insert), MRB_SYM(ljust), MRB_SYM(rjust), MRB_SYM(center), MRB_SYM(chars), MRB_SYM(each_char), MRB_SYM(codepoints), MRB_SYM(each_codepoint), MRB_SYM(prepend), MRB_SYM(lines), MRB_SYM(upto), MRB_SYM(__upto_endless), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_1[173] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,
0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x63,0x01,0x58,0x02,0x06,0x5f,0x01,0x06,0x63,0x01,0x58,0x02,
0x07,0x5f,0x01,0x07,0x63,0x01,0x58,0x02,0x08,0x5f,0x01,0x08,0x63,0x01,0x58,0x02,0x09,0x5f,0x01,0x09,
0x63,0x01,0x58,0x02,0x0a,0x5f,0x01,0x0a,0x63,0x01,0x58,0x02,0x0b,0x5f,0x01,0x0b,0x63,0x01,0x58,0x02,
0x0c,0x5f,0x01,0x0c,0x63,0x01,0x58,0x02,0x0d,0x5f,0x01,0x0d,0x63,0x01,0x58,0x02,0x0e,0x5f,0x01,0x0e,
0x63,0x01,0x58,0x02,0x0f,0x5f,0x01,0x0f,0x63,0x01,0x58,0x02,0x10,0x5f,0x01,0x10,0x60,0x11,0x10,0x63,
0x01,0x58,0x02,0x11,0x5f,0x01,0x12,0x63,0x01,0x58,0x02,0x12,0x5f,0x01,0x13,0x63,0x01,0x58,0x02,0x13,
0x5f,0x01,0x14,0x63,0x01,0x58,0x02,0x14,0x5f,0x01,0x15,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_1 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_1,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_1,gem_mrblib_mruby_string_ext_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  173,0,22,21,0
};
static const mrb_irep *gem_mrblib_mruby_string_ext_proc_reps_0[1] = {
  &gem_mrblib_mruby_string_ext_proc_irep_1,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_string_ext_proc_syms_0, 1, (MRB_SYM(String), ), const);
static const mrb_code gem_mrblib_mruby_string_ext_proc_iseq_0[13] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_string_ext_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_string_ext_proc_iseq_0,
  NULL,gem_mrblib_mruby_string_ext_proc_syms_0,gem_mrblib_mruby_string_ext_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  13,0,1,1,0
};
static
const struct RProc gem_mrblib_mruby_string_ext_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_string_ext_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_string_ext_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_string_ext_gem_init(mrb_state *mrb);
void mrb_mruby_string_ext_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_string_ext_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_string_ext_proc_init_syms(mrb);
  mrb_mruby_string_ext_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_string_ext_proc);
}

void GENERATED_TMP_mrb_mruby_string_ext_gem_final(mrb_state *mrb) {
  mrb_mruby_string_ext_gem_final(mrb);
}
