/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_10[3] = {
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x49\x4e\x45\x54"}},
{IREP_TT_STR|(8<<2), {"\x41\x46\x5f\x49\x4e\x45\x54\x36"}},
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x55\x4e\x49\x58"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_10, 13, (MRB_SYM(PF_UNSPEC), MRB_SYM(Socket), MRB_IVSYM(hostname), MRB_SYM(Array), MRB_SYM_Q(is_a), MRB_SYM(sockaddr_in), MRB_IVSYM(sockaddr), MRB_SYM(sockaddr_un), MRB_SYM(dup), MRB_SYM(_sockaddr_family), MRB_IVSYM(family), MRB_IVSYM(socktype), MRB_IVSYM(protocol), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_10[222] = {
0x34,0x04,0x60,0x00,0x25,0x00,0x09,0x25,0x00,0x0f,0x25,0x00,0x0e,0x25,0x00,0x0d,0x1d,0x07,0x01,0x1f,
0x07,0x00,0x01,0x02,0x07,0x06,0x03,0x06,0x04,0x11,0x07,0x1a,0x07,0x02,0x01,0x07,0x01,0x1d,0x08,0x03,
0x2f,0x07,0x04,0x01,0x27,0x07,0x00,0x6c,0x01,0x06,0x01,0x01,0x07,0x06,0x06,0x08,0x23,0x07,0x51,0x08,
0x00,0x42,0x07,0x26,0x07,0x00,0x0c,0x01,0x07,0x06,0x06,0x08,0x23,0x07,0x51,0x08,0x01,0x42,0x07,0x27,
0x07,0x00,0x25,0x1d,0x07,0x01,0x01,0x08,0x06,0x07,0x09,0x23,0x08,0x01,0x09,0x06,0x09,0x0a,0x23,0x09,
0x2f,0x07,0x05,0x02,0x1a,0x07,0x06,0x01,0x07,0x06,0x08,0x08,0x23,0x07,0x1a,0x07,0x02,0x25,0x00,0x21,
0x01,0x07,0x06,0x06,0x08,0x23,0x07,0x51,0x08,0x02,0x42,0x07,0x27,0x07,0x00,0x11,0x1d,0x07,0x01,0x01,
0x08,0x06,0x07,0x09,0x23,0x08,0x2f,0x07,0x07,0x01,0x1a,0x07,0x06,0x25,0x00,0x0a,0x01,0x07,0x01,0x2f,
0x07,0x08,0x00,0x1a,0x07,0x06,0x01,0x07,0x02,0x1d,0x08,0x01,0x1f,0x08,0x00,0x42,0x07,0x26,0x07,0x00,
0x07,0x01,0x07,0x02,0x11,0x08,0x42,0x07,0x27,0x07,0x00,0x10,0x1d,0x07,0x01,0x19,0x08,0x06,0x2f,0x07,
0x09,0x01,0x1a,0x07,0x0a,0x25,0x00,0x03,0x1a,0x02,0x0a,0x1a,0x03,0x0b,0x01,0x07,0x04,0x1a,0x07,0x0c,
0x38,0x07,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_10, 6, (MRB_SYM(sockaddr), MRB_SYM(family), MRB_SYM(socktype), MRB_SYM(protocol), 0,MRB_SYM(sary), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_10 = {
  7,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_10,
  gem_mrblib_mruby_socket_proc_pool_10,gem_mrblib_mruby_socket_proc_syms_10,NULL,
  gem_mrblib_mruby_socket_proc_lv_10,
  NULL,					/* debug_info */
  222,3,13,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_48, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_48[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x07,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_48, 2, (MRB_SYM(ai), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_48 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_48,
  NULL,gem_mrblib_mruby_socket_proc_syms_48,NULL,
  gem_mrblib_mruby_socket_proc_lv_48,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_11[1] = {
  &gem_mrblib_mruby_socket_proc_irep_48,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_11, 2, (MRB_SYM(getaddrinfo), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_11[66] = {
0x34,0x08,0x80,0x01,0x25,0x00,0x0c,0x25,0x00,0x0b,0x25,0x00,0x0a,0x25,0x00,0x09,0x25,0x00,0x08,0x11,
0x03,0x11,0x04,0x11,0x05,0x06,0x06,0x12,0x09,0x01,0x0a,0x01,0x01,0x0b,0x02,0x01,0x0c,0x03,0x01,0x0d,
0x04,0x01,0x0e,0x05,0x01,0x0f,0x06,0x2f,0x09,0x00,0x06,0x01,0x08,0x09,0x01,0x09,0x08,0x57,0x0a,0x00,
0x30,0x09,0x01,0x00,0x38,0x08,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_11, 8, (MRB_SYM(nodename), MRB_SYM(service), MRB_SYM(family), MRB_SYM(socktype), MRB_SYM(protocol), MRB_SYM(flags), MRB_SYM(block), MRB_SYM(a), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_11 = {
  9,17,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_11,
  NULL,gem_mrblib_mruby_socket_proc_syms_11,gem_mrblib_mruby_socket_proc_reps_11,
  gem_mrblib_mruby_socket_proc_lv_11,
  NULL,					/* debug_info */
  66,0,2,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_12, 4, (MRB_SYM(Addrinfo), MRB_SYM(Socket), MRB_SYM(sockaddr_in), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_12[25] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x1d,0x04,0x01,0x06,0x05,0x01,0x06,0x01,0x2f,0x04,0x02,0x02,0x2f,
0x03,0x03,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_12, 2, (MRB_SYM(host), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_12 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_12,
  NULL,gem_mrblib_mruby_socket_proc_syms_12,NULL,
  gem_mrblib_mruby_socket_proc_lv_12,
  NULL,					/* debug_info */
  25,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_13, 5, (MRB_SYM(Addrinfo), MRB_SYM(SOCK_STREAM), MRB_SYM(Socket), MRB_SYM(IPPROTO_TCP), MRB_SYM(getaddrinfo), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_13[37] = {
0x34,0x08,0x00,0x00,0x1d,0x04,0x00,0x01,0x05,0x01,0x01,0x06,0x02,0x11,0x07,0x1d,0x08,0x02,0x1f,0x08,
0x01,0x1d,0x09,0x02,0x1f,0x09,0x03,0x2f,0x04,0x04,0x05,0x06,0x05,0x23,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_13, 3, (MRB_SYM(host), MRB_SYM(port), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_13 = {
  4,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_13,
  NULL,gem_mrblib_mruby_socket_proc_syms_13,NULL,
  gem_mrblib_mruby_socket_proc_lv_13,
  NULL,					/* debug_info */
  37,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_14, 5, (MRB_SYM(Addrinfo), MRB_SYM(SOCK_DGRAM), MRB_SYM(Socket), MRB_SYM(IPPROTO_UDP), MRB_SYM(getaddrinfo), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_14[37] = {
0x34,0x08,0x00,0x00,0x1d,0x04,0x00,0x01,0x05,0x01,0x01,0x06,0x02,0x11,0x07,0x1d,0x08,0x02,0x1f,0x08,
0x01,0x1d,0x09,0x02,0x1f,0x09,0x03,0x2f,0x04,0x04,0x05,0x06,0x05,0x23,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_14, 3, (MRB_SYM(host), MRB_SYM(port), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_14 = {
  4,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_14,
  NULL,gem_mrblib_mruby_socket_proc_syms_14,NULL,
  gem_mrblib_mruby_socket_proc_lv_14,
  NULL,					/* debug_info */
  37,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_15, 6, (MRB_SYM(SOCK_STREAM), MRB_SYM(Socket), MRB_SYM(Addrinfo), MRB_SYM(sockaddr_un), MRB_SYM(AF_UNIX), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_15[47] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x09,0x1d,0x04,0x01,0x1f,0x04,0x00,0x01,0x02,0x04,0x1d,
0x04,0x02,0x1d,0x05,0x01,0x01,0x06,0x01,0x2f,0x05,0x03,0x01,0x1d,0x06,0x01,0x1f,0x06,0x04,0x01,0x07,
0x02,0x2f,0x04,0x05,0x03,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_15, 3, (MRB_SYM(path), MRB_SYM(socktype), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_15 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_15,
  NULL,gem_mrblib_mruby_socket_proc_syms_15,NULL,
  gem_mrblib_mruby_socket_proc_lv_15,
  NULL,					/* debug_info */
  47,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_16, 1, (MRB_IVSYM(family), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_16[9] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_16, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_16 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_16,
  NULL,gem_mrblib_mruby_socket_proc_syms_16,NULL,
  gem_mrblib_mruby_socket_proc_lv_16,
  NULL,					/* debug_info */
  9,0,1,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_17[7] = {
{IREP_TT_STR|(3<<2), {"\x54\x43\x50"}},
{IREP_TT_STR|(3<<2), {"\x55\x44\x50"}},
{IREP_TT_STR|(3<<2), {"\x3f\x3f\x3f"}},
{IREP_TT_STR|(11<<2), {"\x53\x4f\x43\x4b\x5f\x53\x54\x52\x45\x41\x4d"}},
{IREP_TT_STR|(12<<2), {"\x23\x3c\x41\x64\x64\x72\x69\x6e\x66\x6f\x3a\x20"}},
{IREP_TT_STR|(1<<2), {"\x20"}},
{IREP_TT_STR|(1<<2), {"\x3e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_17, 10, (MRB_SYM_Q(ipv4), MRB_SYM_Q(ipv6), MRB_IVSYM(protocol), MRB_SYM(IPPROTO_TCP), MRB_SYM(Socket), MRB_IVSYM(socktype), MRB_SYM(SOCK_STREAM), MRB_SYM(IPPROTO_UDP), MRB_SYM(SOCK_DGRAM), MRB_SYM(inspect_sockaddr), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_17[149] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x26,0x03,0x00,0x04,0x2d,0x03,0x01,0x00,0x27,0x03,0x00,0x64,
0x19,0x03,0x02,0x1d,0x04,0x04,0x1f,0x04,0x03,0x42,0x03,0x26,0x03,0x00,0x16,0x19,0x03,0x05,0x1d,0x04,
0x04,0x1f,0x04,0x06,0x42,0x03,0x27,0x03,0x00,0x07,0x19,0x03,0x02,0x06,0x04,0x42,0x03,0x27,0x03,0x00,
0x06,0x51,0x02,0x00,0x25,0x00,0x32,0x19,0x03,0x02,0x1d,0x04,0x04,0x1f,0x04,0x07,0x42,0x03,0x26,0x03,
0x00,0x16,0x19,0x03,0x05,0x1d,0x04,0x04,0x1f,0x04,0x08,0x42,0x03,0x27,0x03,0x00,0x07,0x19,0x03,0x02,
0x06,0x04,0x42,0x03,0x27,0x03,0x00,0x06,0x51,0x02,0x01,0x25,0x00,0x03,0x51,0x02,0x02,0x25,0x00,0x03,
0x51,0x02,0x03,0x51,0x03,0x04,0x2d,0x04,0x09,0x00,0x52,0x03,0x51,0x04,0x05,0x52,0x03,0x01,0x04,0x02,
0x52,0x03,0x51,0x04,0x06,0x52,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_17, 2, (0,MRB_SYM(proto), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_17 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_17,
  gem_mrblib_mruby_socket_proc_pool_17,gem_mrblib_mruby_socket_proc_syms_17,NULL,
  gem_mrblib_mruby_socket_proc_lv_17,
  NULL,					/* debug_info */
  149,7,10,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_18[5] = {
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(1<<2), {"\x3a"}},
{IREP_TT_STR|(1<<2), {"\x5b"}},
{IREP_TT_STR|(2<<2), {"\x5d\x3a"}},
{IREP_TT_STR|(3<<2), {"\x3f\x3f\x3f"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_18, 5, (MRB_SYM_Q(ipv4), MRB_SYM(ip_unpack), MRB_SYM_Q(ipv6), MRB_SYM_Q(unix), MRB_SYM(unix_path), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_18[106] = {
0x34,0x00,0x00,0x00,0x2d,0x04,0x00,0x00,0x27,0x04,0x00,0x21,0x2d,0x04,0x01,0x00,0x4c,0x02,0x04,0x00,
0x4c,0x03,0x04,0x01,0x51,0x04,0x00,0x01,0x05,0x02,0x52,0x04,0x51,0x05,0x01,0x52,0x04,0x01,0x05,0x03,
0x52,0x04,0x25,0x00,0x3b,0x2d,0x04,0x02,0x00,0x27,0x04,0x00,0x21,0x2d,0x04,0x01,0x00,0x4c,0x02,0x04,
0x00,0x4c,0x03,0x04,0x01,0x51,0x04,0x02,0x01,0x05,0x02,0x52,0x04,0x51,0x05,0x03,0x52,0x04,0x01,0x05,
0x03,0x52,0x04,0x25,0x00,0x12,0x2d,0x04,0x03,0x00,0x27,0x04,0x00,0x07,0x2d,0x04,0x04,0x00,0x25,0x00,
0x03,0x51,0x04,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_18, 3, (0,MRB_SYM(a), MRB_SYM(p), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_18 = {
  4,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_18,
  gem_mrblib_mruby_socket_proc_pool_18,gem_mrblib_mruby_socket_proc_syms_18,NULL,
  gem_mrblib_mruby_socket_proc_lv_18,
  NULL,					/* debug_info */
  106,5,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_19, 2, (MRB_SYM_Q(ipv4), MRB_SYM_Q(ipv6), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_19[18] = {
0x34,0x00,0x00,0x00,0x2d,0x02,0x00,0x00,0x26,0x02,0x00,0x04,0x2d,0x02,0x01,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_19, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_19 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_19,
  NULL,gem_mrblib_mruby_socket_proc_syms_19,NULL,
  gem_mrblib_mruby_socket_proc_lv_19,
  NULL,					/* debug_info */
  18,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_20, 1, (MRB_SYM(ip_unpack), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_20[14] = {
0x34,0x00,0x00,0x00,0x2d,0x02,0x00,0x00,0x06,0x03,0x23,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_20, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_20 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_20,
  NULL,gem_mrblib_mruby_socket_proc_syms_20,NULL,
  gem_mrblib_mruby_socket_proc_lv_20,
  NULL,					/* debug_info */
  14,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_21, 1, (MRB_SYM(ip_unpack), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_21[14] = {
0x34,0x00,0x00,0x00,0x2d,0x02,0x00,0x00,0x07,0x03,0x23,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_21, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_21 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_21,
  NULL,gem_mrblib_mruby_socket_proc_syms_21,NULL,
  gem_mrblib_mruby_socket_proc_lv_21,
  NULL,					/* debug_info */
  14,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_22, 6, (MRB_SYM(NI_NUMERICHOST), MRB_SYM(Socket), MRB_SYM(NI_NUMERICSERV), MRB_OPSYM(or), MRB_SYM(getnameinfo), MRB_SYM(to_i), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_22[47] = {
0x34,0x00,0x00,0x00,0x1d,0x05,0x01,0x1f,0x05,0x00,0x1d,0x06,0x01,0x1f,0x06,0x02,0x2f,0x05,0x03,0x01,
0x2d,0x04,0x04,0x01,0x4c,0x02,0x04,0x00,0x4c,0x03,0x04,0x01,0x01,0x04,0x02,0x01,0x05,0x03,0x2f,0x05,
0x05,0x00,0x47,0x04,0x02,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_22, 3, (0,MRB_SYM(h), MRB_SYM(p), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_22 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_22,
  NULL,gem_mrblib_mruby_socket_proc_syms_22,NULL,
  gem_mrblib_mruby_socket_proc_lv_22,
  NULL,					/* debug_info */
  47,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_23, 3, (MRB_IVSYM(family), MRB_SYM(AF_INET), MRB_SYM(Socket), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_23[17] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x1d,0x03,0x02,0x1f,0x03,0x01,0x42,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_23, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_23 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_23,
  NULL,gem_mrblib_mruby_socket_proc_syms_23,NULL,
  gem_mrblib_mruby_socket_proc_lv_23,
  NULL,					/* debug_info */
  17,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_24, 3, (MRB_IVSYM(family), MRB_SYM(AF_INET6), MRB_SYM(Socket), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_24[17] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x1d,0x03,0x02,0x1f,0x03,0x01,0x42,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_24, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_24 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_24,
  NULL,gem_mrblib_mruby_socket_proc_syms_24,NULL,
  gem_mrblib_mruby_socket_proc_lv_24,
  NULL,					/* debug_info */
  17,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_25, 1, (MRB_IVSYM(family), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_25[9] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_25, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_25 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_25,
  NULL,gem_mrblib_mruby_socket_proc_syms_25,NULL,
  gem_mrblib_mruby_socket_proc_lv_25,
  NULL,					/* debug_info */
  9,0,1,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_26[4] = {
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x49\x4e\x45\x54"}},
{IREP_TT_STR|(8<<2), {"\x41\x46\x5f\x49\x4e\x45\x54\x36"}},
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x55\x4e\x49\x58"}},
{IREP_TT_STR|(12<<2), {"\x28\x75\x6e\x6b\x6e\x6f\x77\x6e\x20\x41\x46\x29"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_26, 11, (MRB_IVSYM(family), MRB_SYM(AF_INET), MRB_SYM(Socket), MRB_OPSYM(eqq), MRB_SYM(AF_INET6), MRB_SYM(AF_UNIX), MRB_SYM(NI_NUMERICHOST), MRB_SYM(NI_NUMERICSERV), MRB_OPSYM(or), MRB_SYM(getnameinfo), MRB_SYM(to_i), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_26[142] = {
0x34,0x00,0x00,0x00,0x19,0x05,0x00,0x1d,0x06,0x02,0x1f,0x06,0x01,0x01,0x07,0x05,0x2f,0x06,0x03,0x01,
0x26,0x06,0x00,0x03,0x25,0x00,0x06,0x51,0x02,0x00,0x25,0x00,0x3a,0x1d,0x06,0x02,0x1f,0x06,0x04,0x01,
0x07,0x05,0x2f,0x06,0x03,0x01,0x26,0x06,0x00,0x03,0x25,0x00,0x06,0x51,0x02,0x01,0x25,0x00,0x20,0x1d,
0x06,0x02,0x1f,0x06,0x05,0x01,0x07,0x05,0x2f,0x06,0x03,0x01,0x26,0x06,0x00,0x03,0x25,0x00,0x06,0x51,
0x02,0x02,0x25,0x00,0x06,0x51,0x02,0x03,0x25,0x00,0x00,0x12,0x05,0x1d,0x06,0x02,0x1f,0x06,0x06,0x1d,
0x07,0x02,0x1f,0x07,0x07,0x2f,0x06,0x08,0x01,0x2f,0x05,0x09,0x01,0x4c,0x03,0x05,0x00,0x4c,0x04,0x05,
0x01,0x01,0x05,0x02,0x01,0x06,0x04,0x2f,0x06,0x0a,0x00,0x01,0x07,0x03,0x01,0x08,0x03,0x47,0x05,0x04,
0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_26, 4, (0,MRB_SYM(s), MRB_SYM(addr), MRB_SYM(port), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_26 = {
  5,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_26,
  gem_mrblib_mruby_socket_proc_pool_26,gem_mrblib_mruby_socket_proc_syms_26,NULL,
  gem_mrblib_mruby_socket_proc_lv_26,
  NULL,					/* debug_info */
  142,4,11,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_27, 1, (MRB_IVSYM(sockaddr), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_27[9] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_27, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_27 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_27,
  NULL,gem_mrblib_mruby_socket_proc_syms_27,NULL,
  gem_mrblib_mruby_socket_proc_lv_27,
  NULL,					/* debug_info */
  9,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_28, 3, (MRB_IVSYM(family), MRB_SYM(AF_UNIX), MRB_SYM(Socket), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_28[17] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x1d,0x03,0x02,0x1f,0x03,0x01,0x42,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_28, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_28 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_28,
  NULL,gem_mrblib_mruby_socket_proc_syms_28,NULL,
  gem_mrblib_mruby_socket_proc_lv_28,
  NULL,					/* debug_info */
  17,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_1[19] = {
  &gem_mrblib_mruby_socket_proc_irep_10,
  &gem_mrblib_mruby_socket_proc_irep_11,
  &gem_mrblib_mruby_socket_proc_irep_12,
  &gem_mrblib_mruby_socket_proc_irep_13,
  &gem_mrblib_mruby_socket_proc_irep_14,
  &gem_mrblib_mruby_socket_proc_irep_15,
  &gem_mrblib_mruby_socket_proc_irep_16,
  &gem_mrblib_mruby_socket_proc_irep_17,
  &gem_mrblib_mruby_socket_proc_irep_18,
  &gem_mrblib_mruby_socket_proc_irep_19,
  &gem_mrblib_mruby_socket_proc_irep_20,
  &gem_mrblib_mruby_socket_proc_irep_21,
  &gem_mrblib_mruby_socket_proc_irep_22,
  &gem_mrblib_mruby_socket_proc_irep_23,
  &gem_mrblib_mruby_socket_proc_irep_24,
  &gem_mrblib_mruby_socket_proc_irep_25,
  &gem_mrblib_mruby_socket_proc_irep_26,
  &gem_mrblib_mruby_socket_proc_irep_27,
  &gem_mrblib_mruby_socket_proc_irep_28,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_1, 23, (MRB_SYM(initialize), MRB_SYM(foreach), MRB_SYM(ip), MRB_SYM(tcp), MRB_SYM(udp), MRB_SYM(unix), MRB_SYM(afamily), MRB_SYM(inspect), MRB_SYM(inspect_sockaddr), MRB_SYM_Q(ip), MRB_SYM(ip_address), MRB_SYM(ip_port), MRB_SYM(ip_unpack), MRB_SYM_Q(ipv4), MRB_SYM_Q(ipv6), MRB_SYM(pfamily), MRB_SYM(protocol), MRB_SYM(attr_reader), MRB_SYM(socktype), MRB_SYM(_to_array), MRB_SYM(to_sockaddr), MRB_SYM(to_s), MRB_SYM_Q(unix), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_1[181] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x12,0x01,0x62,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x12,0x01,
0x62,0x01,0x58,0x02,0x02,0x5f,0x01,0x02,0x12,0x01,0x62,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x12,0x01,
0x62,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,0x12,0x01,0x62,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x63,0x01,
0x58,0x02,0x06,0x5f,0x01,0x06,0x63,0x01,0x58,0x02,0x07,0x5f,0x01,0x07,0x63,0x01,0x58,0x02,0x08,0x5f,
0x01,0x08,0x63,0x01,0x58,0x02,0x09,0x5f,0x01,0x09,0x63,0x01,0x58,0x02,0x0a,0x5f,0x01,0x0a,0x63,0x01,
0x58,0x02,0x0b,0x5f,0x01,0x0b,0x63,0x01,0x58,0x02,0x0c,0x5f,0x01,0x0c,0x63,0x01,0x58,0x02,0x0d,0x5f,
0x01,0x0d,0x63,0x01,0x58,0x02,0x0e,0x5f,0x01,0x0e,0x63,0x01,0x58,0x02,0x0f,0x5f,0x01,0x0f,0x10,0x02,
0x10,0x2d,0x01,0x11,0x01,0x10,0x02,0x12,0x2d,0x01,0x11,0x01,0x63,0x01,0x58,0x02,0x10,0x5f,0x01,0x13,
0x63,0x01,0x58,0x02,0x11,0x5f,0x01,0x14,0x60,0x15,0x14,0x63,0x01,0x58,0x02,0x12,0x5f,0x01,0x16,0x38,
0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_1 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_1,
  NULL,gem_mrblib_mruby_socket_proc_syms_1,gem_mrblib_mruby_socket_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  181,0,23,19,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_381, 1, (MRB_CVSYM(do_not_reverse_lookup), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_381[9] = {
0x34,0x00,0x00,0x00,0x1b,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_381, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_381 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_381,
  NULL,gem_mrblib_mruby_socket_proc_syms_381,NULL,
  gem_mrblib_mruby_socket_proc_lv_381,
  NULL,					/* debug_info */
  9,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_382, 1, (MRB_CVSYM(do_not_reverse_lookup), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_382[23] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x27,0x03,0x00,0x05,0x13,0x03,0x25,0x00,0x02,0x14,0x03,0x1c,0x03,
0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_382, 2, (MRB_SYM(val), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_382 = {
  3,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_382,
  NULL,gem_mrblib_mruby_socket_proc_syms_382,NULL,
  gem_mrblib_mruby_socket_proc_lv_382,
  NULL,					/* debug_info */
  23,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_383, 3, (MRB_SYM_E(_is_socket), MRB_CVSYM(do_not_reverse_lookup), MRB_IVSYM(do_not_reverse_lookup), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_383[33] = {
0x34,0x00,0x10,0x00,0x11,0x04,0x01,0x05,0x01,0x49,0x04,0x01,0x05,0x02,0x32,0x03,0x0f,0x12,0x03,0x13,
0x04,0x2f,0x03,0x00,0x01,0x1b,0x03,0x01,0x1a,0x03,0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_383, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_383 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_383,
  NULL,gem_mrblib_mruby_socket_proc_syms_383,NULL,
  gem_mrblib_mruby_socket_proc_lv_383,
  NULL,					/* debug_info */
  33,0,3,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_384[1] = {
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_384[18] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x51,0x05,0x00,0x01,0x06,0x02,0x32,0x03,0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_384, 2, (MRB_SYM(fd), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_384 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_384,
  gem_mrblib_mruby_socket_proc_pool_384,NULL,NULL,
  gem_mrblib_mruby_socket_proc_lv_384,
  NULL,					/* debug_info */
  18,1,0,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_385, 3, (MRB_SYM(Addrinfo), MRB_SYM(getsockname), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_385[19] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_385, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_385 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_385,
  NULL,gem_mrblib_mruby_socket_proc_syms_385,NULL,
  gem_mrblib_mruby_socket_proc_lv_385,
  NULL,					/* debug_info */
  19,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_386, 2, (MRB_SYM(_setnonblock), MRB_SYM(recv), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_386[53] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x06,0x02,0x13,0x05,0x2d,0x04,0x00,0x01,0x01,0x05,
0x01,0x01,0x06,0x02,0x2d,0x04,0x01,0x02,0x2a,0x06,0x14,0x08,0x2d,0x07,0x00,0x01,0x2c,0x06,0x38,0x04,
0x01,0x00,0x00,0x00,0x0c,0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x1c,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_386, 3, (MRB_SYM(maxlen), MRB_SYM(flags), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_386 = {
  4,10,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_386,
  NULL,gem_mrblib_mruby_socket_proc_syms_386,NULL,
  gem_mrblib_mruby_socket_proc_lv_386,
  NULL,					/* debug_info */
  40,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_387, 3, (MRB_SYM(Addrinfo), MRB_SYM(getpeername), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_387[19] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_387, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_387 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_387,
  NULL,gem_mrblib_mruby_socket_proc_syms_387,NULL,
  gem_mrblib_mruby_socket_proc_lv_387,
  NULL,					/* debug_info */
  19,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_2[7] = {
  &gem_mrblib_mruby_socket_proc_irep_381,
  &gem_mrblib_mruby_socket_proc_irep_382,
  &gem_mrblib_mruby_socket_proc_irep_383,
  &gem_mrblib_mruby_socket_proc_irep_384,
  &gem_mrblib_mruby_socket_proc_irep_385,
  &gem_mrblib_mruby_socket_proc_irep_386,
  &gem_mrblib_mruby_socket_proc_irep_387,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_2, 9, (MRB_CVSYM(do_not_reverse_lookup), MRB_SYM(do_not_reverse_lookup), MRB_SYM_E(do_not_reverse_lookup), MRB_SYM(initialize), MRB_SYM(for_fd), MRB_SYM(local_address), MRB_SYM(recv_nonblock), MRB_SYM(remote_address), MRB_SYM(attr_accessor), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_2[76] = {
0x13,0x01,0x1c,0x01,0x00,0x12,0x01,0x62,0x01,0x58,0x02,0x00,0x5f,0x01,0x01,0x12,0x01,0x62,0x01,0x58,
0x02,0x01,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x02,0x5f,0x01,0x03,0x12,0x01,0x62,0x01,0x58,0x02,0x03,
0x5f,0x01,0x04,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x05,0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x06,0x63,
0x01,0x58,0x02,0x06,0x5f,0x01,0x07,0x10,0x02,0x01,0x2d,0x01,0x08,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_2 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_2,
  NULL,gem_mrblib_mruby_socket_proc_syms_2,gem_mrblib_mruby_socket_proc_reps_2,
  NULL,					/* lv */
  NULL,					/* debug_info */
  76,0,9,7,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_439, 3, (MRB_SYM(Addrinfo), MRB_SYM(ip), MRB_SYM(ip_address), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_439[20] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x2f,0x03,0x02,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_439, 2, (MRB_SYM(host), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_439 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_439,
  NULL,gem_mrblib_mruby_socket_proc_syms_439,NULL,
  gem_mrblib_mruby_socket_proc_lv_439,
  NULL,					/* debug_info */
  20,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_440, 4, (MRB_SYM(Addrinfo), MRB_SYM(getsockname), MRB_SYM(new), MRB_SYM(_to_array), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_440[23] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x2f,0x02,0x03,
0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_440, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_440 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_440,
  NULL,gem_mrblib_mruby_socket_proc_syms_440,NULL,
  gem_mrblib_mruby_socket_proc_lv_440,
  NULL,					/* debug_info */
  23,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_441, 4, (MRB_SYM(Addrinfo), MRB_SYM(getpeername), MRB_SYM(new), MRB_SYM(_to_array), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_441[23] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x2f,0x02,0x03,
0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_441, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_441 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_441,
  NULL,gem_mrblib_mruby_socket_proc_syms_441,NULL,
  gem_mrblib_mruby_socket_proc_lv_441,
  NULL,					/* debug_info */
  23,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_442, 4, (MRB_SYM(_recvfrom), MRB_SYM(Addrinfo), MRB_SYM(new), MRB_SYM(_to_array), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_442[52] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x06,0x02,0x01,0x07,0x01,0x01,0x08,0x02,0x2d,0x06,
0x00,0x02,0x4c,0x04,0x06,0x00,0x4c,0x05,0x06,0x01,0x01,0x06,0x04,0x1d,0x07,0x01,0x01,0x08,0x05,0x2f,
0x07,0x02,0x01,0x2f,0x07,0x03,0x00,0x47,0x06,0x02,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_442, 5, (MRB_SYM(maxlen), MRB_SYM(flags), 0,MRB_SYM(msg), MRB_SYM(sa), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_442 = {
  6,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_442,
  NULL,gem_mrblib_mruby_socket_proc_syms_442,NULL,
  gem_mrblib_mruby_socket_proc_lv_442,
  NULL,					/* debug_info */
  52,0,4,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_3[4] = {
  &gem_mrblib_mruby_socket_proc_irep_439,
  &gem_mrblib_mruby_socket_proc_irep_440,
  &gem_mrblib_mruby_socket_proc_irep_441,
  &gem_mrblib_mruby_socket_proc_irep_442,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_3, 4, (MRB_SYM(getaddress), MRB_SYM(addr), MRB_SYM(peeraddr), MRB_SYM(recvfrom), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_3[36] = {
0x12,0x01,0x62,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,
0x58,0x02,0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_3 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_3,
  NULL,gem_mrblib_mruby_socket_proc_syms_3,gem_mrblib_mruby_socket_proc_reps_3,
  NULL,					/* lv */
  NULL,					/* debug_info */
  36,0,4,4,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_466[4] = {
{IREP_TT_STR|(7<<2), {"\x30\x2e\x30\x2e\x30\x2e\x30"}},
{IREP_TT_STR|(2<<2), {"\x3a\x3a"}},
{IREP_TT_STR|(1<<2), {"\x30"}},
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_466, 12, (MRB_SYM(Socket), MRB_SYM(afamily), MRB_SYM(SOCK_STREAM), MRB_SYM(_socket), MRB_SYM(AF_INET), MRB_SYM(Addrinfo), MRB_SYM(socktype), MRB_SYM(getaddrinfo), MRB_SYM(to_sockaddr), MRB_SYM(_bind), MRB_SYM(_connect), MRB_SYM(StandardError), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_466[236] = {
0x34,0x04,0x00,0x00,0x1d,0x05,0x00,0x01,0x06,0x01,0x2f,0x06,0x01,0x00,0x1d,0x07,0x00,0x1f,0x07,0x02,
0x06,0x08,0x2f,0x05,0x03,0x03,0x22,0x05,0x06,0x00,0x21,0x05,0x03,0x00,0x26,0x05,0x00,0x04,0x21,0x05,
0x04,0x00,0x27,0x05,0x00,0x6d,0x21,0x05,0x03,0x00,0x26,0x05,0x00,0x20,0x01,0x05,0x01,0x2f,0x05,0x01,
0x00,0x1d,0x06,0x00,0x1f,0x06,0x04,0x42,0x05,0x27,0x05,0x00,0x06,0x51,0x05,0x00,0x25,0x00,0x03,0x51,
0x05,0x01,0x22,0x05,0x03,0x00,0x21,0x05,0x04,0x00,0x26,0x05,0x00,0x07,0x51,0x05,0x02,0x22,0x05,0x04,
0x00,0x1d,0x05,0x05,0x21,0x06,0x03,0x00,0x21,0x07,0x04,0x00,0x01,0x08,0x01,0x2f,0x08,0x01,0x00,0x01,
0x09,0x01,0x2f,0x09,0x06,0x00,0x2f,0x05,0x07,0x04,0x06,0x06,0x23,0x05,0x01,0x03,0x05,0x1d,0x05,0x00,
0x21,0x06,0x06,0x00,0x01,0x07,0x03,0x2f,0x07,0x08,0x00,0x2f,0x05,0x09,0x02,0x1d,0x05,0x00,0x21,0x06,
0x06,0x00,0x01,0x07,0x01,0x2f,0x07,0x08,0x00,0x2f,0x05,0x0a,0x02,0x21,0x06,0x06,0x00,0x51,0x07,0x03,
0x21,0x08,0x05,0x01,0x32,0x05,0x02,0x11,0x05,0x39,0x05,0x25,0x00,0x1b,0x2a,0x05,0x1d,0x06,0x0b,0x2b,
0x05,0x06,0x26,0x06,0x00,0x03,0x25,0x00,0x0a,0x01,0x04,0x05,0x22,0x04,0x07,0x00,0x25,0x00,0x02,0x2c,
0x05,0x38,0x05,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0xbf,0x00,0x00,0x00,0xc2,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_466, 4, (MRB_SYM(ai), 0,MRB_SYM(bi), MRB_SYM(e0), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_466 = {
  5,11,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_466,
  gem_mrblib_mruby_socket_proc_pool_466,gem_mrblib_mruby_socket_proc_syms_466,NULL,
  gem_mrblib_mruby_socket_proc_lv_466,
  NULL,					/* debug_info */
  223,4,12,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_464[1] = {
  &gem_mrblib_mruby_socket_proc_irep_466,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_464, 5, (MRB_IVSYM(init_with_fd), MRB_SYM(SocketError), MRB_SYM(Addrinfo), MRB_SYM(foreach), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_464[69] = {
0x34,0x08,0x40,0x00,0x25,0x00,0x06,0x25,0x00,0x05,0x25,0x00,0x04,0x11,0x03,0x11,0x04,0x19,0x08,0x00,
0x27,0x08,0x00,0x0f,0x01,0x09,0x01,0x01,0x0a,0x02,0x01,0x0b,0x05,0x32,0x08,0x02,0x25,0x00,0x1c,0x11,
0x06,0x1d,0x07,0x01,0x1d,0x08,0x02,0x01,0x09,0x01,0x01,0x0a,0x02,0x57,0x0b,0x00,0x30,0x08,0x03,0x02,
0x01,0x09,0x07,0x2d,0x08,0x04,0x01,0x38,0x08,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_464, 7, (MRB_SYM(host), MRB_SYM(service), MRB_SYM(local_host), MRB_SYM(local_service), 0,MRB_SYM(s), MRB_SYM(e), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_464 = {
  8,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_464,
  NULL,gem_mrblib_mruby_socket_proc_syms_464,gem_mrblib_mruby_socket_proc_reps_464,
  gem_mrblib_mruby_socket_proc_lv_464,
  NULL,					/* debug_info */
  69,0,5,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_465, 3, (MRB_SYM(_allocate), MRB_SYM(instance_eval), MRB_SYM(initialize), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_465[39] = {
0x34,0x00,0x10,0x01,0x12,0x04,0x2f,0x04,0x00,0x00,0x01,0x03,0x04,0x01,0x04,0x03,0x01,0x05,0x02,0x30,
0x04,0x01,0x00,0x01,0x04,0x03,0x11,0x05,0x01,0x06,0x01,0x49,0x05,0x2f,0x04,0x02,0x0f,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_465, 3, (MRB_SYM(args), MRB_SYM(pre), MRB_SYM(o), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_465 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_465,
  NULL,gem_mrblib_mruby_socket_proc_syms_465,NULL,
  gem_mrblib_mruby_socket_proc_lv_465,
  NULL,					/* debug_info */
  39,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_4[2] = {
  &gem_mrblib_mruby_socket_proc_irep_464,
  &gem_mrblib_mruby_socket_proc_irep_465,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_4, 2, (MRB_SYM(initialize), MRB_SYM(_new_with_prelude), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_4[20] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x12,0x01,0x62,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_4 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_4,
  NULL,gem_mrblib_mruby_socket_proc_syms_4,gem_mrblib_mruby_socket_proc_reps_4,
  NULL,					/* lv */
  NULL,					/* debug_info */
  20,0,2,2,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_478[1] = {
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_478, 16, (MRB_SYM(Addrinfo), MRB_SYM(AI_PASSIVE), MRB_SYM(Socket), MRB_SYM(getaddrinfo), MRB_IVSYM(init_with_fd), MRB_SYM(afamily), MRB_SYM(SOCK_STREAM), MRB_SYM(_socket), MRB_SYM(SO_REUSEADDR), MRB_SYM_Q(const_defined), MRB_SYM(SOL_SOCKET), MRB_SYM(setsockopt), MRB_SYM(fileno), MRB_SYM(to_sockaddr), MRB_SYM(_bind), MRB_SYM(listen), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_478[144] = {
0x34,0x00,0x20,0x80,0x25,0x00,0x03,0x25,0x00,0x02,0x11,0x01,0x1d,0x05,0x00,0x01,0x06,0x01,0x01,0x07,
0x02,0x11,0x08,0x11,0x09,0x11,0x0a,0x1d,0x0b,0x02,0x1f,0x0b,0x01,0x2f,0x05,0x03,0x06,0x06,0x06,0x23,
0x05,0x01,0x04,0x05,0x13,0x05,0x1a,0x05,0x04,0x1d,0x06,0x02,0x01,0x07,0x04,0x2f,0x07,0x05,0x00,0x1d,
0x08,0x02,0x1f,0x08,0x06,0x06,0x09,0x2f,0x06,0x07,0x03,0x51,0x07,0x00,0x01,0x08,0x03,0x32,0x05,0x02,
0x1d,0x05,0x02,0x10,0x06,0x08,0x2f,0x05,0x09,0x01,0x27,0x05,0x00,0x14,0x12,0x05,0x1d,0x06,0x02,0x1f,
0x06,0x0a,0x1d,0x07,0x02,0x1f,0x07,0x08,0x13,0x08,0x2f,0x05,0x0b,0x03,0x1d,0x05,0x02,0x12,0x06,0x2f,
0x06,0x0c,0x00,0x01,0x07,0x04,0x2f,0x07,0x0d,0x00,0x2f,0x05,0x0e,0x02,0x0b,0x06,0x2d,0x05,0x0f,0x01,
0x12,0x05,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_478, 4, (MRB_SYM(host), MRB_SYM(service), 0,MRB_SYM(ai), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_478 = {
  5,13,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_478,
  gem_mrblib_mruby_socket_proc_pool_478,gem_mrblib_mruby_socket_proc_syms_478,NULL,
  gem_mrblib_mruby_socket_proc_lv_478,
  NULL,					/* debug_info */
  144,1,16,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_488, 1, (MRB_IVSYM(init_with_fd), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_488[11] = {
0x34,0x00,0x00,0x00,0x13,0x02,0x1a,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_488, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_488 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_488,
  NULL,gem_mrblib_mruby_socket_proc_syms_488,NULL,
  gem_mrblib_mruby_socket_proc_lv_488,
  NULL,					/* debug_info */
  11,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_479[1] = {
  &gem_mrblib_mruby_socket_proc_irep_488,
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_479[1] = {
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_479, 7, (MRB_SYM(sysaccept), MRB_SYM(TCPSocket), MRB_SYM(_new_with_prelude), MRB_SYM(StandardError), MRB_SYM(IO), MRB_SYM(_sysclose), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_479[117] = {
0x34,0x00,0x00,0x00,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x1d,0x03,0x01,0x01,0x04,0x02,0x51,
0x05,0x00,0x57,0x06,0x00,0x30,0x03,0x02,0x02,0x25,0x00,0x39,0x2a,0x03,0x1d,0x04,0x03,0x2b,0x03,0x04,
0x26,0x04,0x00,0x03,0x25,0x00,0x28,0x1d,0x03,0x04,0x01,0x04,0x02,0x2f,0x03,0x05,0x01,0x25,0x00,0x14,
0x2a,0x03,0x1d,0x04,0x03,0x2b,0x03,0x04,0x26,0x04,0x00,0x03,0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x03,
0x2d,0x03,0x06,0x00,0x25,0x00,0x02,0x2c,0x03,0x38,0x03,0x00,0x00,0x00,0x00,0x0d,0x00,0x00,0x00,0x1d,
0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x2f,0x00,0x00,0x00,0x39,0x00,0x00,0x00,0x3c,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_479, 2, (0,MRB_SYM(fd), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_479 = {
  3,7,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_479,
  gem_mrblib_mruby_socket_proc_pool_479,gem_mrblib_mruby_socket_proc_syms_479,gem_mrblib_mruby_socket_proc_reps_479,
  gem_mrblib_mruby_socket_proc_lv_479,
  NULL,					/* debug_info */
  91,1,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_480, 2, (MRB_SYM(_setnonblock), MRB_SYM(accept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_480[45] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x13,0x03,0x2f,0x02,0x00,0x01,0x12,0x02,0x2f,0x02,0x01,0x00,0x2a,0x04,
0x12,0x05,0x14,0x06,0x2f,0x05,0x00,0x01,0x2c,0x04,0x38,0x02,0x01,0x00,0x00,0x00,0x04,0x00,0x00,0x00,
0x12,0x00,0x00,0x00,0x12,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_480, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_480 = {
  2,8,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_480,
  NULL,gem_mrblib_mruby_socket_proc_syms_480,NULL,
  gem_mrblib_mruby_socket_proc_lv_480,
  NULL,					/* debug_info */
  32,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_481, 3, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_listen), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_481[24] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,0x00,0x01,0x05,0x01,0x2f,0x03,0x02,0x02,
0x06,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_481, 2, (MRB_SYM(backlog), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_481 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_481,
  NULL,gem_mrblib_mruby_socket_proc_syms_481,NULL,
  gem_mrblib_mruby_socket_proc_lv_481,
  NULL,					/* debug_info */
  24,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_482, 3, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_accept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_482[19] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_482, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_482 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_482,
  NULL,gem_mrblib_mruby_socket_proc_syms_482,NULL,
  gem_mrblib_mruby_socket_proc_lv_482,
  NULL,					/* debug_info */
  19,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_5[5] = {
  &gem_mrblib_mruby_socket_proc_irep_478,
  &gem_mrblib_mruby_socket_proc_irep_479,
  &gem_mrblib_mruby_socket_proc_irep_480,
  &gem_mrblib_mruby_socket_proc_irep_481,
  &gem_mrblib_mruby_socket_proc_irep_482,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_5, 5, (MRB_SYM(initialize), MRB_SYM(accept), MRB_SYM(accept_nonblock), MRB_SYM(listen), MRB_SYM(sysaccept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_5[42] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,
0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_5 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_5,
  NULL,gem_mrblib_mruby_socket_proc_syms_5,gem_mrblib_mruby_socket_proc_reps_5,
  NULL,					/* lv */
  NULL,					/* debug_info */
  42,0,5,5,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_513[1] = {
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_513, 5, (MRB_SYM(AF_INET), MRB_SYM(Socket), MRB_SYM(SOCK_DGRAM), MRB_SYM(_socket), MRB_IVSYM(af), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_513[53] = {
0x34,0x00,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x09,0x1d,0x03,0x01,0x1f,0x03,0x00,0x01,0x01,0x03,0x1d,
0x04,0x01,0x01,0x05,0x01,0x1d,0x06,0x01,0x1f,0x06,0x02,0x06,0x07,0x2f,0x04,0x03,0x03,0x51,0x05,0x00,
0x01,0x06,0x02,0x32,0x03,0x02,0x1a,0x01,0x04,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_513, 2, (MRB_SYM(af), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_513 = {
  3,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_513,
  gem_mrblib_mruby_socket_proc_pool_513,gem_mrblib_mruby_socket_proc_syms_513,NULL,
  gem_mrblib_mruby_socket_proc_lv_513,
  NULL,					/* debug_info */
  53,1,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_514, 4, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_sockaddr_in), MRB_SYM(_bind), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_514[31] = {
0x34,0x08,0x00,0x00,0x1d,0x04,0x00,0x12,0x05,0x2f,0x05,0x01,0x00,0x01,0x07,0x02,0x01,0x08,0x01,0x2d,
0x06,0x02,0x02,0x2f,0x04,0x03,0x02,0x06,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_514, 3, (MRB_SYM(host), MRB_SYM(port), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_514 = {
  4,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_514,
  NULL,gem_mrblib_mruby_socket_proc_syms_514,NULL,
  gem_mrblib_mruby_socket_proc_lv_514,
  NULL,					/* debug_info */
  31,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_515, 4, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_sockaddr_in), MRB_SYM(_connect), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_515[31] = {
0x34,0x08,0x00,0x00,0x1d,0x04,0x00,0x12,0x05,0x2f,0x05,0x01,0x00,0x01,0x07,0x02,0x01,0x08,0x01,0x2d,
0x06,0x02,0x02,0x2f,0x04,0x03,0x02,0x06,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_515, 3, (MRB_SYM(host), MRB_SYM(port), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_515 = {
  4,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_515,
  NULL,gem_mrblib_mruby_socket_proc_syms_515,NULL,
  gem_mrblib_mruby_socket_proc_lv_515,
  NULL,					/* debug_info */
  31,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_516, 2, (MRB_SYM(_setnonblock), MRB_SYM(recvfrom), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_516[55] = {
0x34,0x00,0x10,0x00,0x12,0x03,0x12,0x04,0x13,0x05,0x2f,0x04,0x00,0x01,0x12,0x04,0x11,0x05,0x01,0x06,
0x01,0x49,0x05,0x2f,0x04,0x01,0x0f,0x2a,0x06,0x01,0x07,0x03,0x14,0x08,0x2f,0x07,0x00,0x01,0x2c,0x06,
0x38,0x04,0x01,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x1b,0x00,0x00,0x00,0x1b,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_516, 3, (MRB_SYM(args), 0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_516 = {
  4,10,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_516,
  NULL,gem_mrblib_mruby_socket_proc_syms_516,NULL,
  gem_mrblib_mruby_socket_proc_lv_516,
  NULL,					/* debug_info */
  42,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_517, 1, (MRB_SYM(_sockaddr_in), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_517[88] = {
0x34,0x08,0x40,0x00,0x25,0x00,0x06,0x25,0x00,0x05,0x25,0x00,0x04,0x11,0x03,0x11,0x04,0x01,0x06,0x04,
0x27,0x06,0x00,0x19,0x01,0x07,0x01,0x01,0x08,0x02,0x01,0x0a,0x04,0x01,0x0b,0x03,0x2d,0x09,0x00,0x02,
0x01,0x0a,0x05,0x32,0x06,0x03,0x25,0x00,0x25,0x01,0x06,0x03,0x27,0x06,0x00,0x12,0x01,0x07,0x01,0x01,
0x08,0x02,0x01,0x09,0x03,0x01,0x0a,0x05,0x32,0x06,0x03,0x25,0x00,0x0c,0x01,0x07,0x01,0x01,0x08,0x02,
0x01,0x09,0x05,0x32,0x06,0x02,0x38,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_517, 5, (MRB_SYM(mesg), MRB_SYM(flags), MRB_SYM(host), MRB_SYM(port), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_517 = {
  6,13,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_517,
  NULL,gem_mrblib_mruby_socket_proc_syms_517,NULL,
  gem_mrblib_mruby_socket_proc_lv_517,
  NULL,					/* debug_info */
  88,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_518, 6, (MRB_SYM(Addrinfo), MRB_IVSYM(af), MRB_SYM(SOCK_DGRAM), MRB_SYM(Socket), MRB_SYM(getaddrinfo), MRB_SYM(to_sockaddr), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_518[42] = {
0x34,0x08,0x00,0x00,0x1d,0x05,0x00,0x01,0x06,0x02,0x01,0x07,0x01,0x19,0x08,0x01,0x1d,0x09,0x03,0x1f,
0x09,0x02,0x2f,0x05,0x04,0x04,0x06,0x06,0x23,0x05,0x01,0x04,0x05,0x01,0x05,0x04,0x2f,0x05,0x05,0x00,
0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_518, 4, (MRB_SYM(port), MRB_SYM(host), 0,MRB_SYM(ai), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_518 = {
  5,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_518,
  NULL,gem_mrblib_mruby_socket_proc_syms_518,NULL,
  gem_mrblib_mruby_socket_proc_lv_518,
  NULL,					/* debug_info */
  42,0,6,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_6[6] = {
  &gem_mrblib_mruby_socket_proc_irep_513,
  &gem_mrblib_mruby_socket_proc_irep_514,
  &gem_mrblib_mruby_socket_proc_irep_515,
  &gem_mrblib_mruby_socket_proc_irep_516,
  &gem_mrblib_mruby_socket_proc_irep_517,
  &gem_mrblib_mruby_socket_proc_irep_518,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_6, 6, (MRB_SYM(initialize), MRB_SYM(bind), MRB_SYM(connect), MRB_SYM(recvfrom_nonblock), MRB_SYM(send), MRB_SYM(_sockaddr_in), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_6[50] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,
0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_6 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_6,
  NULL,gem_mrblib_mruby_socket_proc_syms_6,gem_mrblib_mruby_socket_proc_reps_6,
  NULL,					/* lv */
  NULL,					/* debug_info */
  50,0,6,6,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_558[1] = {
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_558, 2, (MRB_SYM(Socket), MRB_SYM(_socket), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_558[39] = {
0x34,0x08,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x06,0x03,0x1d,0x06,0x00,0x01,0x07,0x01,0x01,0x08,
0x02,0x01,0x09,0x03,0x2f,0x06,0x01,0x03,0x51,0x07,0x00,0x01,0x08,0x04,0x32,0x05,0x02,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_558, 4, (MRB_SYM(domain), MRB_SYM(type), MRB_SYM(protocol), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_558 = {
  5,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_558,
  gem_mrblib_mruby_socket_proc_pool_558,gem_mrblib_mruby_socket_proc_syms_558,NULL,
  gem_mrblib_mruby_socket_proc_lv_558,
  NULL,					/* debug_info */
  39,1,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_590, 4, (MRB_SYM(_to_array), MRB_SYM(afamily), MRB_SYM(socktype), MRB_SYM(protocol), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_590[69] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2f,0x04,0x00,0x00,0x01,0x03,0x04,0x01,0x04,0x03,0x08,0x05,0x21,
0x06,0x01,0x00,0x24,0x04,0x01,0x04,0x03,0x0a,0x05,0x01,0x06,0x01,0x2f,0x06,0x01,0x00,0x24,0x04,0x01,
0x04,0x03,0x0b,0x05,0x01,0x06,0x01,0x2f,0x06,0x02,0x00,0x24,0x04,0x01,0x04,0x03,0x0c,0x05,0x01,0x06,
0x01,0x2f,0x06,0x03,0x00,0x24,0x04,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_590, 3, (MRB_SYM(ai), 0,MRB_SYM(ary), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_590 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_590,
  NULL,gem_mrblib_mruby_socket_proc_syms_590,NULL,
  gem_mrblib_mruby_socket_proc_lv_590,
  NULL,					/* debug_info */
  69,0,4,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_559[1] = {
  &gem_mrblib_mruby_socket_proc_irep_590,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_559, 3, (MRB_SYM(Addrinfo), MRB_SYM(getaddrinfo), MRB_SYM(map), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_559[61] = {
0x34,0x08,0x80,0x00,0x25,0x00,0x0c,0x25,0x00,0x0b,0x25,0x00,0x0a,0x25,0x00,0x09,0x25,0x00,0x08,0x11,
0x03,0x11,0x04,0x11,0x05,0x06,0x06,0x1d,0x08,0x00,0x01,0x09,0x01,0x01,0x0a,0x02,0x01,0x0b,0x03,0x01,
0x0c,0x04,0x01,0x0d,0x05,0x01,0x0e,0x06,0x2f,0x08,0x01,0x06,0x57,0x09,0x00,0x30,0x08,0x02,0x00,0x38,
0x08,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_559, 7, (MRB_SYM(nodename), MRB_SYM(servname), MRB_SYM(family), MRB_SYM(socktype), MRB_SYM(protocol), MRB_SYM(flags), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_559 = {
  8,16,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_559,
  NULL,gem_mrblib_mruby_socket_proc_syms_559,gem_mrblib_mruby_socket_proc_reps_559,
  gem_mrblib_mruby_socket_proc_lv_559,
  NULL,					/* debug_info */
  61,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_560, 1, (MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_560[13] = {
0x34,0x00,0x10,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_560, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_560 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_560,
  NULL,gem_mrblib_mruby_socket_proc_syms_560,NULL,
  gem_mrblib_mruby_socket_proc_lv_560,
  NULL,					/* debug_info */
  13,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_561, 5, (MRB_SYM(Addrinfo), MRB_SYM(SOCK_DGRAM), MRB_SYM(Socket), MRB_SYM(getaddrinfo), MRB_SYM(to_sockaddr), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_561[41] = {
0x34,0x08,0x00,0x00,0x1d,0x05,0x00,0x01,0x06,0x02,0x01,0x07,0x01,0x11,0x08,0x1d,0x09,0x02,0x1f,0x09,
0x01,0x2f,0x05,0x03,0x04,0x06,0x06,0x23,0x05,0x01,0x04,0x05,0x01,0x05,0x04,0x2f,0x05,0x04,0x00,0x38,
0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_561, 4, (MRB_SYM(port), MRB_SYM(host), 0,MRB_SYM(ai), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_561 = {
  5,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_561,
  NULL,gem_mrblib_mruby_socket_proc_syms_561,NULL,
  gem_mrblib_mruby_socket_proc_lv_561,
  NULL,					/* debug_info */
  41,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_562, 4, (MRB_SYM(Addrinfo), MRB_SYM(new), MRB_SYM(ip_unpack), MRB_SYM(reverse), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_562[24] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x2f,0x03,0x02,0x00,0x2f,0x03,
0x03,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_562, 2, (MRB_SYM(sa), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_562 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_562,
  NULL,gem_mrblib_mruby_socket_proc_syms_562,NULL,
  gem_mrblib_mruby_socket_proc_lv_562,
  NULL,					/* debug_info */
  24,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_563, 3, (MRB_SYM(Addrinfo), MRB_SYM(new), MRB_SYM(unix_path), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_563[20] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x2f,0x03,0x02,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_563, 2, (MRB_SYM(sa), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_563 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_563,
  NULL,gem_mrblib_mruby_socket_proc_syms_563,NULL,
  gem_mrblib_mruby_socket_proc_lv_563,
  NULL,					/* debug_info */
  20,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_564, 6, (MRB_SYM(pack_sockaddr_in), MRB_SYM(sockaddr_in), MRB_SYM(pack_sockaddr_un), MRB_SYM(sockaddr_un), MRB_SYM(pair), MRB_SYM(socketpair), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_564[13] = {
0x60,0x00,0x01,0x60,0x02,0x03,0x60,0x04,0x05,0x11,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_564 = {
  1,2,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_564,
  NULL,gem_mrblib_mruby_socket_proc_syms_564,NULL,
  NULL,					/* lv */
  NULL,					/* debug_info */
  13,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_565, 3, (MRB_SYM(sysaccept), MRB_SYM(Socket), MRB_SYM(for_fd), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_565[36] = {
0x34,0x00,0x00,0x00,0x12,0x04,0x2f,0x04,0x00,0x00,0x4c,0x02,0x04,0x00,0x4c,0x03,0x04,0x01,0x1d,0x04,
0x01,0x01,0x05,0x02,0x2f,0x04,0x02,0x01,0x01,0x05,0x03,0x47,0x04,0x02,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_565, 3, (0,MRB_SYM(fd), MRB_SYM(addr), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_565 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_565,
  NULL,gem_mrblib_mruby_socket_proc_syms_565,NULL,
  gem_mrblib_mruby_socket_proc_lv_565,
  NULL,					/* debug_info */
  36,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_566, 2, (MRB_SYM(_setnonblock), MRB_SYM(accept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_566[45] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x13,0x03,0x2f,0x02,0x00,0x01,0x12,0x02,0x2f,0x02,0x01,0x00,0x2a,0x04,
0x12,0x05,0x14,0x06,0x2f,0x05,0x00,0x01,0x2c,0x04,0x38,0x02,0x01,0x00,0x00,0x00,0x04,0x00,0x00,0x00,
0x12,0x00,0x00,0x00,0x12,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_566, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_566 = {
  2,8,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_566,
  NULL,gem_mrblib_mruby_socket_proc_syms_566,NULL,
  gem_mrblib_mruby_socket_proc_lv_566,
  NULL,					/* debug_info */
  32,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_567, 6, (MRB_SYM(Addrinfo), MRB_SYM_Q(is_a), MRB_SYM(to_sockaddr), MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_bind), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_567[48] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x27,0x03,0x00,0x0a,0x01,0x03,
0x01,0x2f,0x03,0x02,0x00,0x01,0x01,0x03,0x1d,0x03,0x03,0x12,0x04,0x2f,0x04,0x04,0x00,0x01,0x05,0x01,
0x2f,0x03,0x05,0x02,0x06,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_567, 2, (MRB_SYM(sockaddr), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_567 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_567,
  NULL,gem_mrblib_mruby_socket_proc_syms_567,NULL,
  gem_mrblib_mruby_socket_proc_lv_567,
  NULL,					/* debug_info */
  48,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_568, 6, (MRB_SYM(Addrinfo), MRB_SYM_Q(is_a), MRB_SYM(to_sockaddr), MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_connect), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_568[48] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x27,0x03,0x00,0x0a,0x01,0x03,
0x01,0x2f,0x03,0x02,0x00,0x01,0x01,0x03,0x1d,0x03,0x03,0x12,0x04,0x2f,0x04,0x04,0x00,0x01,0x05,0x01,
0x2f,0x03,0x05,0x02,0x06,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_568, 2, (MRB_SYM(sockaddr), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_568 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_568,
  NULL,gem_mrblib_mruby_socket_proc_syms_568,NULL,
  gem_mrblib_mruby_socket_proc_lv_568,
  NULL,					/* debug_info */
  48,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_569, 2, (MRB_SYM(_setnonblock), MRB_SYM(connect), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_569[48] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x13,0x04,0x2f,0x03,0x00,0x01,0x12,0x03,0x01,0x04,0x01,0x2f,0x03,0x01,
0x01,0x2a,0x05,0x12,0x06,0x14,0x07,0x2f,0x06,0x00,0x01,0x2c,0x05,0x38,0x03,0x01,0x00,0x00,0x00,0x04,
0x00,0x00,0x00,0x15,0x00,0x00,0x00,0x15,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_569, 2, (MRB_SYM(sockaddr), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_569 = {
  3,9,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_569,
  NULL,gem_mrblib_mruby_socket_proc_syms_569,NULL,
  gem_mrblib_mruby_socket_proc_lv_569,
  NULL,					/* debug_info */
  35,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_570, 3, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_listen), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_570[24] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,0x00,0x01,0x05,0x01,0x2f,0x03,0x02,0x02,
0x06,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_570, 2, (MRB_SYM(backlog), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_570 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_570,
  NULL,gem_mrblib_mruby_socket_proc_syms_570,NULL,
  gem_mrblib_mruby_socket_proc_lv_570,
  NULL,					/* debug_info */
  24,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_571, 9, (MRB_SYM(_recvfrom), MRB_SYM(SOL_SOCKET), MRB_SYM(Socket), MRB_SYM(SO_TYPE), MRB_SYM(getsockopt), MRB_SYM(int), MRB_SYM(Addrinfo), MRB_SYM(PF_UNSPEC), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_571[82] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x06,0x02,0x01,0x08,0x01,0x01,0x09,0x02,0x2d,0x07,
0x00,0x02,0x4c,0x04,0x07,0x00,0x4c,0x05,0x07,0x01,0x12,0x07,0x1d,0x08,0x02,0x1f,0x08,0x01,0x1d,0x09,
0x02,0x1f,0x09,0x03,0x2f,0x07,0x04,0x02,0x2f,0x07,0x05,0x00,0x01,0x06,0x07,0x01,0x07,0x04,0x1d,0x08,
0x06,0x01,0x09,0x05,0x1d,0x0a,0x02,0x1f,0x0a,0x07,0x01,0x0b,0x06,0x2f,0x08,0x08,0x03,0x47,0x07,0x02,
0x38,0x07,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_571, 6, (MRB_SYM(maxlen), MRB_SYM(flags), 0,MRB_SYM(msg), MRB_SYM(sa), MRB_SYM(socktype), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_571 = {
  7,13,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_571,
  NULL,gem_mrblib_mruby_socket_proc_syms_571,NULL,
  gem_mrblib_mruby_socket_proc_lv_571,
  NULL,					/* debug_info */
  82,0,9,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_572, 2, (MRB_SYM(_setnonblock), MRB_SYM(_recvfrom), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_572[52] = {
0x34,0x00,0x10,0x00,0x12,0x03,0x13,0x04,0x2f,0x03,0x00,0x01,0x12,0x03,0x11,0x04,0x01,0x05,0x01,0x49,
0x04,0x2f,0x03,0x01,0x0f,0x2a,0x05,0x12,0x06,0x14,0x07,0x2f,0x06,0x00,0x01,0x2c,0x05,0x38,0x03,0x01,
0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x19,0x00,0x00,0x00,0x19,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_572, 2, (MRB_SYM(args), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_572 = {
  3,9,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_572,
  NULL,gem_mrblib_mruby_socket_proc_syms_572,NULL,
  gem_mrblib_mruby_socket_proc_lv_572,
  NULL,					/* debug_info */
  39,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_573, 3, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_accept2), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_573[19] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_573, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_573 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_573,
  NULL,gem_mrblib_mruby_socket_proc_syms_573,NULL,
  gem_mrblib_mruby_socket_proc_lv_573,
  NULL,					/* debug_info */
  19,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_7[16] = {
  &gem_mrblib_mruby_socket_proc_irep_558,
  &gem_mrblib_mruby_socket_proc_irep_559,
  &gem_mrblib_mruby_socket_proc_irep_560,
  &gem_mrblib_mruby_socket_proc_irep_561,
  &gem_mrblib_mruby_socket_proc_irep_562,
  &gem_mrblib_mruby_socket_proc_irep_563,
  &gem_mrblib_mruby_socket_proc_irep_564,
  &gem_mrblib_mruby_socket_proc_irep_565,
  &gem_mrblib_mruby_socket_proc_irep_566,
  &gem_mrblib_mruby_socket_proc_irep_567,
  &gem_mrblib_mruby_socket_proc_irep_568,
  &gem_mrblib_mruby_socket_proc_irep_569,
  &gem_mrblib_mruby_socket_proc_irep_570,
  &gem_mrblib_mruby_socket_proc_irep_571,
  &gem_mrblib_mruby_socket_proc_irep_572,
  &gem_mrblib_mruby_socket_proc_irep_573,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_7, 15, (MRB_SYM(initialize), MRB_SYM(getaddrinfo), MRB_SYM(open), MRB_SYM(sockaddr_in), MRB_SYM(unpack_sockaddr_in), MRB_SYM(unpack_sockaddr_un), MRB_SYM(accept), MRB_SYM(accept_nonblock), MRB_SYM(bind), MRB_SYM(connect), MRB_SYM(connect_nonblock), MRB_SYM(listen), MRB_SYM(recvfrom), MRB_SYM(recvfrom_nonblock), MRB_SYM(sysaccept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_7[139] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x12,0x01,0x62,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x12,0x01,
0x62,0x01,0x58,0x02,0x02,0x5f,0x01,0x02,0x12,0x01,0x62,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x12,0x01,
0x62,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,0x12,0x01,0x62,0x01,0x58,0x02,0x05,0x5f,0x01,0x05,0x12,0x01,
0x62,0x01,0x5e,0x01,0x06,0x63,0x01,0x58,0x02,0x07,0x5f,0x01,0x06,0x63,0x01,0x58,0x02,0x08,0x5f,0x01,
0x07,0x63,0x01,0x58,0x02,0x09,0x5f,0x01,0x08,0x63,0x01,0x58,0x02,0x0a,0x5f,0x01,0x09,0x63,0x01,0x58,
0x02,0x0b,0x5f,0x01,0x0a,0x63,0x01,0x58,0x02,0x0c,0x5f,0x01,0x0b,0x63,0x01,0x58,0x02,0x0d,0x5f,0x01,
0x0c,0x63,0x01,0x58,0x02,0x0e,0x5f,0x01,0x0d,0x63,0x01,0x58,0x02,0x0f,0x5f,0x01,0x0e,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_7 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_7,
  NULL,gem_mrblib_mruby_socket_proc_syms_7,gem_mrblib_mruby_socket_proc_reps_7,
  NULL,					/* lv */
  NULL,					/* debug_info */
  139,0,15,16,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_824[2] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
{IREP_TT_STR|(2<<2), {"\x72\x2b"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_824, 14, (MRB_SYM(UNIXServer), MRB_SYM_Q(is_a), MRB_SYM(Socket), MRB_SYM(AF_UNIX), MRB_SYM(SOCK_STREAM), MRB_SYM(_socket), MRB_SYM(fileno), MRB_SYM(sockaddr_un), MRB_SYM(_connect), MRB_SYM_Q(block_given), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), MRB_SYM(StandardError), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_824[184] = {
0x34,0x04,0x00,0x01,0x12,0x03,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x27,0x03,0x00,0x0f,0x01,0x04,0x01,
0x51,0x05,0x00,0x01,0x06,0x02,0x32,0x03,0x02,0x25,0x00,0x7c,0x1d,0x04,0x02,0x1d,0x05,0x02,0x1f,0x05,
0x03,0x1d,0x06,0x02,0x1f,0x06,0x04,0x06,0x07,0x2f,0x04,0x05,0x03,0x51,0x05,0x01,0x01,0x06,0x02,0x32,
0x03,0x02,0x1d,0x03,0x02,0x12,0x04,0x2f,0x04,0x06,0x00,0x1d,0x05,0x02,0x01,0x06,0x01,0x2f,0x05,0x07,
0x01,0x2f,0x03,0x08,0x02,0x2d,0x03,0x09,0x00,0x27,0x03,0x00,0x3d,0x12,0x04,0x3b,0x03,0x08,0x00,0x2f,
0x03,0x0a,0x01,0x2a,0x05,0x12,0x06,0x2f,0x06,0x0b,0x00,0x27,0x06,0x00,0x05,0x11,0x06,0x25,0x00,0x06,
0x12,0x06,0x2f,0x06,0x0c,0x00,0x25,0x00,0x14,0x2a,0x06,0x1d,0x07,0x0d,0x2b,0x06,0x07,0x26,0x07,0x00,
0x03,0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x06,0x2c,0x05,0x25,0x00,0x02,0x11,0x03,0x38,0x03,0x01,0x00,
0x00,0x00,0x5d,0x00,0x00,0x00,0x67,0x00,0x00,0x00,0x67,0x00,0x00,0x00,0x00,0x69,0x00,0x00,0x00,0x7e,
0x00,0x00,0x00,0x81,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_824, 2, (MRB_SYM(path), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_824 = {
  3,9,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_824,
  gem_mrblib_mruby_socket_proc_pool_824,gem_mrblib_mruby_socket_proc_syms_824,NULL,
  gem_mrblib_mruby_socket_proc_lv_824,
  NULL,					/* debug_info */
  158,2,14,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_825, 6, (MRB_SYM(SOCK_STREAM), MRB_SYM(Socket), MRB_SYM(AF_UNIX), MRB_SYM(socketpair), MRB_SYM(UNIXSocket), MRB_SYM(for_fd), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_825[79] = {
0x34,0x00,0x40,0x00,0x25,0x00,0x06,0x25,0x00,0x0c,0x25,0x00,0x0b,0x1d,0x05,0x01,0x1f,0x05,0x00,0x01,
0x01,0x05,0x06,0x02,0x1d,0x05,0x01,0x1d,0x06,0x01,0x1f,0x06,0x02,0x01,0x07,0x01,0x01,0x08,0x02,0x2f,
0x05,0x03,0x03,0x01,0x04,0x05,0x1d,0x05,0x04,0x01,0x06,0x04,0x06,0x07,0x23,0x06,0x2f,0x05,0x05,0x01,
0x1d,0x06,0x04,0x01,0x07,0x04,0x07,0x08,0x23,0x07,0x2f,0x06,0x05,0x01,0x47,0x05,0x02,0x38,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_825, 4, (MRB_SYM(type), MRB_SYM(protocol), 0,MRB_SYM(a), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_825 = {
  5,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_825,
  NULL,gem_mrblib_mruby_socket_proc_syms_825,NULL,
  gem_mrblib_mruby_socket_proc_lv_825,
  NULL,					/* debug_info */
  79,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_826, 2, (MRB_SYM(pair), MRB_SYM(socketpair), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_826[7] = {
0x60,0x00,0x01,0x11,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_826 = {
  1,2,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_826,
  NULL,gem_mrblib_mruby_socket_proc_syms_826,NULL,
  NULL,					/* lv */
  NULL,					/* debug_info */
  7,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_827[1] = {
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x55\x4e\x49\x58"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_827, 1, (MRB_SYM(path), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_827[16] = {
0x34,0x00,0x00,0x00,0x51,0x02,0x00,0x2d,0x03,0x00,0x00,0x47,0x02,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_827, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_827 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_827,
  gem_mrblib_mruby_socket_proc_pool_827,gem_mrblib_mruby_socket_proc_syms_827,NULL,
  gem_mrblib_mruby_socket_proc_lv_827,
  NULL,					/* debug_info */
  16,1,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_828, 4, (MRB_SYM(Addrinfo), MRB_SYM(getsockname), MRB_SYM(new), MRB_SYM(unix_path), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_828[23] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x2f,0x02,0x03,
0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_828, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_828 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_828,
  NULL,gem_mrblib_mruby_socket_proc_syms_828,NULL,
  gem_mrblib_mruby_socket_proc_lv_828,
  NULL,					/* debug_info */
  23,0,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_829[1] = {
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x55\x4e\x49\x58"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_829, 4, (MRB_SYM(Addrinfo), MRB_SYM(getpeername), MRB_SYM(new), MRB_SYM(unix_path), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_829[29] = {
0x34,0x00,0x00,0x00,0x51,0x02,0x00,0x1d,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,0x00,0x2f,0x03,0x02,0x01,
0x2f,0x03,0x03,0x00,0x47,0x02,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_829, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_829 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_829,
  gem_mrblib_mruby_socket_proc_pool_829,gem_mrblib_mruby_socket_proc_syms_829,NULL,
  gem_mrblib_mruby_socket_proc_lv_829,
  NULL,					/* debug_info */
  29,1,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_socket_proc_pool_830[2] = {
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(7<<2), {"\x41\x46\x5f\x55\x4e\x49\x58"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_830, 5, (MRB_SYM(_recvfrom), MRB_SYM(size), MRB_SYM(Addrinfo), MRB_SYM(new), MRB_SYM(unix_path), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_830[85] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x06,0x02,0x01,0x08,0x01,0x01,0x09,0x02,0x2d,0x07,
0x00,0x02,0x4c,0x04,0x07,0x00,0x4c,0x05,0x07,0x01,0x01,0x07,0x05,0x2f,0x07,0x01,0x00,0x06,0x08,0x45,
0x07,0x27,0x07,0x00,0x11,0x1d,0x07,0x02,0x01,0x08,0x05,0x2f,0x07,0x03,0x01,0x2f,0x07,0x04,0x00,0x25,
0x00,0x03,0x51,0x07,0x00,0x01,0x06,0x07,0x01,0x07,0x04,0x51,0x08,0x01,0x01,0x09,0x06,0x47,0x08,0x02,
0x47,0x07,0x02,0x38,0x07,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_830, 6, (MRB_SYM(maxlen), MRB_SYM(flags), 0,MRB_SYM(msg), MRB_SYM(sa), MRB_SYM(path), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_830 = {
  7,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_830,
  gem_mrblib_mruby_socket_proc_pool_830,gem_mrblib_mruby_socket_proc_syms_830,NULL,
  gem_mrblib_mruby_socket_proc_lv_830,
  NULL,					/* debug_info */
  85,2,5,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_8[7] = {
  &gem_mrblib_mruby_socket_proc_irep_824,
  &gem_mrblib_mruby_socket_proc_irep_825,
  &gem_mrblib_mruby_socket_proc_irep_826,
  &gem_mrblib_mruby_socket_proc_irep_827,
  &gem_mrblib_mruby_socket_proc_irep_828,
  &gem_mrblib_mruby_socket_proc_irep_829,
  &gem_mrblib_mruby_socket_proc_irep_830,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_8, 6, (MRB_SYM(initialize), MRB_SYM(socketpair), MRB_SYM(addr), MRB_SYM(path), MRB_SYM(peeraddr), MRB_SYM(recvfrom), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_8[59] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x12,0x01,0x62,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x12,0x01,
0x62,0x01,0x5e,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,
0x03,0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x04,0x63,0x01,0x58,0x02,0x06,0x5f,0x01,0x05,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_8 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_8,
  NULL,gem_mrblib_mruby_socket_proc_syms_8,gem_mrblib_mruby_socket_proc_reps_8,
  NULL,					/* lv */
  NULL,					/* debug_info */
  59,0,6,7,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_882, 15, (MRB_SYM(Socket), MRB_SYM(AF_UNIX), MRB_SYM(SOCK_STREAM), MRB_SYM(_socket), MRB_SYM(pack_sockaddr_un), MRB_SYM(_bind), MRB_SYM(listen), MRB_SYM(StandardError), MRB_SYM(IO), MRB_SYM(_sysclose), MRB_SYM(raise), MRB_SYM_Q(block_given), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_882[251] = {
0x34,0x04,0x00,0x00,0x1d,0x05,0x00,0x1d,0x06,0x00,0x1f,0x06,0x01,0x1d,0x07,0x00,0x1f,0x07,0x02,0x06,
0x08,0x2f,0x05,0x03,0x03,0x01,0x03,0x05,0x01,0x06,0x03,0x01,0x07,0x02,0x32,0x05,0x01,0x1d,0x05,0x00,
0x01,0x06,0x03,0x1d,0x07,0x00,0x01,0x08,0x01,0x2f,0x07,0x04,0x01,0x2f,0x05,0x05,0x02,0x12,0x05,0x0b,
0x06,0x2f,0x05,0x06,0x01,0x25,0x00,0x3f,0x2a,0x05,0x1d,0x06,0x07,0x2b,0x05,0x06,0x26,0x06,0x00,0x03,
0x25,0x00,0x2e,0x01,0x04,0x05,0x1d,0x05,0x08,0x01,0x06,0x03,0x2f,0x05,0x09,0x01,0x25,0x00,0x14,0x2a,
0x05,0x1d,0x06,0x07,0x2b,0x05,0x06,0x26,0x06,0x00,0x03,0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x05,0x01,
0x06,0x04,0x2d,0x05,0x0a,0x01,0x25,0x00,0x02,0x2c,0x05,0x2d,0x05,0x0b,0x00,0x27,0x05,0x00,0x38,0x12,
0x06,0x3b,0x05,0x08,0x00,0x2f,0x05,0x0c,0x01,0x2a,0x07,0x12,0x08,0x2f,0x08,0x0d,0x00,0x26,0x08,0x00,
0x1d,0x12,0x08,0x2f,0x08,0x0e,0x00,0x25,0x00,0x14,0x2a,0x08,0x1d,0x09,0x07,0x2b,0x08,0x09,0x26,0x09,
0x00,0x03,0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x08,0x2c,0x07,0x25,0x00,0x02,0x11,0x05,0x38,0x05,0x00,
0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x41,0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0x56,0x00,0x00,0x00,
0x60,0x00,0x00,0x00,0x63,0x01,0x00,0x00,0x00,0x8b,0x00,0x00,0x00,0x95,0x00,0x00,0x00,0x95,0x00,0x00,
0x00,0x00,0xa1,0x00,0x00,0x00,0xa7,0x00,0x00,0x00,0xaa,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_882, 4, (MRB_SYM(path), 0,MRB_SYM(fd), MRB_SYM(e), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_882 = {
  5,10,4,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_882,
  NULL,gem_mrblib_mruby_socket_proc_syms_882,NULL,
  gem_mrblib_mruby_socket_proc_lv_882,
  NULL,					/* debug_info */
  199,0,15,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_883, 6, (MRB_SYM(sysaccept), MRB_SYM(UNIXSocket), MRB_SYM(for_fd), MRB_SYM(StandardError), MRB_SYM(IO), MRB_SYM(_sysclose), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_883[110] = {
0x34,0x00,0x00,0x00,0x12,0x04,0x2f,0x04,0x00,0x00,0x01,0x02,0x04,0x1d,0x04,0x01,0x01,0x05,0x02,0x2f,
0x04,0x02,0x01,0x01,0x03,0x04,0x25,0x00,0x35,0x2a,0x04,0x1d,0x05,0x03,0x2b,0x04,0x05,0x26,0x05,0x00,
0x03,0x25,0x00,0x24,0x1d,0x04,0x04,0x01,0x05,0x02,0x2f,0x04,0x05,0x01,0x25,0x00,0x14,0x2a,0x04,0x1d,
0x05,0x03,0x2b,0x04,0x05,0x26,0x05,0x00,0x03,0x25,0x00,0x03,0x25,0x00,0x02,0x2c,0x04,0x25,0x00,0x02,
0x2c,0x04,0x38,0x03,0x00,0x00,0x00,0x00,0x0d,0x00,0x00,0x00,0x1a,0x00,0x00,0x00,0x1d,0x00,0x00,0x00,
0x00,0x2c,0x00,0x00,0x00,0x36,0x00,0x00,0x00,0x39,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_883, 3, (0,MRB_SYM(fd), MRB_SYM(sock), ), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_883 = {
  4,7,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_883,
  NULL,gem_mrblib_mruby_socket_proc_syms_883,NULL,
  gem_mrblib_mruby_socket_proc_lv_883,
  NULL,					/* debug_info */
  84,0,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_884, 2, (MRB_SYM(_setnonblock), MRB_SYM(accept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_884[45] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x13,0x03,0x2f,0x02,0x00,0x01,0x12,0x02,0x2f,0x02,0x01,0x00,0x2a,0x04,
0x12,0x05,0x14,0x06,0x2f,0x05,0x00,0x01,0x2c,0x04,0x38,0x02,0x01,0x00,0x00,0x00,0x04,0x00,0x00,0x00,
0x12,0x00,0x00,0x00,0x12,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_884, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_884 = {
  2,8,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_884,
  NULL,gem_mrblib_mruby_socket_proc_syms_884,NULL,
  gem_mrblib_mruby_socket_proc_lv_884,
  NULL,					/* debug_info */
  32,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_885, 3, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_listen), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_885[24] = {
0x34,0x04,0x00,0x00,0x1d,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,0x00,0x01,0x05,0x01,0x2f,0x03,0x02,0x02,
0x06,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_885, 2, (MRB_SYM(backlog), 0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_885 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_885,
  NULL,gem_mrblib_mruby_socket_proc_syms_885,NULL,
  gem_mrblib_mruby_socket_proc_lv_885,
  NULL,					/* debug_info */
  24,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_886, 3, (MRB_SYM(Socket), MRB_SYM(fileno), MRB_SYM(_accept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_886[19] = {
0x34,0x00,0x00,0x00,0x1d,0x02,0x00,0x12,0x03,0x2f,0x03,0x01,0x00,0x2f,0x02,0x02,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_lv_886, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_886 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_886,
  NULL,gem_mrblib_mruby_socket_proc_syms_886,NULL,
  gem_mrblib_mruby_socket_proc_lv_886,
  NULL,					/* debug_info */
  19,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_9[5] = {
  &gem_mrblib_mruby_socket_proc_irep_882,
  &gem_mrblib_mruby_socket_proc_irep_883,
  &gem_mrblib_mruby_socket_proc_irep_884,
  &gem_mrblib_mruby_socket_proc_irep_885,
  &gem_mrblib_mruby_socket_proc_irep_886,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_9, 5, (MRB_SYM(initialize), MRB_SYM(accept), MRB_SYM(accept_nonblock), MRB_SYM(listen), MRB_SYM(sysaccept), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_9[42] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x04,
0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_9 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_9,
  NULL,gem_mrblib_mruby_socket_proc_syms_9,gem_mrblib_mruby_socket_proc_reps_9,
  NULL,					/* lv */
  NULL,					/* debug_info */
  42,0,5,5,0
};
static const mrb_irep *gem_mrblib_mruby_socket_proc_reps_0[9] = {
  &gem_mrblib_mruby_socket_proc_irep_1,
  &gem_mrblib_mruby_socket_proc_irep_2,
  &gem_mrblib_mruby_socket_proc_irep_3,
  &gem_mrblib_mruby_socket_proc_irep_4,
  &gem_mrblib_mruby_socket_proc_irep_5,
  &gem_mrblib_mruby_socket_proc_irep_6,
  &gem_mrblib_mruby_socket_proc_irep_7,
  &gem_mrblib_mruby_socket_proc_irep_8,
  &gem_mrblib_mruby_socket_proc_irep_9,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_socket_proc_syms_0, 12, (MRB_SYM(Addrinfo), MRB_SYM(IO), MRB_SYM(BasicSocket), MRB_SYM(IPSocket), MRB_SYM(TCPSocket), MRB_SYM(TCPServer), MRB_SYM(UDPSocket), MRB_SYM(Socket), MRB_SYM(UNIXSocket), MRB_SYM(UNIXServer), MRB_SYM(StandardError), MRB_SYM(SocketError), ), const);
static const mrb_code gem_mrblib_mruby_socket_proc_iseq_0[111] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x11,0x01,0x1d,0x02,0x01,0x5c,0x01,0x02,0x5e,0x01,
0x01,0x11,0x01,0x1d,0x02,0x02,0x5c,0x01,0x03,0x5e,0x01,0x02,0x11,0x01,0x1d,0x02,0x03,0x5c,0x01,0x04,
0x5e,0x01,0x03,0x11,0x01,0x1d,0x02,0x04,0x5c,0x01,0x05,0x5e,0x01,0x04,0x11,0x01,0x1d,0x02,0x03,0x5c,
0x01,0x06,0x5e,0x01,0x05,0x11,0x01,0x1d,0x02,0x02,0x5c,0x01,0x07,0x5e,0x01,0x06,0x11,0x01,0x1d,0x02,
0x02,0x5c,0x01,0x08,0x5e,0x01,0x07,0x11,0x01,0x1d,0x02,0x08,0x5c,0x01,0x09,0x5e,0x01,0x08,0x11,0x01,
0x1d,0x02,0x0a,0x5c,0x01,0x0b,0x11,0x01,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_socket_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_socket_proc_iseq_0,
  NULL,gem_mrblib_mruby_socket_proc_syms_0,gem_mrblib_mruby_socket_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  111,0,12,9,0
};
static
const struct RProc gem_mrblib_mruby_socket_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_socket_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_socket_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_socket_gem_init(mrb_state *mrb);
void mrb_mruby_socket_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_socket_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_socket_proc_init_syms(mrb);
  mrb_mruby_socket_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_socket_proc);
}

void GENERATED_TMP_mrb_mruby_socket_gem_final(mrb_state *mrb) {
  mrb_mruby_socket_gem_final(mrb);
}
