/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_syms_5, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_method_proc_iseq_5[32] = {
0x34,0x00,0x10,0x03,0x21,0x04,0x02,0x00,0x11,0x05,0x01,0x06,0x01,0x49,0x05,0x53,0x06,0x00,0x01,0x07,
0x02,0x55,0x06,0x01,0x07,0x03,0x30,0x04,0x00,0xff,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_lv_5, 3, (MRB_SYM(args), MRB_SYM(opts), MRB_SYM(b), ), const);
static const mrb_irep gem_mrblib_mruby_method_proc_irep_5 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_5,
  NULL,gem_mrblib_mruby_method_proc_syms_5,NULL,
  gem_mrblib_mruby_method_proc_lv_5,
  NULL,					/* debug_info */
  32,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_method_proc_reps_2[1] = {
  &gem_mrblib_mruby_method_proc_irep_5,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_syms_2, 1, (MRB_SYM(lambda), ), const);
static const mrb_code gem_mrblib_mruby_method_proc_iseq_2[15] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x57,0x04,0x00,0x2e,0x03,0x00,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_lv_2, 2, (0,MRB_SYM(m), ), const);
static const mrb_irep gem_mrblib_mruby_method_proc_irep_2 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_2,
  NULL,gem_mrblib_mruby_method_proc_syms_2,gem_mrblib_mruby_method_proc_reps_2,
  gem_mrblib_mruby_method_proc_lv_2,
  NULL,					/* debug_info */
  15,0,1,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_syms_9, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_method_proc_iseq_9[36] = {
0x34,0x00,0x10,0x03,0x21,0x05,0x01,0x00,0x11,0x06,0x01,0x07,0x01,0x49,0x06,0x53,0x07,0x00,0x01,0x08,
0x02,0x55,0x07,0x01,0x08,0x03,0x30,0x05,0x00,0xff,0x2d,0x04,0x00,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_lv_9, 3, (MRB_SYM(args), MRB_SYM(opts), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_method_proc_irep_9 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_9,
  NULL,gem_mrblib_mruby_method_proc_syms_9,NULL,
  gem_mrblib_mruby_method_proc_lv_9,
  NULL,					/* debug_info */
  36,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_method_proc_reps_3[1] = {
  &gem_mrblib_mruby_method_proc_irep_9,
};
static const mrb_code gem_mrblib_mruby_method_proc_iseq_3[9] = {
0x34,0x04,0x00,0x00,0x56,0x03,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_lv_3, 2, (MRB_SYM(other), 0,), const);
static const mrb_irep gem_mrblib_mruby_method_proc_irep_3 = {
  3,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_3,
  NULL,NULL,gem_mrblib_mruby_method_proc_reps_3,
  gem_mrblib_mruby_method_proc_lv_3,
  NULL,					/* debug_info */
  9,0,0,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_syms_13, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_method_proc_iseq_13[36] = {
0x34,0x00,0x10,0x03,0x21,0x04,0x01,0x00,0x11,0x06,0x01,0x07,0x01,0x49,0x06,0x53,0x07,0x00,0x01,0x08,
0x02,0x55,0x07,0x01,0x08,0x03,0x2e,0x05,0x00,0xff,0x2f,0x04,0x00,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_lv_13, 3, (MRB_SYM(args), MRB_SYM(opts), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_method_proc_irep_13 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_13,
  NULL,gem_mrblib_mruby_method_proc_syms_13,NULL,
  gem_mrblib_mruby_method_proc_lv_13,
  NULL,					/* debug_info */
  36,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_method_proc_reps_4[1] = {
  &gem_mrblib_mruby_method_proc_irep_13,
};
static const mrb_code gem_mrblib_mruby_method_proc_iseq_4[9] = {
0x34,0x04,0x00,0x00,0x56,0x03,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_lv_4, 2, (MRB_SYM(other), 0,), const);
static const mrb_irep gem_mrblib_mruby_method_proc_irep_4 = {
  3,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_4,
  NULL,NULL,gem_mrblib_mruby_method_proc_reps_4,
  gem_mrblib_mruby_method_proc_lv_4,
  NULL,					/* debug_info */
  9,0,0,1,0
};
static const mrb_irep *gem_mrblib_mruby_method_proc_reps_1[3] = {
  &gem_mrblib_mruby_method_proc_irep_2,
  &gem_mrblib_mruby_method_proc_irep_3,
  &gem_mrblib_mruby_method_proc_irep_4,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_syms_1, 3, (MRB_SYM(to_proc), MRB_OPSYM(lshift), MRB_OPSYM(rshift), ), const);
static const mrb_code gem_mrblib_mruby_method_proc_iseq_1[26] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x01,0x63,0x01,0x58,0x02,
0x02,0x5f,0x01,0x02,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_method_proc_irep_1 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_1,
  NULL,gem_mrblib_mruby_method_proc_syms_1,gem_mrblib_mruby_method_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  26,0,3,3,0
};
static const mrb_irep *gem_mrblib_mruby_method_proc_reps_0[1] = {
  &gem_mrblib_mruby_method_proc_irep_1,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_method_proc_syms_0, 1, (MRB_SYM(Method), ), const);
static const mrb_code gem_mrblib_mruby_method_proc_iseq_0[13] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_method_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_method_proc_iseq_0,
  NULL,gem_mrblib_mruby_method_proc_syms_0,gem_mrblib_mruby_method_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  13,0,1,1,0
};
static
const struct RProc gem_mrblib_mruby_method_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_method_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_method_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_method_gem_init(mrb_state *mrb);
void mrb_mruby_method_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_method_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_method_proc_init_syms(mrb);
  mrb_mruby_method_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_method_proc);
}

void GENERATED_TMP_mrb_mruby_method_gem_final(mrb_state *mrb) {
  mrb_mruby_method_gem_final(mrb);
}
