/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_2, 2, (MRB_SYM(read), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_2[34] = {
0x34,0x00,0x00,0x01,0x12,0x03,0x2f,0x03,0x00,0x00,0x01,0x02,0x03,0x27,0x03,0x00,0x0d,0x01,0x03,0x01,
0x01,0x04,0x02,0x2f,0x03,0x01,0x01,0x25,0xff,0xe6,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_2, 2, (MRB_SYM(block), MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_2 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_2,
  NULL,gem_mrblib_mruby_dir_proc_syms_2,NULL,
  gem_mrblib_mruby_dir_proc_lv_2,
  NULL,					/* debug_info */
  34,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_10, 2, (MRB_SYM(read), MRB_OPSYM(lshift), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_10[36] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2f,0x04,0x00,0x00,0x01,0x03,0x04,0x27,0x04,0x00,0x0e,0x21,0x04,
0x03,0x00,0x01,0x05,0x03,0x2f,0x04,0x01,0x01,0x25,0xff,0xe4,0x11,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_10, 3, (MRB_SYM(d), 0,MRB_SYM(s), ), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_10 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_10,
  NULL,gem_mrblib_mruby_dir_proc_syms_10,NULL,
  gem_mrblib_mruby_dir_proc_lv_10,
  NULL,					/* debug_info */
  36,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_dir_proc_reps_6[1] = {
  &gem_mrblib_mruby_dir_proc_irep_10,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_6, 1, (MRB_SYM(open), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_6[21] = {
0x34,0x04,0x00,0x00,0x47,0x03,0x00,0x12,0x04,0x01,0x05,0x01,0x57,0x06,0x00,0x30,0x04,0x00,0x01,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_6, 3, (MRB_SYM(path), 0,MRB_SYM(a), ), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_6 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_6,
  NULL,gem_mrblib_mruby_dir_proc_syms_6,gem_mrblib_mruby_dir_proc_reps_6,
  gem_mrblib_mruby_dir_proc_lv_6,
  NULL,					/* debug_info */
  21,0,1,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_15, 1, (MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_15[17] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x21,0x04,0x02,0x00,0x30,0x03,0x00,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_15, 2, (MRB_SYM(d), 0,), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_15 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_15,
  NULL,gem_mrblib_mruby_dir_proc_syms_15,NULL,
  gem_mrblib_mruby_dir_proc_lv_15,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_dir_proc_reps_7[1] = {
  &gem_mrblib_mruby_dir_proc_irep_15,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_7, 1, (MRB_SYM(open), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_7[18] = {
0x34,0x04,0x00,0x01,0x12,0x03,0x01,0x04,0x01,0x57,0x05,0x00,0x30,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_7, 2, (MRB_SYM(path), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_7 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_7,
  NULL,gem_mrblib_mruby_dir_proc_syms_7,gem_mrblib_mruby_dir_proc_reps_7,
  gem_mrblib_mruby_dir_proc_lv_7,
  NULL,					/* debug_info */
  18,0,1,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_8, 4, (MRB_SYM(new), MRB_SYM(call), MRB_SYM(close), MRB_SYM(IOError), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_8[107] = {
0x34,0x04,0x00,0x01,0x01,0x04,0x02,0x27,0x04,0x00,0x3b,0x12,0x04,0x01,0x05,0x01,0x2f,0x04,0x00,0x01,
0x01,0x03,0x04,0x01,0x04,0x02,0x01,0x05,0x03,0x2f,0x04,0x01,0x01,0x2a,0x06,0x01,0x07,0x03,0x2f,0x07,
0x02,0x00,0x25,0x00,0x14,0x2a,0x07,0x1d,0x08,0x03,0x2b,0x07,0x08,0x26,0x08,0x00,0x03,0x25,0x00,0x03,
0x25,0x00,0x02,0x2c,0x07,0x2c,0x06,0x25,0x00,0x09,0x12,0x04,0x01,0x05,0x01,0x2f,0x04,0x00,0x01,0x38,
0x04,0x01,0x00,0x00,0x00,0x17,0x00,0x00,0x00,0x21,0x00,0x00,0x00,0x21,0x00,0x00,0x00,0x00,0x23,0x00,
0x00,0x00,0x2a,0x00,0x00,0x00,0x2d,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_8, 3, (MRB_SYM(path), MRB_SYM(block), MRB_SYM(d), ), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_8 = {
  4,9,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_8,
  NULL,gem_mrblib_mruby_dir_proc_syms_8,NULL,
  gem_mrblib_mruby_dir_proc_lv_8,
  NULL,					/* debug_info */
  81,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_9, 3, (MRB_SYM(getwd), MRB_SYM(_chdir), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_9[79] = {
0x34,0x04,0x00,0x01,0x01,0x04,0x02,0x27,0x04,0x00,0x2c,0x12,0x04,0x2f,0x04,0x00,0x00,0x01,0x03,0x04,
0x12,0x04,0x01,0x05,0x01,0x2f,0x04,0x01,0x01,0x01,0x04,0x02,0x01,0x05,0x01,0x2f,0x04,0x02,0x01,0x2a,
0x06,0x12,0x07,0x01,0x08,0x03,0x2f,0x07,0x01,0x01,0x2c,0x06,0x25,0x00,0x09,0x12,0x04,0x01,0x05,0x01,
0x2f,0x04,0x01,0x01,0x38,0x04,0x01,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x27,0x00,0x00,0x00,0x27,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_lv_9, 3, (MRB_SYM(path), MRB_SYM(block), MRB_SYM(wd), ), const);
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_9 = {
  4,10,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_9,
  NULL,gem_mrblib_mruby_dir_proc_syms_9,NULL,
  gem_mrblib_mruby_dir_proc_lv_9,
  NULL,					/* debug_info */
  66,0,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_dir_proc_reps_3[4] = {
  &gem_mrblib_mruby_dir_proc_irep_6,
  &gem_mrblib_mruby_dir_proc_irep_7,
  &gem_mrblib_mruby_dir_proc_irep_8,
  &gem_mrblib_mruby_dir_proc_irep_9,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_3, 12, (MRB_SYM(entries), MRB_SYM(children), MRB_SYM(foreach), MRB_SYM(open), MRB_SYM(chdir), MRB_SYM_Q(exists), MRB_SYM_Q(exist), MRB_SYM(pwd), MRB_SYM(getwd), MRB_SYM(rmdir), MRB_SYM(delete), MRB_SYM(unlink), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_3[51] = {
0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x00,0x60,0x01,0x00,0x63,0x01,0x58,0x02,0x01,0x5f,0x01,0x02,0x63,
0x01,0x58,0x02,0x02,0x5f,0x01,0x03,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,0x04,0x60,0x05,0x06,0x60,0x07,
0x08,0x60,0x09,0x0a,0x60,0x0b,0x0a,0x11,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_3 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_3,
  NULL,gem_mrblib_mruby_dir_proc_syms_3,gem_mrblib_mruby_dir_proc_reps_3,
  NULL,					/* lv */
  NULL,					/* debug_info */
  51,0,12,4,0
};
static const mrb_irep *gem_mrblib_mruby_dir_proc_reps_1[2] = {
  &gem_mrblib_mruby_dir_proc_irep_2,
  &gem_mrblib_mruby_dir_proc_irep_3,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_1, 8, (MRB_SYM(Enumerable), MRB_SYM(include), MRB_SYM(each), MRB_SYM(each_child), MRB_SYM(pos), MRB_SYM(tell), MRB_SYM_E(pos), MRB_SYM(seek), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_1[33] = {
0x1d,0x02,0x00,0x2d,0x01,0x01,0x01,0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x02,0x60,0x03,0x02,0x60,0x04,
0x05,0x60,0x06,0x07,0x12,0x01,0x62,0x01,0x5e,0x01,0x01,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_1 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_1,
  NULL,gem_mrblib_mruby_dir_proc_syms_1,gem_mrblib_mruby_dir_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  33,0,8,2,0
};
static const mrb_irep *gem_mrblib_mruby_dir_proc_reps_0[1] = {
  &gem_mrblib_mruby_dir_proc_irep_1,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_dir_proc_syms_0, 1, (MRB_SYM(Dir), ), const);
static const mrb_code gem_mrblib_mruby_dir_proc_iseq_0[13] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_dir_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_dir_proc_iseq_0,
  NULL,gem_mrblib_mruby_dir_proc_syms_0,gem_mrblib_mruby_dir_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  13,0,1,1,0
};
static
const struct RProc gem_mrblib_mruby_dir_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_dir_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_dir_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_dir_gem_init(mrb_state *mrb);
void mrb_mruby_dir_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_dir_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_dir_proc_init_syms(mrb);
  mrb_mruby_dir_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_dir_proc);
}

void GENERATED_TMP_mrb_mruby_dir_gem_final(mrb_state *mrb) {
  mrb_mruby_dir_gem_final(mrb);
}
