/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <mruby.h>
void mrb_mruby_pack_gem_init(mrb_state *mrb);
void mrb_mruby_pack_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_pack_gem_init(mrb_state *mrb) {
  mrb_mruby_pack_gem_init(mrb);
}

void GENERATED_TMP_mrb_mruby_pack_gem_final(mrb_state *mrb) {
  mrb_mruby_pack_gem_final(mrb);
}
